
# DP_RetroYearsCalibrationTag         = '<DP_RetroYearsCalibration_V1>'
DP_InitialConditionsTag             = '<DP_InitialConditions_V3>'
# DP_SurvRate1970Tag                  = '<DP_SurvRate1970_V1>'
# DP_FirstYearTag                     = '<DP_FirstYear_V1>'
DP_CustomFileYearsTag               = '<DP_CustomFileYears_V1>'
DP_CustomPopStopRescalingYearTag    = '<DP_CustomPopStopRescalingYear_V1>'
# DP_FinalYearTag                     = '<DP_FinalYear_V1>'
# DP_ProjectionValidTag               = '<DP_ProjectionValid_V1>'
# DP_VersionNumTag                    = '<DP_VersionNum_V1>'
# DP_FileTitleTag                     = '<DP_FileTitle_V1>'
# DP_ValidVersTag                     = '<DP_ValidVers_V1>'
# DP_ValidDateTag                     = '<DP_ValidDate_V1>'
# DP_EdAdSourceTag                    = '<DP_EdAdSource_V1>'
# DP_EdDmSourceTag                    = '<DP_EdDmSource_V1>'
DP_DPSourcesTag                     = '<DP_DPSources_V1>'
DP_DataSourceTag                    = '<DP_DataSource_V1>'
# DP_SourcesTag                       = '<DP_Sources_V1>'
# DP_DefaultDataSourceTag             = '<DP_DefaultDataSource_V1>'
DP_DefaultUPDLETag                  = '<DP_DefaultUPDLE_V1>'
DP_DefaultUPDIMRTag                 = '<DP_DefaultUPDIMR_V1>'
DP_DefaultUPDCMRTag                 = '<DP_DefaultUPDCMR_V1>'
DP_DefaultUPDSurvRateTag            = '<DP_DefaultUPDSurvRate_V1>'
DP_BigPopTag                        = '<DP_BigPop_V1>'
DP_FirstYearPop_Meta_Tag            = '<DP_FirstYearPop_Meta_V1>'
DP_TFRTag                           = '<DP_TFR_V1>'
DP_ASFRTag                          = '<DP_ASFR_V1>'
DP_UNPopASFRTag                     = '<DP_UNPopASFR_V1>'
DP_ASFRTablesTag                    = '<DP_ASFRTables_V1>'
DP_ASFRNumTag                       = '<DP_ASFRNum_V1>'
DP_ASFRCustomFlagTag                = '<DP_ASFRCustomFlag_V1>'
DP_SexBirthRatioTag                 = '<DP_SexBirthRatio_V1>'
DP_LETag                            = '<DP_LE_V1>'
DP_MigrRateTag                      = '<DP_MigrRate_V1>'
DP_MigrAgeDistTag                   = '<DP_MigrAgeDist_V1>'
# DP_COVID19DeathRateTag              = '<DP_COVID19DeathRate_V1>'
# DP_COVID19DeathAgeDistTag           = '<DP_COVID19DeathAgeDist_V1>'
# DP_FirstYearChangedPercentTag       = '<DP_FirstYearChangedPercent_V1>'
DP_ModelLifeFileNameTag             = '<DP_ModelLifeFileName_V1>'
# DP_ScalerTag                        = '<DP_Scaler_V1>'
DP_UseFYrSingleAgesTag              = '<DP_UseFYrSingleAges_V1>'
# DP_EnterCOVID19DeathsTag            = '<DP_EnterCOVID19Deaths_V1>'
DP_RegionalAdjustPopDataTag         = '<DP_RegionalAdjustPopData_V1>'
DP_RegionalAdjustPopCBStateTag      = '<DP_RegionalAdjustPopCBState_V1>'
DP_RegionalAdjustPopFNameTag        = '<DP_RegionalAdjustPopFName_V1>'
DP_RegionalAdjustPopFDateTag        = '<DP_RegionalAdjustPopFDate_V1>'
DP_LifeTableNumTag                  = '<DP_LifeTableNum_V1>'
# DP_DefaultEpidemicTag               = '<DP_DefaultEpidemic_V1>'
# DP_FirstYearOfEpidemicTag           = '<DP_FirstYearOfEpidemic_V1>'
# DP_SingleYearProjectionTag          = '<DP_SingleYearProjection_V1>'
DP_SurvRateTag                      = '<DP_SurvRate_V1>'
DP_BirthsTag                        = '<DP_Births_V1>'
# DP_DeathsTag                        = '<DP_Deaths_V1>'
DP_DeathsByAgeTag                   = '<DP_DeathsByAge_V1>'
DP_IMRTag                           = '<DP_IMR_V1>'
DP_CMRTag                           = '<DP_CMR_V1>'
DP_AdjLETag                         = '<DP_AdjLE_V1>'

# DP_ARTByAgeInputTypeTag             = '<DP_ARTByAgeInputType_V1>'
DP_UALowHighRatiosTag               = '<DP_UALowHighRatios_V1>'
DP_AIDSDeathsFYearUATag             = '<DP_AIDSDeathsFYearUA_V1>'
DP_UAHasRanTag                      = '<DP_UAHasRan_V1>'
DP_UAInfoTag                        = '<DP_UAInfo_V1>'

# result tags
DP_ResultAgeSpecificMortalityTag            = '<DP_ResultAgeSpecificMortality_V1>'
DP_ResultDeathsByAgeLastBirthdayTag         = '<DP_ResultDeathsByAgeAtLastBirthday_V1>'
DP_ResultCWRTag                             = '<DP_ResultCWR_V1>'
DP_ResultGRRTag                             = '<DP_ResultGRR_V1>'
DP_ResultMACTag                             = '<DP_ResultMAC_V1>'
DP_ResultNRRTag                             = '<DP_ResultNRR_V1>'
DP_ResultIMRTag                             = '<DP_ResultIMR_V1>'
DP_ResultU5MRTag                            = '<DP_ResultU5MR_V1>'
DP_Result45q15Tag                           = '<DP_Result45q15_V1>'
DP_ResultCBRTag                             = '<DP_ResultCBR_V1>'
DP_ResultGRTag                              = '<DP_ResultGR_V1>'
DP_ResultCDRTag                             = '<DP_ResultCDR_V1>'
DP_ResultDoublingTimeTag                    = '<DP_ResultDoublingTime_V1>'
DP_ResultRNITag                             = '<DP_ResultRNI_V1>'
DP_ResultMedianAgeTag                       = '<DP_ResultMedianAge_V1>'

# temp calculation tags
# DP_BirthsSATempTag          = '<DP_BirthsSA_V1>'
# DP_DeathsSATempTag          = '<DP_DeathsSA_V1>'
# DP_Pop1TempTag              = '<DP_pop1_V1>'
# DP_SAMigrRateTempTag        = '<DP_SingleAgeMigrRate_V1>'
# DP_VMatrixTempTag           = '<DP_vMatrix_V1>'
# DP_SexRatioAtBirthTempTag   = '<DP_Sex_ratio_at_birth_V1>'
# DP_SurvRateTempTag          = '<DP_SurvRateTemp_V1>'
DP_Pop1TempTransportTag                     = '<pop1TempTransport>'
DP_InitialConditionsTempTransportTag        = '<InitialConditionsTempTransport>'
