HVFirstYearTag = "<HV_FirstYear_V1>"
HVFinalYearTag = "<HV_FinalYear_V1>"
HVFinalIndexTag = "<HV_FinalIndex_V1>"
HVDataChangedTag = "<HV_DataChanged_V1>"
HVProjectionValidTag = "<HV_ProjectionValid_V1>"
HVProjectionValidDateTag = "<HV_ProjectionValidDate_V1>"
HVFileNameTag = "<HV_FileName_V1>"
HVBehaviorTag = "<HV_Behavior_V1>"
HVAgeFirstSexTag = "<HV_AgeFirstSex_V1>"
HVForceInfTag = "<HV_ForceInf_V1>"
HVInfectiousnessTag = "<HV_Infectiousness_V1>"
HVPrevalenceTag = "<HV_Prevalence_V1>"
HVCondomPercentTag = "<HV_CondomPercent_V1>"
HVTransMultSTITag = "<HV_TransMultSTI_V1>"
HVTransHIVFTag = "<HV_TransHIVF_V1>"
HVTransMultMTag = "<HV_TransMultM_V1>"
HVCondomEffTag = "<HV_CondomEff_V1>"
HVNumPartTag = "<HV_NumPart_V1>"
HVSexActsTag = "<HV_SexActs_V1>"
HVSTIPrevTag = "<HV_STIPrev_V1>"
HVEpidemicStYrTag = "<HV_EpidemicStYr_V1>"
HVIncRecruitmentTag = "<HV_IncRecruitment_V1>"
HVAllRiskOutputTag = "<HV_AllRiskOutput_V1>"
HVMaxAllRiskTag = "<HV_MaxAllRisk_V1>"
HVPercMarriedTag = "<HV_PercMarried_V1>"
HVPerIDUsharingTag = "<HV_PerIDUsharing_V1>"
HVInitialPulseTag = "<HV_InitialPulse_V1>"
HVTransMultMSMTag = "<HV_TransMultMSM_V1>"
HVRedWHenCircumTag = "<HV_RedWHenCircum_V1>"
HVInfectMultiplierOnARTTag = "<HV_InfectMultiplierOnART_V1>"
HVBloodInfectionTag = "<HV_BloodInfection_V1>"
HVARTReceiveTag = "<HV_ARTReceive_V1>"
HVMonthsInPrimaryStageTag = "<HV_MonthsInPrimaryStage_V1>"
HVGoalsBaseYearIdxTag = "<HV_GoalsBaseYearIdx_V1>"
HVGoalsTargetYearIdxTag = "<HV_GoalsTargetYearIdx_V1>"
HVImpactMatrixTag = "<HV_ImpactMatrix_V1>"
HVImpactMatrixCBIdxTag = "<HV_ImpactMatrixCBIdx_V1>"
HVARTInputCoverageByRGTag = "<HV_ARTInputCoverageByRG_V1>"
HVNumMSMRiskGroupsTag = "<HV_NumMSMRiskGroups_V1>"
HVBalanceSexActsTag = "<HV_BalanceSexActs_V1>"
HVCondomUseRadioGroupIdxTag = "<HV_CondomUseRadioGroupIdx_V1>"
HVCondomUseLogCurveParValTag = "<HV_CondomUseLogCurveParVal_V1>"
HVCondomUseInterpolatedValTag = "<HV_CondomUseInterpolatedVal_V1>"
HVCondomUseLogisticsValTag = "<HV_CondomUseLogisticsVal_V1>"
HVSTIPrevRadioGroupIdxTag = "<HV_STIPrevRadioGroupIdx_V1>"
HVSTIPrevLogCurveParValTag = "<HV_STIPrevLogCurveParVal_V1>"
HVSTIPrevInterpolatedValTag = "<HV_STIPrevInterpolatedVal_V1>"
HVSTIPrevLogisticsValTag = "<HV_STIPrevLogisticsVal_V1>"
HVRiskGroupNamesTag = "<HV_RiskGroupNames_V1>"
HVEdHVSourceTag = "<HV_EdHVSource_V1>"
HVCalcStateDataTag = "<HV_CalcStateData_V1>"
HVAdultsTag = "<HV_Adults_V1>"
HVRiskGroupPercentTag = "<HV_RiskGroupPercent_V1>"
HVNonAIDSDeathRateTag = "<HV_NonAIDSDeathRate_V1>"
HVRateofAgingTag = "<HV_RateofAging_V1>"
HVPopulationsTag = "<HV_Populations_V1>"
HVVaccinatedTag = "<HV_Vaccinated_V1>"
HVTotalVaccinatedTag = "<HV_TotalVaccinated_V1>"
HVUnvaccinatedTag = "<HV_Unvaccinated_V1>"
HVNewVaccinationsTag = "<HV_NewVaccinations_V1>"
HVTotalNewVaccinationsTag = "<HV_TotalNewVaccinations_V1>"
HVTotalAdultsHIVTag = "<HV_TotalAdultsHIV_V1>"
HVNewlyOnARTTag = "<HV_NewlyOnART_V1>"
HVNewlyEligibleARTTag = "<HV_NewlyEligibleART_V1>"
HVTotalAdultsARTTag = "<HV_TotalAdultsART_V1>"
HVRMultAllTag = "<HV_RMultAll_V1>"
HVCalcPrevalenceTag = "<HV_CalcPrevalence_V1>"
HVNewInfectionsTag = "<HV_NewInfections_V1>"
HVExitRateTag = "<HV_ExitRate_V1>"
HVAIDSDeathsTag = "<HV_AIDSDeaths_V1>"
HVAIDSDeathsARTTag = "<HV_AIDSDeathsART_V1>"
HVTotalAIDSDeathsTag = "<HV_TotalAIDSDeaths_V1>"
HVTotalNewInfectionTag = "<HV_TotalNewInfection_V1>"
HVIncidenceTag = "<HV_Incidence_V1>"
HVIncSexRatioTag = "<HV_IncSexRatio_V1>"
HVPercentPopTag = "<HV_PercentPop_V1>"
HVInfectionsAvertedTag = "<HV_InfectionsAverted_V1>"
HVCumInfectionsAvertedTag = "<HV_CumInfectionsAverted_V1>"
HVDeathsAvertedTag = "<HV_DeathsAverted_V1>"
HVCumDeathsAvertedTag = "<HV_CumDeathsAverted_V1>"
HVARTCoverageByRGTag = "<HV_ARTCoverageByRG_V1>"
HVTotalARTCoverageTag = "<HV_TotalARTCoverage_V1>"
HVNewHIVTag = "<HV_NewHIV_V1>"
HVFitDataTag = "<HV_FitData_V1>"
HVFitParamSetTag = "<HV_FitParamSet_V1>"
HVFitControlTag = "<HV_FitControl_V1>"
HVLowRiskCondomUseFromFPTag = "<HV_LowRiskCondomUseFromFP_V1>"
HVEdFmHighlightTag = "<HV_EdFmHighlight_V1>"
