RNProjectionValidTag = "<RN_ProjectionValid_V1>"
RNProjectionValidDateTag = "<RN_ProjectionValidDate_V1>"
RNDataSourceTag = "<RN_DataSource_V1>"
RNVariablesRWTag = "<RN_VariablesRW_V1>"
RNMaxInterventionsTag = "<RN_MaxInterventions_V1>"
RNMaxPOPConstantsTag = "<RN_MaxPOPConstants_V1>"
RNMaxPSConstantsTag = "<RN_MaxPSConstants_V1>"
RNMaxSummaryTableConstantsTag = "<RN_MaxSummaryTableConstants_V1>"
RNFirstYearOfEstimatesTag = "<RN_FirstYearOfEstimates_V1>"
RNFirstYearOfEstimatesCBIdxTag = "<RN_FirstYearOfEstimatesCBIdx_V1>"
RNPopulationSizesTag = "<RN_PopulationSizes_V1>"
RNUserGeneralPopTag = "<RN_UserGeneralPop_V1>"
RNUserMostAtRiskPopTag = "<RN_UserMostAtRiskPop_V1>"
RNCoverageTag = "<RN_Coverage_V1>"
RNUserGeneralPopCoverageTag = "<RN_UserGeneralPopCoverage_V1>"
RNUserMostAtRiskPopCoverageTag = "<RN_UserMostAtRiskPopCoverage_V1>"
RNUseRNMDataTag = "<RN_UseRNMData_V1>"
RNCurrencyForMitigationCBIdxTag = "<RN_CurrencyForMitigationCBIdx_V1>"
RNPrEPCoverageTag = "<RN_PrEPCoverage_V1>"
RNPrEPEffectivenessTag = "<RN_PrEPEffectiveness_V1>"
RNVaccineCovTypeTag = "<RN_VaccineCovType_V1>"
RNVacCoverageTag = "<RN_VacCoverage_V1>"
RNVaccineEffectivenessTag = "<RN_VaccineEffectiveness_V1>"
RNVaccineBehavEffectTag = "<RN_VaccineBehavEffect_V1>"
RNTypeOfVaccineTag = "<RN_TypeOfVaccine_V1>"
RNVaccineTargetingTag = "<RN_VaccineTargeting_V1>"
RNCureCovTypeTag = "<RN_CureCovType_V1>"
RNCureCoverageTag = "<RN_CureCoverage_V1>"
RNCureEffectivenessTag = "<RN_CureEffectiveness_V1>"
RNADHTreatCovTag = "<RN_ADHTreatCov_V1>"
RNADHTreatReducMortTag = "<RN_ADHTreatReducMort_V1>"
RNPointOfCareTag = "<RN_PointOfCare_V1>"
RNPOCEffectTag = "<RN_POCEffect_V1>"
RNUnitCostsTag = "<RN_UnitCosts_V1>"
RNUserGeneralPopUnitCostsTag = "<RN_UserGeneralPopUnitCosts_V1>"
RNUserMostAtRiskPopUnitCostsTag = "<RN_UserMostAtRiskPopUnitCosts_V1>"
RNCurrencyForUnitCostsCBIdxTag = "<RN_CurrencyForUnitCostsCBIdx_V1>"
RNPreTestTag = "<RN_PreTest_V1>"
RNPostTestTag = "<RN_PostTest_V1>"
RNPostNatalTag = "<RN_PostNatal_V1>"
RNMotherTag = "<RN_Mother_V1>"
RNPCRForInfantAfterBirthTag = "<RN_PCRForInfantAfterBirth_V1>"
RNInfantAfterBFTag = "<RN_InfantAfterBF_V1>"
RNNevirapine200Tag = "<RN_Nevirapine200_V1>"
RNNevirapineInfantTag = "<RN_NevirapineInfant_V1>"
RNAZTTag = "<RN_AZT_V1>"
RNThreeTCTag = "<RN_ThreeTC_V1>"
RNTripleTreatmentTag = "<RN_TripleTreatment_V1>"
RNTripleProphylaxisTag = "<RN_TripleProphylaxis_V1>"
RNServiceDeliveryTag = "<RN_ServiceDelivery_V1>"
RNFormulaTag = "<RN_Formula_V1>"
RNFirstLineARTDrugsTag = "<RN_FirstLineARTDrugs_V1>"
RNSecondLineARTDrugsTag = "<RN_SecondLineARTDrugs_V1>"
RNAdditARTDrugCostsTBmaleTag = "<RN_AdditARTDrugCostsTBmale_V1>"
RNAdditARTDrugCostsTBfemaleTag = "<RN_AdditARTDrugCostsTBfemale_V1>"
RNLabCostsARTTrTag = "<RN_LabCostsARTTr_V1>"
RNDrugLabCostsTrInfTag = "<RN_DrugLabCostsTrInf_V1>"
RNCotrimProphylaxisTag = "<RN_CotrimProphylaxis_V1>"
RNTBProphylaxisTag = "<RN_TBProphylaxis_V1>"
RNNutritionSuppSixMoTag = "<RN_NutritionSuppSixMo_V1>"
RNChildrenARVDrugsTag = "<RN_ChildrenARVDrugs_V1>"
RNChildrenLabCostsARTTrTag = "<RN_ChildrenLabCostsARTTr_V1>"
RNCostPerInpatientDayTag = "<RN_CostPerInpatientDay_V1>"
RNCostPerOutpatientDayTag = "<RN_CostPerOutpatientDay_V1>"
RNARTinpatientDaysTag = "<RN_ARTinpatientDays_V1>"
RNARToutpatientDaysTag = "<RN_ARToutpatientDays_V1>"
RNOItreatmentInpatientDaysTag = "<RN_OItreatmentInpatientDays_V1>"
RNOItreatmentOutpatientDaysTag = "<RN_OItreatmentOutpatientDays_V1>"
RNMigFirstToSecondLineTag = "<RN_MigFirstToSecondLine_V1>"
RNTestAndVisitScheduleTag = "<RN_TestAndVisitSchedule_V1>"
RNARTUnitCostsTag = "<RN_ARTUnitCosts_V1>"
RNPercentOnARTTag = "<RN_PercentOnART_V1>"
RNCurrencyForProgramSupportCBIdxTag = "<RN_CurrencyForProgramSupportCBIdx_V1>"
RNProgramSupportTag = "<RN_ProgramSupport_V1>"
RNUserProgramSupportTag = "<RN_UserProgramSupport_V1>"
RNMitigationProgramsEnteredTag = "<RN_MitigationProgramsEntered_V1>"
RNMitigationTag = "<RN_Mitigation_V1>"
RNMethodMixTag = "<RN_MethodMix_V1>"
RNCurrencyDisplayedCBIdxTag = "<RN_CurrencyDisplayedCBIdx_V1>"
RNResourcesRequiredTag = "<RN_ResourcesRequired_V1>"
RNNumberPeopleReachedTag = "<RN_NumberPeopleReached_V1>"
RNPMTCTCostsTag = "<RN_PMTCTCosts_V1>"
RNTotalCostsTag = "<RN_TotalCosts_V1>"
RNOptimizerVarsTag = "<RN_OptimizerVars_V1>"
