# fmt: off
# AIM-specific tags

AM_InitialConditionsTag                     = '<AM_InitialConditions_V1>'
AM_DataSourceTag                            = '<AM_DataSource_V1>'
AM_AMSourcesTag                             = '<AM_AMSources_V1>'
# AM_EdAdSourceTag                            = '<AM_EdAdSource_V1>'
AM_RetroYearsCalibrationTag                 = '<AM_RetroYearsCalibration_V1>'
AM_CD4ThreshHoldTag                         = '<AM_CD4ThreshHold_V1>'
AM_PopsEligTreatTag                         = '<AM_PopsEligTreat_V1>'
AM_AgeHIVChildOnTreatmentTag                = '<AM_AgeHIVChildOnTreatment_V1>'
AM_CD4ThreshHoldAdultsTag                   = '<AM_CD4ThreshHoldAdults_V1>'
AM_InfantFeedingOptionsTag                  = '<AM_InfantFeedingOptions_V1>'
AM_InfantFeedingOptions_MetaTag             = '<AM_InfantFeedingOptions_Meta_V1>'
AM_ARVRegimenTag                            = '<AM_ARVRegimen_V1>'
AM_ARVRegimen_MetaTag                       = '<AM_ARVRegimen_Meta_V1>'
AM_PatientsReallocatedTag                   = '<AM_PatientsReallocated_V1>'
AM_PercentARTDeliveryTag                    = '<AM_PercentARTDelivery_V1>'
AM_PregTermAbortionPerNumTag                = '<AM_PregTermAbortionPerNum_V1>'
AM_PregTermAbortionTag                      = '<AM_PregTermAbortion_V1>'
AM_NumNewARTPatsTag                         = '<AM_NumNewARTPats_V1>'
AM_MedCD4CountInitTag                       = '<AM_MedCD4CountInit_V1>'
# AM_PercLostFollowupTag                      = '<AM_PercLostFollowup_V1>' # Turned into AM_PercInterruptedTag
AM_PercInterruptedTag                       = '<AM_PercInterrupted_V1>'
AM_NumberInitTreatmentReinitsTag            = '<AM_NumberInitTreatmentReinits_V1>'
AM_NumNewlyInitARTTag                       = '<AM_NumNewlyInitART_V1>'
# AM_PercLostFollowupChildTag                 = '<AM_PercLostFollowupChild_V1>' # Turned into AM_PercInterruptedChildTag
AM_PercInterruptedChildTag                  = '<AM_PercInterruptedChild_V1>'
AM_NumberInitTreatmentReinitsChildTag       = '<AM_NumberInitTreatmentReinitsChild_V1>'
AM_NumNewlyInitARTChildTag                  = '<AM_NumNewlyInitARTChild_V1>'
AM_HAARTBySexTag                            = '<AM_HAARTBySex_V1>'
AM_CD4CoverageTag                           = '<AM_CD4Coverage_V1>'
AM_ARTByAgeInputTypeTag                     = '<AM_ARTByAgeInputType_V1>'
AM_ARTByAge5YearAGTag                       = '<AM_ARTByAge5YearAG_V1>'
AM_ARTByAgeGAMAGTag                         = '<AM_ARTByAgeGAMAG_V1>'
AM_CovPopsEligTreatTag                      = '<AM_CovPopsEligTreat_V1>'
AM_ChildTreatInputsTag                      = '<AM_ChildTreatInputs_V1>'
# AM_ChildTreatInputTypeTag                   = '<AM_ChildTreatInputType_V1>'
# AM_CotrimPerNumTag                          = '<AM_CotrimPerNum_V1>'
AM_ChildARTByAgeGroupPerNumTag              = '<AM_ChildARTByAgeGroupPerNum_V1>'
# AM_ChildARTByMonthTag                       = '<AM_ChildARTByMonth_V1>'
# AM_ChildPercentLTFUByMonthTag               = '<AM_ChildPercentLTFUByMonth_V1>'
AM_ANCTestingValuesTag                      = '<AM_ANCTestingValues_V1>'
# AM_NetMigrationPLHIVTag                     = '<AM_NetMigrationPLHIV_V1>'
AM_NewInfectionsLessImmigrantsTag           = '<AM_NewInfectionsLessImmigrants_V1>'
AM_HIVTestingTag                            = '<AM_HIVTesting_V2>'
AM_HIVTestingHTSTestsByAgeTag               = '<AM_HIVTestingHTSTestsByAge_V1>'
AM_Shiny90SurveyDataTag                     = '<AM_Shiny90SurveyData_V1>'
AM_Shiny90SurveyData_MetaTag                = '<AM_Shiny90SurveyData_Meta_V1>'
AM_Shiny90ProgramDataTag                    = '<AM_Shiny90ProgramData_V1>'
AM_Shiny90ProgramData_MetaTag               = '<AM_Shiny90ProgramData_Meta_V1>'
AM_Shiny90AIDSDeathsFYearTag                = '<AM_Shiny90AIDSDeathsFYear_V1>'
AM_Shiny90PopTag                            = '<AM_Shiny90Pop_V1>'
AM_Shiny90NumTestsTag                       = '<AM_Shiny90NumTests_V1>'
AM_Shiny90NumTested12MTag                   = '<AM_Shiny90NumTested12M_V1>'
AM_Shiny90TotalTestsTag                     = '<AM_Shiny90TotalTests_V1>'
AM_Shiny90EverTestedTag                     = '<AM_Shiny90EverTested_V1>'
AM_Shiny90DiagnosedTag                      = '<AM_Shiny90Diagnosed_V1>'
AM_Shiny90NumAwareTag                       = '<AM_Shiny90NumAware_V1>'
AM_Shiny90NumDiagnosesTag                   = '<AM_Shiny90NumDiagnoses_V1>'
AM_Shiny90NumDiagnosesModTag                = '<AM_Shiny90NumDiagnosesMod_V1>'
AM_Shiny90NumLateDiagnosesTag               = '<AM_Shiny90NumLateDiagnoses_V1>'
AM_Shiny90NotDiagHIV1YrTag                  = '<AM_Shiny90NotDiagHIV1Yr_V1>'
AM_Shiny90NumFirstTestHIVNeg_Tag            = '<AM_Shiny90NumFirstTestHIVNeg_V1>'
AM_Shiny90NumReTestHIVNeg_Tag               = '<AM_Shiny90NumReTestHIVNeg_V1>'
AM_Shiny90NumRetestPLHIVOnART_Tag           = '<AM_Shiny90NumRetestPLHIVOnART_V1>'
AM_Shiny90NumRetestPLHIVNoART_Tag           = '<AM_Shiny90NumRetestPLHIVNoART_V1>'
AM_Shiny90NumNewDiagnoses_Tag               = '<AM_Shiny90NumNewDiagnoses_V1>'
AM_Shiny90PosRate_Tag                       = '<AM_Shiny90PosRate_V1>'
AM_Shiny90YieldNewDiagn_Tag                 = '<AM_Shiny90YieldNewDiagn_V1>'
AM_Shiny90IsFittedTag                       = '<AM_Shiny90IsFitted_V1>'
AM_KnowledgeOfStatusInputTypeTag            = '<AM_KnowledgeOfStatusInputType_V1>'
AM_KnowledgeOfStatusInputTag                = '<AM_KnowledgeOfStatusInput_V1>'
AM_KOSNewDiagnosesChildren0t14Tag           = '<AM_KOSNewDiagnosesChildren0t14_V1>'
AM_KOSNewDiagnosesAdults15PlusTag           = '<AM_KOSNewDiagnosesAdults15Plus_V1>'
AM_KOSNewDiagnosesRecCD4TestTag             = '<AM_KOSNewDiagnosesRecCD4Test_V1>'
        
AM_ViralSuppressionInputTypeTag             = '<AM_ViralSuppressionInputType_V1>'
AM_ViralSuppressionInputTag                 = '<AM_ViralSuppressionInput_V1>'
AM_ViralSuppressionThresholdTag             = '<AM_ViralSuppressionThreshold_V1>'
AM_Meningitis_Tag                           = '<AM_Meningitis_V1>'
AM_AdvOptsMeningitis_Tag                    = '<AM_AdvOptsMeningitis_V1>'

AM_ChildAnnRateProgressLowerCD4Tag          = '<AM_ChildAnnRateProgressLowerCD4_V1>'
AM_ChildDistNewInfectionsCD4Tag             = '<AM_ChildDistNewInfectionsCD4_V1>'
AM_ChildMortByCD4NoARTTag                   = '<AM_ChildMortByCD4NoART_V1>'
AM_ChildMortalityRatesTag                   = '<AM_ChildMortalityRates_V1>'
AM_ChildMortalityRates_MetaTag              = '<AM_ChildMortalityRates_Meta_V1>'
AM_ChildMortalityRatesMultiplierTag         = '<AM_ChildMortalityRatesMultiplier_V1>'
AM_ChildMortByCD4WithART0to6Tag             = '<AM_ChildMortByCD4WithART0to6_V1>'
AM_ChildMortByCD4WithART0to6_MetaTag        = '<AM_ChildMortByCD4WithART0to6_Meta_V1>'
AM_ChildMortByCD4WithART0to6PercTag         = '<AM_ChildMortByCD4WithART0to6Perc_V1>'
AM_ChildMortByCD4WithART0to6Perc_MetaTag    = '<AM_ChildMortByCD4WithART0to6Perc_Meta_V1>'
AM_ChildMortByCD4WithART7to12Tag            = '<AM_ChildMortByCD4WithART7to12_V1>'
AM_ChildMortByCD4WithART7to12_MetaTag       = '<AM_ChildMortByCD4WithART7to12_Meta_V1>'
AM_ChildMortByCD4WithART7to12PercTag        = '<AM_ChildMortByCD4WithART7to12Perc_V1>'
AM_ChildMortByCD4WithART7to12Perc_MetaTag   = '<AM_ChildMortByCD4WithART7to12Perc_Meta_V1>'
AM_ChildMortByCD4WithARTGT12Tag             = '<AM_ChildMortByCD4WithARTGT12_V1>'
AM_ChildMortByCD4WithARTGT12_MetaTag        = '<AM_ChildMortByCD4WithARTGT12_Meta_V1>'
AM_ChildMortByCD4WithARTGT12PercTag         = '<AM_ChildMortByCD4WithARTGT12Perc_V1>'
AM_ChildMortByCD4WithARTGT12Perc_MetaTag    = '<AM_ChildMortByCD4WithARTGT12Perc_Meta_V1>'
AM_ChildARTDistTag                          = '<AM_ChildARTDist_V1>'
AM_ChildARTDist_MetaTag                     = '<AM_ChildARTDist_Meta_V1>'
AM_EffectTreatChildTag                      = '<AM_EffectTreatChild_V1>'
AM_ChildWeightBandsTag                      = '<AM_ChildWeightBands_V1>'
AM_AdultAnnRateProgressLowerCD4Tag          = '<AM_AdultAnnRateProgressLowerCD4_V1>'
AM_AdultAnnRateProgressLowerCD4_MetaTag     = '<AM_AdultAnnRateProgressLowerCD4_Meta_V1>'
AM_AdultDistNewInfectionsCD4Tag             = '<AM_AdultDistNewInfectionsCD4_V1>'
AM_AdultDistNewInfectionsCD4_MetaTag        = '<AM_AdultDistNewInfectionsCD4_Meta_V1>'
AM_AdultMortByCD4NoARTTag                   = '<AM_AdultMortByCD4NoART_V1>'
AM_AdultMortByCD4NoART_MetaTag              = '<AM_AdultMortByCD4NoART_Meta_V1>'
AM_AdultInfectReducTag                      = '<AM_AdultInfectReduc_V1>'
AM_MortalityRatesTag                        = '<AM_MortalityRates_V1>'
AM_MortalityRates_MetaTag                   = '<AM_MortalityRates_Meta_V1>'
AM_MortalityRatesMultiplierTag              = '<AM_MortalityRatesMultiplier_V1>'
AM_AdultMortByCD4WithART0to6Tag             = '<AM_AdultMortByCD4WithART0to6_V1>'
AM_AdultMortByCD4WithART0to6_MetaTag        = '<AM_AdultMortByCD4WithART0to6_Meta_V1>'
AM_AdultMortByCD4WithART7to12Tag            = '<AM_AdultMortByCD4WithART7to12_V1>'
AM_AdultMortByCD4WithART7to12_MetaTag       = '<AM_AdultMortByCD4WithART7to12_Meta_V1>'
AM_AdultMortByCD4WithARTGT12Tag             = '<AM_AdultMortByCD4WithARTGT12_V1>'
AM_AdultMortByCD4WithARTGT12_MetaTag        = '<AM_AdultMortByCD4WithARTGT12_Meta_V1>'
AM_AdultNonAIDSExcessMortTag                = '<AM_AdultNonAIDSExcessMort_V2>'
AM_AdultNonAIDSExcessMort_Meta_Tag          = '<AM_AdultNonAIDSExcessMort_Meta_V1>'
AM_AdultNonAIDSExcessMortRegionTag          = '<AM_AdultNonAIDSExcessMortRegion_V1>'
AM_AdultNonAIDSExcessMortCustomFlagTag      = '<AM_AdultNonAIDSExcessMortCustomFlag_V1>'
AM_NonAIDSExcessDeathsSingleAgeTag          = '<AM_NonAIDSExcessDeathsSingleAge_V2>'

AM_TFRRegionTag                             = '<AM_TFRRegion_V1>'
AM_TFRRegion_MetaTag                        = '<AM_TFRRegion_Meta_V1>'
AM_HIVTFRCustomFlagTag                      = '<AM_HIVTFRCustomFlag_V1>'
AM_HIVTFRTag                                = '<AM_HIVTFR_V1>'
AM_HIVTFR_MetaTag                           = '<AM_HIVTFR_Meta_V1>'
AM_TFRInputTypeTag                          = '<AM_TFRInputType_V1>'
AM_FertCD4DiscountTag                       = '<AM_FertCD4Discount_V1>'
AM_FertCD4Discount_MetaTag                  = '<AM_FertCD4Discount_Meta_V1>'
AM_RatioWomenOnARTTag                       = '<AM_RatioWomenOnART_V1>'
AM_RatioWomenOnART_MetaTag                  = '<AM_RatioWomenOnART_Meta_V1>'
AM_FRRFitInputTag                           = '<AM_FRRFitInput_V1>'
AM_FRRbyLocationTag                         = '<AM_FRRbyLocation_V1>'
AM_TransEffAssumpTag                        = '<AM_TransEffAssump_V1>'
AM_DALYDisabilityWeightsTag                 = '<AM_DALYDisabilityWeights_V1>'
AM_RiskPopOrphansTag                        = '<AM_RiskPopOrphans_V1>'
AM_ECDCValuesTag                            = '<AM_ECDCValues_V1>'
AM_NosocomialInfectionsByAgeTag             = '<AM_NosocomialInfectionsByAge_V1>'
AM_HIVMigrantsBySexAgeTag                   = '<AM_HIVMigrantsBySexAge_V1>'
AM_HIVMigrantsBySingleAgeTag                = '<AM_HIVMigrantsBySingleAge_V1>'
AM_IncidenceInput1970Tag                    = '<AM_IncidenceInput1970_V1>'
AM_CSAVRInputAIDSDeathsTag                  = '<AM_CSAVRInputAIDSDeaths_V2>'
AM_CSAVRInputAIDSDeathsBySexTag             = '<AM_CSAVRInputAIDSDeathsBySex_V2>'
AM_CSAVRInputAIDSDeathsBySexAgeTag          = '<AM_CSAVRInputAIDSDeathsBySexAge_V2>'
AM_CSAVRInputAIDSDeathsSourceTag            = '<AM_CSAVRInputAIDSDeathsSource_V1>'
AM_CSAVRInputAIDSDeathsSourceNameTag        = '<AM_CSAVRInputAIDSDeathsSourceName_V1>'
AM_CSAVRInputNewDiagnosesTag                = '<AM_CSAVRInputNewDiagnoses_V1>'
AM_CSAVRInputNewDiagnosesBySexTag           = '<AM_CSAVRInputNewDiagnosesBySex_V1>'
AM_CSAVRInputNewDiagnosesBySexAgeTag        = '<AM_CSAVRInputNewDiagnosesBySexAge_V1>'
AM_CSAVRInputNewDiagnosesBySexAgeCD4Tag     = '<AM_CSAVRInputNewDiagnosesBySexAgeCD4_V1>'
AM_CSAVRInputCD4DistAtDiagTag               = '<AM_CSAVRInputCD4DistAtDiag_V1>'
AM_CSAVRPopulationValueTag                  = '<AM_CSAVRPopulationValue_V1>'
AM_AIDSMortalityAllAgesTag                  = '<AM_AIDSMortalityAllAges_V1>'
AM_AnnualInterruptionRateTag                = '<AM_AnnualInterruptionRate_V1>'
AM_IncreasedLikelihoodOfReinitTag           = '<AM_IncreasedLikelihoodOfReinit_V1>'
AM_OffARTMortRateMultiplierTag              = '<AM_OffARTMortRateMultiplier_V1>'
AM_ChildAnnualInterruptionRateTag           = '<AM_ChildAnnualInterruptionRate_V1>'
AM_ChildIncreasedLikelihoodOfReinitTag      = '<AM_ChildIncreasedLikelihoodOfReinit_V1>'
AM_ChildOffARTMortRateMultiplierTag         = '<AM_ChildOffARTMortRateMultiplier_V1>'
AM_CSAVRFitOptionsTag                       = '<AM_CSAVRFitOptions_V1>'
AM_CSAVRParametersTag                       = '<AM_CSAVRParameters_V1>'
AM_CSAVRIncScaleParametersTag               = '<AM_CSAVRIncScaleParameters_V1>'
AM_CSAVRUncertaintyParamsTag                = '<AM_CSAVRUncertaintyParams_V1>'
AM_CSAVRConstrainPLHIVGTNumARTTag           = '<AM_CSAVRConstrainPLHIVGTNumART_V1>'
AM_CSAVRTypeOfFitTag                        = '<AM_CSAVRTypeOfFit_V1>'
AM_CSAVRAdjustIRRsTag                       = '<AM_CSAVRAdjustIRRs_V2>'
AM_CSAVRModelFitTypesTag                    = '<AM_CSAVRModelFitTypes_V1>'
AM_CSAVRMetaDataTag                         = '<AM_CSAVRMetaData_V3>'
AM_CSAVRMeanCD4atDiagnosisTag               = '<AM_CSAVRMeanCD4atDiagnosis_V2>'
AM_CSAVRMeanCD4atDiagnosisByAgeSexTag       = '<AM_CSAVRMeanCD4atDiagnosisByAgeSex_V2>'
AM_CSAVRTimeInfToDiagTag                    = '<AM_CSAVRTimeInfToDiag_V2>'
AM_CSAVRPropOfDiagnosedTag                  = '<AM_CSAVRPropOfDiagnosed_V2>'
AM_CSAVRPropOfDiagnosedNoARTTag             = '<AM_CSAVRPropOfDiagnosedNoART_V2>'
AM_CSAVRPropOfDiagnosedByAgeSexCD4Tag       = '<AM_CSAVRPropOfDiagnosedByAgeSexCD4_V2>'
AM_CSAVRNumPLHIVTag                         = '<AM_CSAVRNumPLHIV_V2>'
AM_CSAVRNumPLHIVByAgeSexCD4Tag              = '<AM_CSAVRNumPLHIVByAgeSexCD4_V2>'
AM_CSAVRNumDiagnosedTag                     = '<AM_CSAVRNumDiagnosed_V2>'
AM_CSAVRNumDiagnosedByAgeSexCD4Tag          = '<AM_CSAVRNumDiagnosedByAgeSexCD4_V2>'
AM_CSAVRAIDSDeathsTag                       = '<AM_CSAVRAIDSDeaths_V2>'
AM_CSAVRAIDSDeathsByAgeSexTag               = '<AM_CSAVRAIDSDeathsByAgeSex_V2>'
AM_CSAVRNumNewInfectionsTag                 = '<AM_CSAVRNumNewInfections_V2>'
AM_CSAVRIncidenceByFitTag                   = '<AM_CSAVRIncidenceByFit_V1>'
AM_HIVSexRatioTag                           = '<AM_HIVSexRatio_V1>'
AM_HIVSexRatio_MetaTag                      = '<AM_HIVSexRatio_Meta_V3>'
AM_CSAVRHIVSexRatioTag                      = '<AM_CSAVRHIVSexRatio_V2>'
AM_HIVSexRatioFittingValuesTag              = '<AM_HIVSexRatioFittingValues_V1>'
AM_CustomSAPDataTag                         = '<AM_CustomSAPData_V2>'
AM_CustomSAPData_MetaTag                    = '<AM_CustomSAPData_Meta_V1>'
AM_CustomSAPDataIndexTag                    = '<AM_CustomSAPDataIndex_V2>'
AM_ARTTreatFitDistOfHIVTag                  = '<AM_ARTTreatFitDistOfHIV_V1>'
AM_ARTTreatFitHIVSexRatioTag                = '<AM_ARTTreatFitHIVSexRatio_V1>'
AM_ARTTreatFitHIVSexRatio_MetaTag           = '<AM_ARTTreatFitHIVSexRatio_Meta_V1>'
AM_FittingDataTag                           = '<AM_FittingData_V1>'
AM_ARTTreatFittingDataTag                   = '<AM_ARTTreatFittingData_V1>'
AM_DistOfHIVTag                             = '<AM_DistOfHIV_V1>'
AM_DistOfHIV_MetaTag                        = '<AM_DistOfHIV_Meta_V2>'
AM_CSAVRDistOfHIVTag                        = '<AM_CSAVRDistOfHIV_V3>'
AM_EPPANCRTDataTag                          = '<AM_EPPANCRTData_V1>'
AM_SAPFormDHSFitSurveyTag                   = '<AM_SAPFormDHSFitSurvey_V1>'
AM_IRRFittingValuesTag                      = '<AM_IRRFittingValues_V1>'
AM_AIDS45q15Tag                             = '<AM_AIDS45q15_V1>'
AM_NonAIDS45q15Tag                          = '<AM_NonAIDS45q15_V1>'
AM_Total45q15Tag                            = '<AM_Total45q15_V1>'
AM_Total45q15_MetaTag                       = '<AM_Total45q15_Meta_V1>'
AM_Under5MortRateTag                        = '<AM_Under5MortRate_V1>'
AM_PMTCTProgEstNeedTag                      = '<AM_PMTCTProgEstNeed_V1>'
AM_NumberOnARTTag                           = '<AM_NumberOnART_V1>'
AM_ARTCovByAgeTag                           = '<AM_ARTCovByAge_V1>'
AM_KeyPopsTag                               = '<AM_KeyPops_V1>'
AM_PregWomenPrevRoutineTestTag              = '<AM_PregWomenPrevRoutineTest_V1>'
AM_PregWomenPrevTag                         = '<AM_PregWomenPrev_V1>'
AM_PregWomenPrev_MetaTag                    = '<AM_PregWomenPrev_Meta_V1>'
AM_PrevSurveyTag                            = '<AM_PrevSurvey_V1>'
AM_PrevSurvey_MetaTag                       = '<AM_PrevSurvey_Meta_V1>'
AM_ARTCovSurveyTag                          = '<AM_ARTCovSurvey_V1>'
AM_ARTCovSurvey_MetaTag                     = '<AM_ARTCovSurvey_Meta_V1>'
AM_MortRateByAgeTag                         = '<AM_MortRateByAge_V1>'
AM_AllCauseMortalityTag                     = '<AM_AllCauseMortality_V1>'
AM_AllCauseMortality_MetaTag                = '<AM_AllCauseMortality_Meta_V1>'
AM_AIDSMortalityTag                         = '<AM_AIDSMortality_V1>'
AM_AIDSMortality_MetaTag                    = '<AM_AIDSMortality_Meta_V1>'
AM_NumberOnARTByAgeTag                      = '<AM_NumberOnARTByAge_V1>'
AM_NewlyStartingARTTag                      = '<AM_NewlyStartingART_V1>'
AM_AdultsChildrenStartingARTTag             = '<AM_AdultsChildrenStartingART_V1>'
AM_PercentOfPopTag                          = '<AM_PercentOfPop_V1>'
# AM_FutureARTTag                             = '<AM_FutureART_V1>'
AM_ARTCoverageSelectionTag                  = '<AM_ARTCoverageSelection_V1>'
AM_BFYearsRGIdxTag                          = '<AM_BFYearsRGIdx_V1>'
AM_BFArvRGIdxTag                            = '<AM_BFArvRGIdx_V1>'
AM_ChildHIVMortARTRegionTag                 = '<AM_ChildHIVMortARTRegion_V1>'
AM_ChildHIVMortARTCustomFlagTag             = '<AM_ChildHIVMortARTCustomFlag_V1>'
AM_ChildARTDistRegionTag                    = '<AM_ChildARTDistRegion_V1>'
AM_ChildARTDistCustomFlagTag                = '<AM_ChildARTDistCustomFlag_V1>'
AM_AdultProgressRatesRegionTag              = '<AM_AdultProgressRatesRegion_V1>'
AM_AdultProgressRatesCustomFlagTag          = '<AM_AdultProgressRatesCustomFlag_V1>'
AM_AdultHIVMortNoARTRegionTag               = '<AM_AdultHIVMortNoARTRegion_V1>'
AM_AdultHIVMortNoARTCustomFlagTag           = '<AM_AdultHIVMortNoARTCustomFlag_V1>'
AM_AdultHIVMortARTRegionTag                 = '<AM_AdultHIVMortARTRegion_V1>'
AM_AdultHIVMortARTCustomFlagTag             = '<AM_AdultHIVMortARTCustomFlag_V1>'
AM_DALYBaseYearTag                          = '<AM_DALYBaseYear_V1>'
AM_DALYDiscountRateTag                      = '<AM_DALYDiscountRate_V1>'
AM_DALYUseStandardLifeTableTag              = '<AM_DALYUseStandardLifeTable_V1>'
# AM_DALYTBWeightTag                          = '<AM_DALYTBWeight_V1>'
AM_OrphansRegionalPatternTag                = '<AM_OrphansRegionalPattern_V1>'
AM_IncidenceInput1970BoolTag                = '<AM_IncidenceInput1970Bool_V1>'
AM_IncidenceOptionsTag                      = '<AM_IncidenceOptions_V1>'
AM_IncidenceByFitTag                        = '<AM_IncidenceByFit_V1>'
AM_FourDecPlaceIDTag                        = '<AM_FourDecPlaceID_V1>'
AM_EPPPrevAdjTag                            = '<AM_EPPPrevAdj_V1>'
AM_EPPMaxAdjFactorTag                       = '<AM_EPPMaxAdjFactor_V1>'
# AM_EPPPrevAdjustmentYearTag                 = '<AM_EPPPrevAdjustmentYear_V1>'
AM_EPPPopulationAgesTag                     = '<AM_EPPPopulationAges_V1>'
# AM_IncEpidemicRGIdxTag                      = '<AM_IncEpidemicRGIdx_V1>'
AM_IncEpidemicCustomFlagTag                 = '<AM_IncEpidemicCustomFlag_V1>'
AM_SexRatioFromEPPTag                       = '<AM_SexRatioFromEPP_V1>'
# AM_SurveyYearIndexTag                       = '<AM_SurveyYearIndex_V1>'
AM_HIVSexRatioFromEPPTag                    = '<AM_HIVSexRatioFromEPP_V1>'
AM_EpidemicTypeFromEPPTag                   = '<AM_EpidemicTypeFromEPP_V1>'
AM_ChangesLogTag                            = '<AM_ChangesLog_V1>'
AM_AdultPrevalenceTag                       = '<AM_AdultPrevalence_V1>'
AM_EPPCountryNameTag                        = '<AM_EPPCountryName_V1>'
AM_EPPEpiNameTag                            = '<AM_EPPEpiName_V1>'
AM_EPPEpidemicTag                           = '<AM_EPPEpidemic_V2>'
AM_EPPPrevDataTag                           = '<AM_EPPPrevData_V1>'
AM_EPPIncDataTag                            = '<AM_EPPIncData_V1>'
AM_EPPPopDataTag                            = '<AM_EPPPopData_V1>'
AM_EPPSexRatioTag                           = '<AM_EPPSexRatio_V1>'
AM_EPPBaseYrPopTag                          = '<AM_EPPBaseYrPop_V1>'
AM_EPPIDUMortalityTag                       = '<AM_EPPIDUMortality_V1>'
AM_EPPPathInfoTag                           = '<AM_EPPPathInfo_V1>'
AM_EPPAgeRangeTag                           = '<AM_EPPAgeRange_V1>'
AM_NumOfEPPEpidemicsTag                     = '<AM_NumOfEPPEpidemics_V1>'
AM_YrPtPrevalence_WBTag                     = '<AM_YrPtPrevalence_WB_V2>'
AM_AIDSDeathsAmongIDUTag                    = '<AM_AIDSDeathsAmongIDU_V1>'
AM_PropIDU_WBTag                            = '<AM_PropIDU_WB_V1>'
AM_NonAIDSDeathsAmongIDUTag                 = '<AM_NonAIDSDeathsAmongIDU_V1>'
# AM_CountryProjUsedBySubNatRegionTag         = '<AM_CountryProjUsedBySubNatRegion_V1>'
# AM_CountryProjBigPopTag                     = '<AM_CountryProjBigPop_V1>'
AM_ChAged14ByCD4CatTag                      = '<AM_ChAged14ByCD4Cat_V1>'
# AM_IMRTag                                   = '<AM_IMR_V1>'
# AM_CMRTag                                   = '<AM_CMR_V1>'
AM_NewHIVInfByRiskGroupTag                  = '<AM_NewHIVInfByRiskGroup_V2>'
# AM_HIVPopByRiskGroupTag                     = '<AM_HIVPopByRiskGroup_V1>'
AM_HIVExpUninfChildrenTag                   = '<AM_HIVExpUninfChildren_V1>'
AM_ARTExpUninfChildrenTag                   = '<AM_ARTExpUninfChildren_V1>'
# AM_PrevIncid15PlusTag                       = '<AM_PrevIncid15Plus_V1>'
AM_NewInfantInfectionsTag                   = '<AM_NewInfantInfections_V1>'
# AM_HIVPop1517Tag                            = '<AM_HIVPop1517_V1>'
# AM_ChildARTNeed1To4Tag                      = '<AM_ChildARTNeed1To4_V1>'
# AM_ARTNeedUnder2Tag                         = '<AM_ARTNeedUnder2_V1>'
AM_CD4DistributionTag                       = '<AM_CD4Distribution_V1>'
AM_CD4Distribution15_49Tag                  = '<AM_CD4Distribution15_49_V1>'
AM_CD4DistributionChildTag                  = '<AM_CD4DistributionChild_V1>'
# AM_HIVPos15YearOldsTag                      = '<AM_HIVPos15YearOlds_V1>'
AM_DeathsByAgeTag                           = '<AM_DeathsByAge_V1>'
AM_HIVBySingleAgeTag                        = '<AM_HIVBySingleAge_V1>'
# AM_AdultDeathsTag                           = '<AM_AdultDeaths_V1>'
AM_RegionalOutputTag                        = '<AM_RegionalOutput_V1>'
AM_OrphansTag                               = '<AM_Orphans_V1>'
AM_AgeLastBDayTag                           = '<AM_AgeLastBDay_V1>'
AM_PopAdjTag                                = '<AM_PopAdj_V1>'
AM_PopAdjAmountTag                          = '<AM_PopAdjAmount_V1>'
# AM_HIVTag                                   = '<AM_HIV_V1>'
# AM_NewInfectionsTag                         = '<AM_NewInfections_V1>'
# AM_AIDSDeathsTag                            = '<AM_AIDSDeaths_V1>'
# AM_AIDSDeathsARTTag                         = '<AM_AIDSDeathsART_V1>'
AM_AIDSDeathsARTSingleAgeTag                = '<AM_AIDSDeathsARTSingleAge_V1>'
# AM_AIDSDeathsNoARTTag                       = '<AM_AIDSDeathsNoART_V1>'
AM_AIDSDeathsNoARTSingleAgeTag              = '<AM_AIDSDeathsNoARTSingleAge_V1>'
AM_HIVPregWomenTag                          = '<AM_HIVPregWomen_V1>'
AM_HIVPregWomenCD4LT350Tag                  = '<AM_HIVPregWomenCD4LT350_V1>'
# AM_ChildARTCalcTag                          = '<AM_ChildARTCalc_V1>'
AM_ChildOnCotrimTag                         = '<AM_ChildOnCotrim_V1>'
AM_ChildNeedCotrimTag                       = '<AM_ChildNeedCotrim_V1>'
AM_NeedARTTag                               = '<AM_NeedART_V1>'
AM_UnmetNeedARTTag                          = '<AM_UnmetNeedART_V1>'
# AM_HIVPopUnder1Tag                          = '<AM_HIVPopUnder1_V1>'
AM_AIDSDeathsByAgeTag                       = '<AM_AIDSDeathsByAge_V1>'
AM_PerinatalTransmissionTag                 = '<AM_PerinatalTransmission_V1>'
AM_ChildCTXNeed1To4Tag                      = '<AM_ChildCTXNeed1To4_V1>'
AM_TotalOrphansTag                          = '<AM_TotalOrphans_V1>'
AM_AllAIDSOrphTag                           = '<AM_AllAIDSOrph_V1>'
AM_AllAIDSNewOrphTag                        = '<AM_AllAIDSNewOrph_V1>'
AM_NewlyNeedARTTag                          = '<AM_NewlyNeedART_V1>'
AM_ChildNeedPMTCTTag                        = '<AM_ChildNeedPMTCT_V1>'
AM_ChildOnPMTCTTag                          = '<AM_ChildOnPMTCT_V1>'
AM_MTCTRate6WksTag                          = '<AM_MTCTRate6Wks_V1>'
# AM_HIVPos50YearOldsTag                      = '<AM_HIVPos50YearOlds_V1>'
# AM_HIVPos50YearOldsARTTag                   = '<AM_HIVPos50YearOldsART_V1>'
# AM_OnARTTag                                 = '<AM_OnART_V1>'
AM_OnARTBySingleAgeTag                      = '<AM_OnARTBySingleAge_V1>'
AM_OnARTBySingleAge_ProgDataTag             = '<AM_OnARTBySingleAge_ProgData_V1>'
AM_NewInfectionsBySingleAgeTag              = '<AM_NewInfectionsBySingleAge_V1>'
AM_NewlyOnARTTag                            = '<AM_NewlyOnART_V1>'
# AM_ARTDropOutRateTag                        = '<AM_ARTDropOutRate_V1>'
# AM_OnSLTag                                  = '<AM_OnSL_V1>'
# AM_NeedARTDec31Tag                          = '<AM_NeedARTDec31_V1>'
AM_ViralSupprPhi_TempTag                    = '<AM_ViralSupprPhi_Temp_V1>'
AM_SexuallyActive15to19Tag                  = '<AM_SexuallyActive15to19_V1>'
AM_SexuallyActive15to19_MetaTag             = '<AM_SexuallyActive15to19_Meta_V1>'
AM_ReadFRR15_19Coefs_TempTag                = '<AM_ReadFRR15_19Coefs_Temp_V1>'
AM_TFR15_19DefaultDataTag                   = '<AM_TFR15_19DefaultData_V1>'
AM_FRRFitXMLDefaultDataTag                  = '<AM_FRRFitXMLDefaultData_V1>'
AM_HAARTBySexPerNumTag                      = '<AM_HAARTBySexPerNum_V1>'
AM_AdultARTAdjFactorTag                     = '<AM_AdultARTAdjFactor_V1>'
AM_AdultARTAdjFactorFlagTag                 = '<AM_AdultARTAdjFactorFlag_V1>'
AM_AdultPatsAllocToFromOtherRegionTag       = '<AM_AdultPatsAllocToFromOtherRegion_V1>'
# AM_AdultARTByMonthTag                       = '<AM_AdultARTByMonth_V1>'
# AM_AdultPercentLTFUByMonthTag               = '<AM_AdultPercentLTFUByMonth_V1>'
AM_KnowledgeOfStatusFileTitleTag            = '<AM_KnowledgeOfStatusFileTitle_V1>'
AM_CascadeActiveTag                         = '<AM_CascadeActive_V1>'
AM_PMTCTEffRegTag                           = '<AM_PMTCTEffReg_V1>'
AM_HIVPosBFWomen3MonthsTag                  = '<AM_HIVPosBFWomen3Months_V1>'
AM_HIVPosBFWomen12MonthsTag                 = '<AM_HIVPosBFWomen12Months_V1>'
# AM_ImpactCalculatedTag                      = '<AM_ImpactCalculated_V1>'
AM_AIDSDeathsNoIntervTag                    = '<AM_AIDSDeathsNoInterv_V1>'
AM_DeathsAvertARTTag                        = '<AM_DeathsAvertART_V1>'
AM_InfectAvertPMTCTTag                      = '<AM_InfectAvertPMTCT_V1>'
AM_LifeYearsGainedTag                       = '<AM_LifeYearsGained_V1>'
AM_ChildDeathsAvertARTTag                   = '<AM_ChildDeathsAvertART_V1>'
AM_DeathsAvertCotrimTag                     = '<AM_DeathsAvertCotrim_V1>'
AM_DeathsAvertPMTCTTag                      = '<AM_DeathsAvertPMTCT_V1>'
AM_HIVAgingRateTag                          = '<AM_HIVAgingRate_V1>'
AM_HIVChildNoARTByInfectionTag              = '<AM_HIVChildNoARTByInfection_V1>'
AM_TreatPercentTag                          = '<AM_TreatPercent_V1>'
# AM_AIDSBirthsTag                            = '<AM_AIDSBirths_V1>'
# AM_ARTCalcTag                               = '<AM_ARTCalc_V1>'
# AM_ARTCalc_15PlusTag                        = '<AM_ARTCalc_15Plus_V1>'
AM_MedianCD4Tag                             = '<AM_MedianCD4_V1>'
# AM_NumChildOnARTUnder1Tag                   = '<AM_NumChildOnARTUnder1_V1>'
# AM_NumChildOnARTByAgeTag                    = '<AM_NumChildOnARTByAge_V1>'
AM_AIDSMortAllAgesFYrAdjIdxTag              = '<AM_AIDSMortAllAgesFYrAdjIdx_V1>'
AM_ValidationNumberOnARTByAgeTag            = '<AM_ValidationNumberOnARTByAge_V1>'
AM_ValidationNewlyOnARTTag                  = '<AM_ValidationNewlyOnART_V1>'
AM_ValidationMortalityRateByAgeTag          = '<AM_ValidationMortalityRateByAge_V1>'
AM_ValidationAIDSMortalityByAgeTag          = '<AM_ValidationAIDSMortalityByAge_V1>'
AM_ValidationAllCausesMortalityByAgeTag     = '<AM_ValidationAllCausesMortalityByAge_V1>'
AM_ValidationPrevalenceSelectionTag         = '<AM_ValidationPrevalenceSelection_V1>'
AM_ValidationARTCoverageSelectionTag        = '<AM_ValidationARTCoverageSelection_V1>'
AM_ValidationAllCauseDeathsARTTag           = '<AM_ValidationAllCauseDeathsART_V1>'
AM_ValidationWaterfallTag                   = '<AM_ValidationWaterfall_V1>'
AM_PercART50PlusTag                         = '<AM_PercART50Plus_V2>'
AM_Prop350_500Tag                           = '<AM_Prop350_500_V1>'
AM_IncidenceAdjustmentFactorTag             = '<AM_IncidenceAdjustmentFactor_V1>'
AM_ECDCFQNameTag                            = '<AM_ECDCFQName_V1>'
AM_NewARTPatAllocTag                        = '<AM_NewARTPatAlloc_V1>'
AM_NewARTPatAlloc_MetaTag                   = '<AM_NewARTPatAlloc_Meta_V1>'
AM_NewARTPatAllocMethodTag                  = '<AM_NewARTPatAllocMethod_V1>'
AM_DefaultEpidemicTag                       = '<AM_DefaultEpidemic_V1>'
AM_FirstYearOfEpidemicTag                   = '<AM_FirstYearOfEpidemic_V1>'
# AM_DefaultDataCheckTag                      = '<AM_DefaultDataCheck_V1>'
AM_ResNonAIDSDeathsHIVPopNoARTTag           = '<AM_ResNonAIDSDeathsHIVPopNoART_V1>'
AM_ResMTCTBySourceTag                       = '<AM_ResMTCTBySource_V1>'
AM_ResDetailedTreatmentCascadeTag           = '<AM_ResDetailedTreatmentCascade_V2>'
AM_ResTreatmentCascadeTag                   = '<AM_ResTreatmentCascade_V2>'
AM_ResPerinatallyInf15_19Tag                = '<AM_ResPerinatallyInf15_19_V1>'
AM_ResPerinatallyInf20_24Tag                = '<AM_ResPerinatallyInf20_24_V1>'
AM_ResQALYsTag                              = '<AM_ResQALYs_V1>'
AM_ResDALYsAIDSOnlyTag                      = '<AM_ResDALYsAIDSOnly_V1>'
AM_ResDALYsTag                              = '<AM_ResDALYs_V1>'
AM_ResYLDTag                                = '<AM_ResYLD_V1>'
AM_ResNonAIDSDeathsHIVPopARTTag             = '<AM_ResNonAIDSDeathsHIVPopART_V1>'
AM_ResTotalDeathsHIVPopTag                  = '<AM_ResTotalDeathsHIVPop_V1>'
AM_ResAIDS45q15Tag                          = '<AM_ResAIDS45q15_V1>'
AM_ResNonAIDS45q15Tag                       = '<AM_ResNonAIDS45q15_V1>'
AM_ResNumWithAHDTag                         = '<AM_ResNumWithAHD_V1>'     
AM_ResNumWithAHDOnARTTag                    = '<AM_ResNumWithAHDOnART_V1>'
AM_ResNumWithAHDNoARTTag                    = '<AM_ResNumWithAHDNoART_V1>'
AM_Res15PlusNumWithCryptoAntigenemiaTag     = '<AM_Res15PlusNumWithCryptoAntigenemia_V1>'
AM_Res15PlusNumWithCryptoMeningitisTag      = '<AM_Res15PlusNumWithCryptoMeningitis_V1>'
AM_Res15PlusDeathsToPLHIVFromCMTag          = '<AM_Res15PlusDeathsToPLHIVFromCM_V1>'
AM_Res15PlusPercAIDSDeathsFromCMTag         = '<AM_Res15PlusPercAIDSDeathsFromCM_V1>'
AM_ResOnARTgt1Yr15PlusTag                   = '<AM_OnARTgt1Yr15Plus_V1>'
AM_ResOnARTlt1Yr15PlusTag                   = '<AM_OnARTlt1Yr15Plus_V1>'

AM_PreventionNeedsFirstTimeTag       = '<AM_PreventionNeeds_FirstTime_V1>'
AM_PreventionNeedsShowVMMCTabTag     = '<AM_PreventionNeeds_ShowVMMCTab_V1>'
AM_PreventionNeedsCondomsTag         = '<AM_PreventionNeeds_Condoms_V1>'
AM_PreventionNeedsVMMCTag            = '<AM_PreventionNeeds_VMMC_V1>'
AM_PreventionNeedsKeyPopsTag         = '<AM_PreventionNeeds_KeyPops_V1>'
AM_PreventionNeedsPrEPTag            = '<AM_PreventionNeeds_PrEP_V3>'

# AM_PrEPParametersTag                  = '<AM_PrEPParameters_V1>'


AM_ChildARTAdjFactorTag                     = '<AM_ChildARTAdjFactor_V1>'
AM_ChildARTAdjFactorFlagTag                 = '<AM_ChildARTAdjFactorFlag_V1>'
AM_ChildPatsAllocToFromOtherRegionTag       = '<AM_ChildPatsAllocToFromOtherRegion_V1>'

AM_SubnatPrevalenceTag       = '<AM_SubnatPrevalence_V1>'
AM_SubnatARTCoverageTag      = '<AM_SubnatARTCoverage_V1>'
AM_SubnatCustomBaseYrFlagTag = '<AM_SubnatCustomBaseYrFlag_V1>'

AM_PMTCTPrEPParametersTag = '<AM_PMTCTPrEPParameters_V2>'
AM_PMTCTReceivingOralPrEPTag = '<AM_PMTCTReceivingOralPrEP_V1>'
AM_PMTCTReceivingInjectablePrEPTag = '<AM_PMTCTReceivingInjectablePrEP_V1>'
