IC_TP_CUSTOM_DEFINED_TARG_POP_MST_ID = 1
IC_TP_TOTAL_POPULATION_MST_ID = 2
IC_TP_FEMALES_REPROD_AGE_15_TO_49_MST_ID = 3
IC_TP_FEMALES_REPROD_AGE_IN_UNION_MST_ID = 4
IC_TP_PREGNANT_FEMALES_MST_ID = 5
IC_TP_LIVE_BIRTHS_MST_ID = 6
IC_TP_POP_UNDER_1_MST_ID = 7
IC_TP_ABORTIONS_MST_ID = 8
IC_MstFPUsers = 9
IC_TP_POP_1_TO_59_MONTHS_MST_ID = 10
IC_TP_POP_6_TO_59_MONTHS_MST_ID = 11
IC_TP_FEMALES_11_MST_ID = 12
IC_MstNumHouseholds = 13
IC_TP_POP_15_PLUS_MST_ID = 14
IC_TP_MALES_15_TO_49_MST_ID = 20
IC_TP_MALES_15_PLUS_MST_ID = 21
IC_TP_FEMALES_15_PLUS_MST_ID = 22
IC_TP_POP_15_TO_49_MST_ID = 23
IC_TP_POP_15_PLUS_NEED_ART_MST_ID = 25
IC_TP_NUM_CHILDREN_REC_ART_MST_ID = 29
IC_TP_NUM_CHILDREN_NEED_COTRIM_MST_ID = 30
IC_TP_NUM_CHILDREN_REC_COTRIM_MST_ID = 31
IC_TP_NUM_ADULTS_REC_ART_MST_ID = 33
IC_TP_POP_6_TO_23_MONTHS_MST_ID = 34
IC_TP_HIV_POS_POP_MST_ID = 35
IC_TP_POP_0_TO_23_MONTHS_MST_ID = 36
IC_TP_HIV_POS_CHILDREN_MST_ID = 37
IC_TP_HIV_POS_FEMALES_BREASTFEEDING_MST_ID = 38
IC_TP_POP_NEED_IO_MGMT_MST_ID = 39
IC_TP_NUM_POP_REC_ART_MST_ID = 40
IC_TP_POP_INIT_ART_1ST_6_MONTHS_MST_ID = 41
IC_TP_POP_6_TO_14_MST_ID = 42
IC_TP_YOUTH_SCHOOL_AGE_5_TO_15_MST_ID = 43
IC_TP_FEMALES_25_TO_65_MST_ID = 44
IC_TP_FEMALES_40_TO_65_MST_ID = 45
IC_TP_FEMALES_NEED_PMTCT_MST_ID = 46
IC_MstAdultMSM = 47
IC_MstFemaleSexWorkers = 48
IC_TP_POP_12_TO_17_MST_ID = 49
IC_MstInjectDrugUsers = 50
IC_TP_POP_HIV_POS_MST_ID = 51
IC_MstNumNewTBCasesExclRel = 52
IC_TP_POP_LOW_RISK_CVD_MST_ID = 53
IC_TP_POP_40_PLUS_MST_ID = 54
IC_TP_POP_5_TO_19_MST_ID = 55
IC_TP_POP_20_PLUS_MST_ID = 56
IC_TP_FEMALES_30_PLUS_MST_ID = 57
IC_TP_ALL_FEMALES_MST_ID = 58
IC_TP_AGE_GROUP_SET_1_MST_ID = 59
IC_TP_AGE_GROUP_SET_2_MST_ID = 60
IC_TP_FEMALES_25_TO_70_MST_ID = 61
IC_TP_FEMALES_40_TO_70_MST_ID = 62
IC_TP_FEMALES_BREAST_CANCER_MST_ID = 63
IC_TP_POP_0_TO_59_MONTHS_MST_ID = 64
IC_TP_DIRECT_ENTRY_MST_ID = 65
IC_MstFemalesRecBrstCncrTrtmnt = 66
IC_TP_POP_15_PLUS_LIVING_WITH_HIV_M_MST_ID = 67
IC_TP_POP_15_PLUS_LIVING_WITH_HIV_F_MST_ID = 68
IC_TP_POP_2_TO_12_MST_ID = 69
IC_TP_POP_12_TO_59_MONTHS_MST_ID = 70
IC_MstMaleSexWorkers = 71
IC_MstPopWithModSevDepression = 72
IC_MstPopWithPsychosis = 73
IC_MstPopWithEpilepsy = 74
IC_MstNumNewPulmTBCases = 79
IC_MstMDRAndXDRCases = 80
IC_TP_POP_0_TO_14_MST_ID = 92
IC_MstNumMalariaCases = 93
IC_MstPopWithMildDepression = 95
IC_MstPopWithADHD = 96
IC_MstPopWithConductDisorder = 97
IC_MstPopWithAlcohUseDisorder = 98
IC_MstPopWithBipolarDisorder = 99
IC_MstPopWithDepression = 100
IC_TP_INFANTS_SURV_PAST_1_MONTH_MST_ID = 101
IC_MstPopWithAnxiety = 102
IC_MstPopWithCOPD = 103
IC_MstPopWithAsthma = 104
IC_MstPopWithDiabetes = 105
IC_MstNumNewTBCases = 106
IC_MstNumNewPulmBactTBCases = 107
IC_MstNumNewPulmBactTBCasesPop = 108
IC_MstNumNewPulmBactTBCasesChildr = 109
IC_MstNumNewPulmBactHIVNegTBCases = 110
IC_MstNumNewPulmBactHIVNegTBCasesPop = 111
IC_MstNumNewPulmBactHIVNegTBCasesChildr = 112
IC_MstNumNewPulmBactHIVPosTBCases = 113
IC_MstNumNewPulmBactHIVPosTBCasesPop = 114
IC_MstNumNewPulmBactHIVPosTBCasesChildr = 115
IC_MstNumNewPulmClinTBCases = 116
IC_MstNumNewPulmClinHIVNegTBCases = 117
IC_MstNumNewPulmClinHIVPosTBCases = 118
IC_MstNumNewExPulmTBCases = 119
IC_MstNumNewExPulmHIVNegTBCases = 120
IC_MstNumNewExPulmHIVPosTBCases = 121
IC_MstNumRelTBCases = 122
IC_MstNumRelPulmTBCases = 123
IC_MstNumRelPulmBactTBCases = 124
IC_MstNumRelPulmBactHIVNegTBCases = 125
IC_MstNumRelPulmBactHIVPosTBCases = 126
IC_MstNumRelPulmClinTBCases = 127
IC_MstNumRelPulmClinHIVNegTBCases = 128
IC_MstNumRelPulmClinHIVPosTBCases = 129
IC_MstNumRelExPulmTBCases = 130
IC_MstNumRelExPulmHIVNegTBCases = 131
IC_MstNumRelExPulmHIVPosTBCases = 132
IC_MstNumNewTBCasesInclRel = 133
IC_MstNumNewNonMDR_TBCasesInclRel = 134
IC_MstNumNewNonMDR_TBCasesInclRelPop = 135
IC_MstNumNewNonMDR_TBCasesInclRelChildr = 136
IC_MstNumNewMDR_TBCasesInclRel = 137
IC_MstNumNewXDR_TBCasesInclRel = 138
IC_MstNumNewNonMDR_TBCasesExclRel = 139
IC_MstNumNewNonMDR_TBCasesExclRelPop = 140
IC_MstNumNewNonMDR_TBCasesExclRelChildr = 141
IC_MstNumNewMDR_TBCasesExclRel = 142
IC_MstNumNewXDR_TBCasesExclRel = 143
IC_MstNumPrTrTBCasesInclRel = 144
IC_MstNumPrTrNonMDR_TBCasesInclRel = 145
IC_MstNumPrTrNonMDR_TBCasesInclRelPop = 146
IC_MstNumPrTrNonMDR_TBCasesInclRelChildr = 147
IC_MstNumPrTrMDR_TBCasesInclRel = 148
IC_MstNumPrTrXDR_TBCasesInclRel = 149
IC_MstNumPrTrTBCasesExclRel = 150
IC_MstNumPrTrNonMDR_TBCasesExclRel = 151
IC_MstNumPrTrNonMDR_TBCasesExclRelPop = 152
IC_MstNumPrTrNonMDR_TBCasesExclRelChildr = 153
IC_MstNumPrTrMDR_TBCasesExclRel = 154
IC_MstNumPrTrXDR_TBCasesExclRel = 155
IC_MstNumNewRelTBCasesU15Yrs = 156
IC_MstNonXDRCases = 157
IC_MstXDRCases = 158
IC_MstNumTB_HIVCoInfCases = 159
IC_MstNumTB_HIVCoInfCasesNotOnART = 160
IC_MstNumTB_HIVCoInfCasesOnART = 161
IC_MstNumNewRelBactTBCases = 162
IC_MstNumNewRelPulmClinTBCases = 163
IC_MstNumNewRelExPulmTBCases = 164
IC_TP_NUM_FEMALES_30_TO_49_MST_ID = 165
IC_MstFemalesRecBreastCancerTreat = 166
IC_MstFemalesRecTreatPrecancLesCervCancer = 167
IC_MstFemalesPreCancerLesions = 168
IC_MstFemalesCervicalCancerDetS1 = 169
IC_MstFemalesCervicalCancerDetS2 = 170
IC_MstFemalesCervicalCancerDetS3 = 171
IC_MstFemalesCervicalCancerDetS4 = 172
IC_MstFemalesTreatCervCancerLast5Yrs = 173
IC_TP_POP_50_PLUS_MST_ID = 174
IC_MstPopRecColorectalCancerTreat = 175
IC_MstPopColorectalCancerDetS1 = 176
IC_MstPopColorectalCancerDetS2 = 177
IC_MstPopColorectalCancerDetS3 = 178
IC_MstPopColorectalCancerDetS4 = 179
IC_MstPopTreatColorectCancerLast5Yrs = 180
IC_MstFemalesBreastCancerDetS1 = 181
IC_MstFemalesBreastCancerDetS2 = 182
IC_MstFemalesBreastCancerDetS3 = 183
IC_MstFemalesBreastCancerDetS4 = 184
IC_MstFemalesDetectedBreastCancer = 185
IC_MstFemalesTreatBreastCancerLast5Yrs = 186
IC_TP_POP_10_TO_19_MST_ID = 187
IC_TP_FEMALES_10_TO_14_MST_ID = 188
IC_TP_FEMALES_15_TO_19_MST_ID = 189
IC_TP_POP_10_TO_49_MST_ID = 190
IC_TP_MALES_10_TO_49_MST_ID = 191
IC_TP_POP_10_PLUS_MST_ID = 192
IC_TP_POP_5_TO_14_MST_ID = 193
IC_TP_POP_1_TO_14_MST_ID = 194
IC_TP_POP_GT_6_MONTHS_MST_ID = 195
IC_TP_POP_3_TO_59_MONTHS_MST_ID = 196
IC_MstMalariaCases0t4 = 197
IC_MstMalariaCases5t14 = 198
IC_MstMalariaCases15Plus = 199
IC_MstMalariaCases5Plus = 200
IC_MstNumUncompMalariaCases = 201
IC_MstUncompMalariaCases0t4 = 202
IC_MstUncompMalariaCases5t14 = 203
IC_MstUncompMalariaCases15Plus = 204
IC_MstUncompMalariaCases5Plus = 205
IC_MstNumSevMalariaCases = 206
IC_MstSevMalariaCases0t4 = 207
IC_MstSevMalariaCases5t14 = 208
IC_MstSevMalariaCases15Plus = 209
IC_MstSevMalariaCases5Plus = 210
IC_TP_TOTAL_POP_EXCL_PREG_FEMALES_MST_ID = 211
IC_TP_PREGNANCIES_CARRIED_TO_TERM_MST_ID = 212
IC_MstPop6t23moFoodSec = 213
IC_MstPop6t23moFoodInsec = 214
IC_MstPopSBP_GT160_CVD_Risk_LT30 = 215
IC_MstPopSBP_GT140_CVD_Risk_LT30 = 216
IC_MstPopSBP_GT160_CVD_Risk_LT20 = 217
IC_MstPopSBP_GT140_CVD_Risk_LT20 = 218
IC_MstPopCholGT8_CVD_Risk_LT30 = 219
IC_MstPopCholGT6_CVD_Risk_LT30 = 220
IC_MstPopCholGT8_CVD_Risk_LT20 = 221
IC_MstPopCholGT6_CVD_Risk_LT20 = 222
IC_MstPopCVD_DiabRisk20t30 = 223
IC_MstPopCVD_DiabRiskGT30 = 224
IC_MstPopStroke_A_IHD_A = 225
IC_MstPopIHD_PA = 226
IC_MstPopStroke_PA_StrokeIHD_PA = 227
IC_MstPopStrokeIHD_A_PA_5Combo = 228
IC_TP_POP_1_TO_4_MST_ID = 229
IC_MstSputumSmearMicr_DAT = 230
IC_MstGeneXpert_DAT = 231
IC_MstChestXRay_DAT = 232
IC_MstCultTests_DAT = 233
IC_MstNumScreenedThroughPathway_DAT = 234
IC_MstActiveCaseFindingHHs = 235
IC_MstActiveCaseFindingHRGs = 236
IC_MstNumHHContEval = 237
IC_MstNumPersHRGsEval = 238
IC_MstNumNewARTPatEval = 239
IC_MstNumExistARTPatEval = 240
IC_MstTBNegNewAdultARTPat = 241
IC_MstTBNegExistAdultARTPat = 242
IC_MstTBNegNewChildARTPat = 243
IC_MstTBNegExistChildARTPat = 244
IC_MstAdultHHContacts = 245
IC_MstChildHHContacts = 246
IC_MstAdultHRGs = 247
IC_MstPopHRGs = 248
IC_MstNumChildHHContTestedLTBI = 249
IC_MstNumAdultHHContTestedLTBI = 250
IC_MstNumChildHRGsTestedLTBI = 251
IC_MstNumAdultHRGsTestedLTBI = 252
IC_MstNumNewChildARTPatTestedLTBI = 253
IC_MstNumNewAdultARTPatTestedLTBI = 254
IC_MstNumExistChildARTPatTestedLTBI = 255
IC_MstNumExistAdultARTPatTestedLTBI = 256
IC_MstPopNumToScreenActiveTBAllAges = 257
IC_MstPopNumToScreenActiveTBChildren = 258
IC_MstPopNumToScreenActiveTBAdults = 259
IC_MstPopNumScreenedActiveTBAllAges = 260
IC_MstPopNumScreenedActiveTBChildren = 261
IC_MstPopNumScreenedActiveTBAdults = 262
IC_MstPopNumLinkedActiveTBAllAges = 263
IC_MstPopNumLinkedActiveTBChildren = 264
IC_MstPopNumLinkedActiveTBAdults = 265
IC_TP_FEMALES_15_TO_24_MST_ID = 266
IC_TP_POP_15_TO_24_MST_ID = 267
IC_TP_HH_CONTACTS_PULM_TB_0_TO_14_ELIG_SCR_MST_ID = 268
IC_TP_HH_CONTACTS_PULM_TB_0_TO_4_ELIG_SCR_MST_ID = 269
IC_TP_HH_CONTACTS_PULM_TB_5_TO_14_ELIG_SCR_MST_ID = 270
IC_TP_HH_CONTACTS_PULM_15_PLUS_ELIG_SCR_MST_ID = 271
IC_TP_PRISONERS_PULM_15_PLUS_ELIG_SCR_MST_ID = 272
IC_TP_MINERS_SILICA_PULM_TB_15_PLUS_ELIG_SCR_MST_ID = 273
IC_TP_POP_UNTR_FIBR_LESIONS_PULM_TB_15_PLUS_ELIG_SCR_MST_ID = 274
IC_TP_POP_RISK_FACTORS_GT_PT_1_PREV_PULM_15_PLUS_ELIG_SCR_MST_ID = 275
IC_TP_POP_RISK_FACTORS_LIMIT_HLTH_CARE_PULM_15_PLUS_ELIG_SCR_MST_ID = 276
IC_TP_POP_GT_PT_5_PERC_PREV_PULM_TB_15_PLUS_ELIG_SCR_MST_ID = 277
IC_TP_HH_CONTACTS_PULM_TB_5_TO_14_ELIG_EVAL_MST_ID = 278
IC_TP_HH_CONTACTS_PULM_15_PLUS_ELIG_EVAL_MST_ID = 279
IC_TP_HH_CONTACTS_PULM_TB_0_TO_4_TESTED_TB_MST_ID = 280
IC_TP_PLHIV_PULM_TB_ART_NOT_SERIOUS_10_PLUS_ELIG_SCR_MST_ID = 281
IC_TP_PULM_TB_HIV_POS_NOT_ON_ART_10_PLUS_ELIG_SCR_MST_ID = 282
IC_TP_PLHIV_PULM_TB_ART_SERIOUS_10_PLUS_ELIG_SCR_MST_ID = 283
IC_TP_CLHIV_PULM_TB_ON_ART_NOT_SERIOUS_0_TO_9_ELIG_SCR_MST_ID = 284
IC_TP_PREV_TB_INFECT_15_PLUS_DRUG_SUSC_STRAINS_MST_ID = 285
IC_TP_PREV_TB_INFECT_0_TO_14_DRUG_SUSC_STRAINS_MST_ID = 286
IC_TP_PREV_TB_INFECT_DRUG_RESIST_STRAINS_MST_ID = 288
IC_TP_PULM_TB_HIV_NEG_15_PLUS_CLIN_ASSESSED_MST_ID = 289
IC_TP_PULM_TB_HIV_NEG_0_TO_14_CLIN_ASSESSED_MST_ID = 290
IC_TP_EXTRAPULM_TB_HIV_NEG_15_PLUS_CLIN_ASSESSED_MST_ID = 291
IC_TP_EXTRAPULM_TB_HIV_NEG_0_TO_14_PLUS_CLIN_ASSESSED_MST_ID = 292
IC_TP_PULM_TB_15_PLUS_REF_DIAG_EVAL_MST_ID = 293
IC_TP_EXTRAPULM_TB_15_PLUS_REF_DIAG_EVAL_MST_ID = 294
IC_TP_PULM_TB_0_TO_14_REF_DIAG_EVAL_MST_ID = 295
IC_TP_EXTRAPULM_TB_0_TO_14_REF_DIAG_EVAL_MST_ID = 296
IC_TP_HRGS_PULM_TB_15_PLUS_REF_DIAG_EVAL_MST_ID = 297
IC_TP_HH_CONTACTS_PULM_TB_0_TO_14_REF_DIAG_EVAL_MST_ID = 298
IC_TP_PLHIV_PULM_TB_ON_ART_NOT_SERIOUS_ILL_15_PLUS_REF_DIAG_EVAL_MST_ID = 299
IC_TP_PLHIV_PULM_TB_ON_ART_SERIOUS_ILL_15_PLUS_REF_DIAG_EVAL_MST_ID = 300
IC_TP_PLHIV_PULM_TB_ON_ART_NOT_SERIOUS_ILL_0_TO_14_PLUS_REF_DIAG_EVAL_MST_ID = 301
IC_TP_PLHIV_PULM_TB_ON_ART_SERIOUS_ILL_0_TO_14_PLUS_REF_DIAG_EVAL_MST_ID = 302
IC_TP_PULM_TB_TO_BE_TESTED_RIFAMP_ISON_RESIST_MST_ID = 303
IC_TP_EXTRAPULM_TB_TO_BE_TESTED_RIFAMP_ISON_RESIST_MST_ID = 304
IC_TP_PULM_TB_TO_BE_TESTED_ISON_RESIST_RIFAMP_SENS_MST_ID = 305
IC_TP_EXTRAPULM_TB_TO_BE_TESTED_ISON_RESIST_RIFAMP_SENS_MST_ID = 306
IC_TP_PULM_TB_TO_BE_TESTED_FLUOR_RESIST_RIFAMP_RESIST_MST_ID = 307
IC_TP_TO_BE_TESTED_FLUOR_RESIST_RIFAMP_RESIST_MST_ID = 308
IC_TP_TO_BE_TESTED_BEDAQ_RESIST_RIFAMP_RESIST_MST_ID = 309
IC_TP_PULM_TB_TO_BE_TESTED_BEDAQ_RESIST_FLUOR_RESIST_MST_ID = 310
IC_TP_EXTRAPULM_TB_TO_BE_TESTED_BEDAQ_RESIST_FLUOR_RESIST_MST_ID = 311
IC_TP_TO_BE_TESTED_BEDAQ_RESIST_FLUOR_RESIST_MST_ID = 312
IC_TP_PULM_TB_TO_BE_TESTED_LINEZ_RESIST_RIFAMP_RESIST_MST_ID = 313
IC_TP_EXTRAPULM_TB_TO_BE_TESTED_LINEZ_RESIST_RIFAMP_RESIST_MST_ID = 314
IC_TP_TO_BE_TESTED_LINEZ_RESIST_RIFAMP_RESIST_MST_ID = 315
IC_TP_PULM_TB_TO_BE_TESTED_LINEZ_RESIST_FLUOR_RESIST_MST_ID = 316
IC_TP_EXTRAPULM_TB_TO_BE_TESTED_LINEZ_RESIST_FLUOR_RESIST_MST_ID = 317
IC_TP_TO_BE_TESTED_LINEZ_RESIST_FLUOR_RESIST_MST_ID = 318
IC_TP_TO_BE_TESTED_AMIK_RESIST_MST_ID = 319
IC_TP_TO_BE_TESTED_ETHIO_RESIST_MST_ID = 320
IC_TP_TO_BE_TESTED_PYRAZ_RESIST_MST_ID = 321
IC_TP_15_PLUS_NO_SEV_TB_RIFAMP_ISON_SENS_MST_ID = 322
IC_TP_0_14_PLUS_NO_SEV_TB_RIFAMP_ISON_SENS_MST_ID = 323
IC_TP_DRUG_SUSC_TB_15_PLUS_MENING_PERICARD_MST_ID = 324
IC_TP_DRUG_SUSC_TB_0_TO_14_PLUS_MENING_PERICARD_MST_ID = 325
IC_TP_15_PLUS_RIFAMP_SENS_ISON_RESIST_MST_ID = 326
IC_TP_0_TO_14_PLUS_RIFAMP_SENS_ISON_RESIST_MST_ID = 327
IC_TP_15_PLUS_RIFAMP_RESIST_FLUOR_SENS_MST_ID = 328
IC_TP_0_TO_14_PLUS_RIFAMP_RESIST_FLUOR_SENS_MST_ID = 329
IC_TP_15_PLUS_RIFAMP_RESIST_FLUOR_RESIST_PRE_XDR_MST_ID = 330
IC_TP_0_TO_14_PLUS_RIFAMP_RESIST_FLUOR_RESIST_PRE_XDR_MST_ID = 331
IC_TP_15_PLUS_PRE_XDR_RESIST_ONE_OF_MST_ID = 332
IC_TP_0_TO_14_PLUS_PRE_XDR_RESIST_ONE_OF_MST_ID = 333
IC_TP_PALL_CARE_TREAT_EXHASUTED_MST_ID = 334
IC_TP_TB_INFECT_PREV_0_TO_14_RECEIV_BCG_IMMUNIZ_MST_ID = 335
IC_TP_HIV_TB_COINFECTION_MST_ID = 336
IC_TP_HIV_TB_COINFECTION_CHILDREN_MST_ID = 337
IC_TP_NUM_TESTED_RESIST_BEDAQ_LINEZ_LEVO_MOXI_MST_ID = 338
IC_TP_TESTING_RIFAMP_RESIST_MST_ID = 339
IC_TP_TESTING_ISON_RESIST_RIFAMP_SENS_CASES_MST_ID = 340
IC_TP_POP_0_TO_11_MONTHS_MST_ID = 341
IC_TP_PROV_INIT_ALL_HRGS_NUM_ELIG_EVAL_TB_INF_MST_ID = 342
IC_TP_HH_CONTACTS_0_TO_4_ELIG_EVAL_MST_ID = 343
IC_TP_PAT_6_MO_ISON_RESIST_SHORTER_SEC_LINE_15_PLUS_MST_ID = 344
IC_TP_PAT_6_MO_ISON_RESIST_SHORTER_SEC_LINE_0_TO_14_MST_ID = 345
IC_TP_PAT_LONGER_REG_MDR_RR_TB_XDR_MST_ID = 346
IC_TP_PAT_6_MO_ISON_RESIST_SHORTER_SEC_LINE_MST_ID = 347
IC_TP_NUM_NEED_FIRST_LINE_TREAT_15_PLUS_MST_ID = 348
IC_TP_NUM_NEED_FIRST_LINE_TREAT_0_TO_14_MST_ID = 349
IC_TP_NUM_NEED_FIRST_LINE_TREAT_ALL_AGES_MST_ID = 350
IC_TP_NUM_NEED_SECOND_LINE_TREAT_0_TO_14_MST_ID = 351
IC_TP_NUM_NEED_SECOND_LINE_TREAT_15_PLUS_MST_ID = 352
IC_TP_NUM_REQ_LUNG_RESECT_SURGERY_15_PLUS_MST_ID = 353
IC_TP_NUM_REQ_LUNG_RESECT_SURGERY_0_TO_14_MST_ID = 354
IC_TP_PULM_EXTRAPULM_TB_ADULTS_15_P_PRES_RIFAMP_ISON_SENS_MST_ID = 355
IC_TP_PULM_EXTRAPULM_TB_CHILD_0_14_PRES_RIFAMP_ISON_SENS_MST_ID = 356
IC_TP_PULM_EXTRAPULM_TB_CHILD_0_14_NOT_SEV_PRES_RIFAMP_ISON_SENS_MST_ID = 357
IC_TP_HIV_POS_PREGNANT_WOMEN_MST_ID = 358
IC_TP_POP_0_TO_4_MST_ID = 359
IC_TP_NUM_REQ_LUNG_RESECT_SURGERY_MST_ID = 360
IC_TP_CLHIV_PULM_TB_ON_ART_INPAT_0_TO_9_ELIG_SCR_MST_ID = 361
IC_TP_15_PLUS_CLIN_ASSESSED_MST_ID = 362
IC_TP_0_TO_14_CLIN_ASSESSED_MST_ID = 363
IC_TP_NUM_NEED_SECOND_LINE_TREAT_ALL_AGES_MST_ID = 364
