FS_ScenarioNameTag = '<FS_ScenarioNames_V1>'
FS_MacroGDPTag = '<FS_MacroGDP_V1>'
FS_MacroExpenditureTag = '<FS_MacroExpenditure_V1>'
FS_MacroTaxesTag = '<FS_MacroTaxes_V1>'
FS_MacroNonTaxesTag = '<FS_MacroNonTaxes_V1>'
FS_MacroGrantsTag = '<FS_MacroGrants_V1>'
FS_MacroOtherRevenueTag = '<FS_MacroOtherRevenue_V1>'
FS_GGHEApproachTag = '<FS_GGHEApproach_V1>'
FS_GGHEDomesticTag = '<FS_GGHEDomestic_V1>'
FS_GGHEExternalTag = '<FS_GGHEExternal_V1>'
FS_HealthExpCoeffTag = '<FS_HealthExpCoeff_V1>'
FS_PercOfGGETag = '<FS_PercOfGGE_V1>'
FS_ConstantPricesTag = '<FS_ConstantPrices_V1>'
FS_OutOfPocketTag = '<FS_OutOfPocket_V1>'
FS_PrePaidRiskPlansTag = '<FS_PrePaidRiskPlans_V1>'
FS_GrowthOptionTag = '<FS_GrowthOption_V1>'
FS_PrivateHealthCoeffTag = '<FS_PrivateHealthCoeff_V1>'
FS_HealthExpOtherTag = '<FS_HealthExpOther_V1>'