IC_TI_IV_BCG_Vacc_MST_ID = '49'
IC_TI_IV_ScreenProvInitPLHIV_GTE10YrsOnART_NotIll_MST_ID = '641'
IC_TI_IV_ScreenProvInitPLHIV_Children0t9_MST_ID = '551'
IC_TI_IV_ScreenProvInitPLHIV_GTE10YrsInpat_MST_ID = '550'
IC_TI_IV_ScreenProvInitPLHIV_Children0t9Inpat_MST_ID = '674'
IC_TI_IV_ScreenProvInitHHAdults15Plus_MST_ID = '555'
IC_TI_IV_ScreenProvInitHHChildren0t14_MST_ID = '552'
IC_TI_IV_ScreenProvInitHHChildren0t4_MST_ID = '553'
IC_TI_IV_ScreenProvInitHHChildren5t14_MST_ID = '554'
IC_TI_IV_ScreenProvInitPrisoners_MST_ID = '556'
IC_TI_IV_ScreenProvInitMiners_MST_ID = '557'
IC_TI_IV_ScreenProvInitFibroticLesions_MST_ID = '558'
IC_TI_IV_ScreenProvInitRiskFactorsGTE_P1PercTBPrev_MST_ID = '559'
IC_TI_IV_ScreenProvInitRiskFactorsLmtdHlthCare_MST_ID = '560'
IC_TI_IV_ScreenProvInitGenPop_MST_ID = '561'
IC_TI_IV_TBCaseFindPatInitAdults_MST_ID = '675'
IC_TI_IV_TBCaseFindPatInitChildren_MST_ID = '676'
IC_TI_IV_DiagPatInitPulmTBAdults_MST_ID = '574'
IC_TI_IV_DiagPatInitPulmTBChildren_MST_ID = '576'
IC_TI_IV_DiagPatInitExtraPulmTBAdults_MST_ID = '575'
IC_TI_IV_DiagPatInitExtraPulmTBChildren_MST_ID = '577'
IC_TI_IV_DiagProvInitPulmTB_PLHIV_Outpat_MST_ID = '580'
IC_TI_IV_DiagProvInitPulmTB_PLHIV_Inpat_MST_ID = '581'
IC_TI_IV_DiagProvInitPulmTB_PLHIV_ChildrenOutpat_MST_ID = '582'
IC_TI_IV_DiagProvInitPulmTB_PLHIV_ChildrenInpat_MST_ID = '583'
IC_TI_IV_DiagProvInitPulmTB_HHChildren_MST_ID = '579'
IC_TI_IV_DiagProvInitPulmTBAllHRGsAdults_MST_ID = '578'
IC_TI_IV_RifampIsonResistTest_MST_ID = '584'
IC_TI_IV_IsonResistTestRifampSensCases_MST_ID = '585'
IC_TI_IV_FluoroqResistTestRifampResistCases_MST_ID = '586'
IC_TI_IV_RESIST_TEST_BEDAQ_LINEZ_LEVO_MOXI_MST_ID = '649'
IC_TI_IV_TreatDrugSuscTBRifampIsonSensAdults_MST_ID = '597'
IC_TI_IV_TreatDrugSuscTBRifampIsonSensChildren0t14_MST_ID = '598'
IC_TI_IV_TreatDrugSuscTBRifampIsonSensChildren3MoTo16_MST_ID = '599'
IC_TI_IV_TreatTBMeningPericardAdults_MST_ID = '600'
IC_TI_IV_TreatDrugSuscTBMeningPericardChildren_MST_ID = '601'
IC_TI_IV_NonMedTreatSuppPatFirstLine_MST_ID = '677'
IC_TI_IV_TreatDrugResistTBRifampSensIsonResistAdults_MST_ID = '602'
IC_TI_IV_TreatDrugResistTBRifampSensIsonResistChildren_MST_ID = '603'
IC_TI_IV_BpalMOralBedaqRegDrugResistTBAdults_MST_ID = '604'
IC_TI_IV_OralBedaqRegDrugResistTBChildren_MST_ID = '605'
IC_TI_IV_BPalRegDrugResistTBAdults_MST_ID = '606'
IC_TI_IV_LongerRegDrugResistTBTreatAdults_MST_ID = '607'
IC_TI_IV_LongerRegDrugResistTBTreatChildren_MST_ID = '608'
IC_TI_IV_TreatDrugResistTB_XDR_Adults_MST_ID = '609'
IC_TI_IV_TreatDrugResistTB_XDR_Children_MST_ID = '610'
IC_TI_IV_NonMedTreatSuppPatSecLine_MST_ID = '678'
IC_TI_IV_TestLatentTB_HHContactAdults15Plus_MST_ID = '563'
IC_TI_IV_TestLatentTB_HHContactChildren5t14_MST_ID = '562'
IC_TI_IV_TestLatentTB_HHContactChildren0t4_MST_ID = '564'
IC_TI_IV_TestLatentTBOtherHRGsAdults15Plus_MST_ID = '565'
IC_TI_IV_TB_ORAL_PREV_MED_ADULTS_15_PLUS_MST_ID = '650'
IC_TI_IV_TB_ORAL_PREV_MED_CHILDREN_0_14_MST_ID = '567'
IC_TI_IV_TBOralPrevMedWRifampDrugResist_MST_ID = '569'
IC_TI_IV_LungResectionSurgery_MST_ID = '673'
IC_TI_IV_PalliativeCare_MST_ID = '625'
