IH_VERSION_TAG_V1                                  = '<OH_Version_V1>'
IH_HLTH_SERV_ANAL_MODE_MST_ID_TAG_V1               = '<OH_HealthServiceAnalysisModeMstID_V1>'
IH_PROG_AREA_DELIV_CHAN_FILTER_MST_ID_TAG_V1       = '<OH_ProgrammeAreaDeliveryChannelFilterMstID_V1>'
IH_MAX_CUST_INTERV_MST_ID_TAG_V1                   = '<OH_MaxCustomInterventionMstID_V1>'     
IH_MOH_BUDGET_TAG_V1                               = '<OH_MOHBudget_V1>'               
IH_DATA_CHANGED_TAG_V1                             = '<OH_DataChanged_V1>'
IH_PROJ_VALID_TAG_V1                               = '<OH_ProjectionValid_V1>'
IH_USING_ADOL_STRATA_MODE_TAG_V1                   = '<OH_UsingAdolescentStrataMode_V1>'
IH_USING_DIS_SPEC_COST_MODE_TAG_V1                 = '<OH_UsingDiseaseSpecificCostingMode_V1>'
IH_USING_PHC_MODE_TAG_V1                           = '<OH_UsingPrimaryHealthCareMode_V1>'
IH_USING_DEF_MED_STAFF_TYPES_TAG_V1                = '<OH_UsingDefaultMedicalStaffTypes_V1>' 
IH_USING_DEF_FAC_TYPES_TAG_V1                      = '<OH_UsingDefaultFacilityTypes_V1>' 
IH_USING_MOH_BUDGET_RES_TAG_V1                     = '<OH_UsingMOHBudgetInResults_V1>' 
IH_USING_HPV_PROG_AREA_TAG_V1                      = '<OH_UsingHPVProgrammeArea_V1>'
IH_USING_WORK_HLTH_PROG_AREA_TAG_V1                = '<OH_UsingWorkersHealthProgrammeArea_V1>'
IH_USING_TP_FROM_TIME_TAG_V1                       = '<OH_UsingTargetPopulationsFromTIME_V1>'
IH_USING_TB_IMPACT_CALCS_TP_TAG_V1                 = '<OH_UsingTBImpactCalcsForTargetPopulations_V1>'
IH_USING_TB_DAT_TP_TAG_V1                          = '<OH_UsingTB_DAT_TargetPopulations_V1>'
IH_USING_LOCAL_CURR_TAG_V1                         = '<OH_UsingLocalCurrency_V1>'
IH_FILE_NAME_TAG_V1                                = '<OH_FileName_V1>'                        
IH_PROJ_VALID_DATE_TAG_V1                          = '<OH_ProjectionValidDate_V1>'                      
IH_PROG_AREA_RECORDS_TAG_V1                        = '<OH_ProgrammeAreaRecords_V1>'            
IH_DELIV_CHAN_RECORDS_TAG_V1                       = '<OH_DeliveryChannelRecords_V1>'         
IH_NAT_PROG_AREA_RECORDS_TAG_V1                    = '<OH_NationalProgrammeRecords_V1>'     
IH_AUDIT_RECORDS_TAG_V1                            = '<OH_AuditRecords_V1>'         
IH_HEALTH_SYS_ADMIN_UNIT_RECORDS_TAG               = '<OH_HealthSysAdminUnitRecords_V1>'
IH_LOCKED_AREA_RECORDS_TAG_V1                      = '<OH_LockedAreaRecords_V1>' 
IH_HPV_PARAM_RECORDS_TAG_V1                        = '<OH_HPV_ParamRecords_V1>'
IH_COLD_CHAIN_TAG_V1                               = '<OH_ColdChain_V1>'
IH_PERC_PROG_MGMT_COSTS_PHC_VIS_TAG_V1             = '<OH_PercProgOrMgmtCostsPHC_Visited_V1>'    
IH_PERC_PROG_MGMT_COSTS_PHC_PROG_AREA_TAG_V1       = '<OH_PercProgOrMgmtCostsPHC_ProgArea_V1>'
IH_PERC_PROG_MGMT_COSTS_PHC_HLTH_SYS_TAG_V1        = '<OH_PercProgOrMgmtCostsPHC_HealthSys_V1>'
IH_PERC_PROG_MGMT_COSTS_PHC_DELIV_CHAN_TAG_V1      = '<OH_PercProgOrMgmtCostsPHC_DelivChan_V1>'
IH_PERC_PROG_MGMT_COSTS_PHC_NAT_PROG_TAG_V1        = '<OH_PercProgOrMgmtCostsPHC_NatProg_V1>'
IH_PERC_PROG_MGMT_COSTS_PHC_DELIV_CHAN_PACK_TAG_V1 = '<OH_PercProgOrMgmtCostsPHC_DelivChanPack_V1>'
IH_HR_FACTOR_PHC_TAG_V1                            = '<OH_HRFactorPHC_V1>'    
IH_PERC_FAC_TYPE_PHC_TAG_V1                        = '<OH_PercFacTypePHC_V1>'     
IH_LG_PERC_DRUG_SUPP_COSTS_PHC_TAG_V1              = '<OH_LGPercDrugSuppCostsPHC_V1>'   
IH_SHOW_INACTIVE_PROG_AREAS_EXIST_INTERV_V1        = '<OH_ShowInactiveProgAreasExistIntervs_V1>'
IH_SHOW_INACTIVE_PROG_AREAS_EXIST_DRUG_SUPP_V1     = '<OH_ShowInactiveProgAreasExistDrugsSupplies_V1>'
IH_ENTER_UNIT_COSTS_ALL_YEARS_DRUG_SUPP_V1         = '<OH_EnterUnitCostsAllYearsDrugsSupplies_V1>'

# TB Costing

IH_PROG_AREA_RECORDS_IHT_ID_INFO_ONLY_TAG_V1       = '<OH_ProgrammeAreaRecordsIHT_IDInfoOnly_V1>'

# Results 

IH_RES_STAFF_CAP_UTILIZATION_STATIC_TAG_V1          = '<OH_ResStaffCapUtilizationStatic_V1>' 
IH_RES_STAFF_CAP_UTILIZATION_DYNAMIC_TAG_V1         = '<OH_ResStaffCapUtilizationDynamic_V1>' 