# Spectrum modules

# IHT modules
from SpectrumCommon.Const.IH.IHModVarFields import *
from SpectrumCommon.Const.PC.PCModVarFields import *
from SpectrumCommon.Const.IC.ICModVarFields import *
from SpectrumCommon.Const.IS.ISModVarFields import *
from SpectrumCommon.Const.HW.HWModVarFields import *
from SpectrumCommon.Const.LG.LGModVarFields import *
from SpectrumCommon.Const.BG.BGModVarFields import *

#############################    IH    ##########################

TR_P_PROG_AREA_ID = IH_F_PROG_AREA_ID
TR_P_SUBGROUP_ID = IH_F_SUBGROUP_ID
TR_P_DELIV_CHAN_ID = IH_F_DELIV_CHAN_ID
TR_P_HEALTH_SYS_ADMIN_UNIT_ID = IH_F_HEALTH_SYS_ADMIN_UNIT_ID

#############################    PC    ##########################

TR_P_COST_CAT_ID = PC_F_COST_CAT_ID
TR_P_COST_INPUT_ID = PC_F_COST_INPUT_ID
TR_P_AREA_ID = PC_F_AREA_ID
TR_P_AREA_TYPE_ID = PC_F_AREA_TYPE_ID
TR_P_COSTING_SECT_ID = PC_F_COSTING_SECT_ID
TR_P_COSTING_SUBSECT_ID = PC_F_COSTING_SUBSECT_ID
TR_P_ACT_ID = PC_F_ACT_ID

#############################    IC    ##########################

TR_P_INTERV_ID = IC_F_INTERV_ID
TR_P_DRUG_SUPPLY_TYPE_MST_ID = IC_F_DRUG_SUPPLY_TYPE_MST_ID
TR_P_DRUG_SUPPLY_ID = IC_F_DRUG_SUPPLY_ID
TR_P_TREAT_INPUT_ID = IC_F_TREAT_INPUT_ID
TR_P_TREAT_INPUT_GROUP_ID = IC_F_TREAT_INPUT_GROUP_ID
TR_P_APPLIC_PROG_AREA_IDS = IC_F_APPLIC_PROG_AREA_IDS
TR_P_CUSTOM_STAFF_TYPE = IC_F_CUSTOM_STAFF_TYPE

#############################    IS    ##########################

TR_P_FACILITY_TYPE_ID = IS_F_FACILITY_TYPE_ID
TR_P_FACILITY_MED_EQUIP_GROUP_ID = IS_F_FACILITY_MED_EQUIP_GROUP_ID
TR_P_FACILITY_EQUIP_ID = IS_F_FACILITY_EQUIP_ID
TR_P_ICT_EQUIP_ID = IS_F_ICT_EQUIP_ID
TR_P_VEHICLE_TYPE_ID = IS_F_VEHICLE_TYPE_ID
TR_P_FACILITY_SUPP_TYPE_MST_ID = IS_FACIL_SUPP_TYPE_MST_ID
TR_P_DEF_FACILITY_TYPE_MAP_MST_ID = IS_FACIL_DEFAULT_MAP_MST_ID

#############################    HW    ##########################

TR_P_STAFF_TYPE_ID = HW_F_STAFF_TYPE_ID
TR_P_ATTR_TYPE_ID = HW_F_ATTR_TYPE_ID
TR_P_RETENT_INCENT_ID = HW_F_RETENT_INCENT_ID
TR_P_STAFF_DIVISION_MST_ID = HW_STAFF_DIVISION_MST_ID
TR_P_STATIC_STAFF_TYPE_MAP_MST_ID = HW_STAFF_STATIC_MAP_MST_ID

#############################   BG   ##############################

TR_P_BUDGET_ID = BG_F_BUDGET_ID
TR_P_MOD_ID = BG_F_MOD_ID
TR_P_BUDGET_CAT_ID = BG_F_BUDGET_CAT_ID
TR_P_FUND_FW_ID = BG_F_FUND_FW_ID
TR_P_FUND_SOURCE_ID = BG_F_FUND_SOURCE_ID
TR_P_IND_TYPE_ID = BG_F_IND_TYPE_ID
TR_P_IND_ID = BG_F_IND_ID
TR_P_IS_AGGREGATE = BG_F_IS_AGGREGATE
TR_P_TARGET_ID = BG_QUICK_MAP_TARGET_ID
TR_P_ON = BG_QUICK_MAP_ON
TR_P_STAFF_LEVEL_ID = BG_F_STAFF_LEVEL_ID_HW
TR_P_COMPENS_TYPE_ID = BG_F_COMPENS_TYPE_ID_HW
