FP_ActiveMethodsTag                = '<FP_ActiveMethods_V1>'
# FP_DataChangedTag                  = '<FP_DataChanged_V1>' 
# FP_ProjectionValidTag              = '<FP_ProjectionValid_V1>'
# FP_ProjectionValidDateTag          = '<FP_ProjectionValidDate_V1>'
FP_AgeGroupOptionTag               = '<FP_AgeGroupOption_V1>'
FP_GoalTag                         = '<FP_Goal_V1>'
FP_AbortionOptionTag               = '<FP_AbortionOption_V1>'
FP_NeedOptionTag                   = '<FP_NeedOption_V1>'
FP_SourcesTag                      = '<FP_Sources_V1>'
FP_MethodNameTag                   = '<FP_MethodName_V1>'
FP_NumSourcesTag                   = '<FP_NumSources_V1>'
FP_NumNeedsTag                     = '<FP_NumNeeds_V1>'
FP_NumCustomMethodsTag             = '<FP_NumCustomMethods_V1>'
FP_PregnancyRateTag                = '<FP_PregnancyRate_V1>'
FP_PercentPregWithMiscarriageTag   = '<FP_PercentPregWithMiscarriage_V1>'
FP_PropUnintendedPregEndInAbortTag = '<FP_PropUnintendedPregEndInAbort_V1>'
FP_PropUnsafeAbortTag              = '<FP_PropUnsafeAbort_V1>'
FP_MortalityRateSafeAbortTag       = '<FP_MortalityRateSafeAbort_V1>'
FP_MortalityRateUnsafeAbortTag     = '<FP_MortalityRateUnsafeAbort_V1>'
FP_PropPregWantedLaterTag          = '<FP_PropPregWantedLater_V1>'
FP_PropPregUnwantedTag             = '<FP_PropPregUnwanted_V1>'
FP_MiscarriagePercentTag           = '<FP_MiscarriagePercent_V1>'
FP_CalcMethOptionTag               = '<FP_CalcMethOption_V1>'
FP_MethodMixTag                    = '<FP_MethodMix_V1>'
FP_MethodPermTermTag               = '<FP_MethodPermTerm_V1>'
FP_MethodLongTermTag               = '<FP_MethodLongTerm_V1>'
FP_MethodshortTermTag              = '<FP_MethodshortTerm_V1>'
FP_EffectivenessTag                = '<FP_Effectiveness_V1>'
FP_EffectivenessMetaTag            = '<FP_Effectiveness_Meta_V1>'
FP_UnitsPerCYPTag                  = '<FP_UnitsPerCYP_V1>'
FP_AverageAgeTag                   = '<FP_AverageAge_V1>'
FP_DurationOfUseTag                = '<FP_DurationOfUse_V1>'
FP_SourceMixTag                    = '<FP_SourceMix_V1>'
FP_CostPerUATag                    = '<FP_CostPerUA_V1>'
FP_FeesTag                         = '<FP_Fees_V1>'
FP_GrossCostTag                    = '<FP_GrossCost_V1>'
FP_RevenueTag                      = '<FP_Revenue_V1>'
FP_NetCostTag                      = '<FP_NetCost_V1>'
FP_CommoditiesTag                  = '<FP_Commodities_V1>'
FP_PercentInUnionTag               = '<FP_PercentInUnion_V1>'
FP_PPITag                          = '<FP_PPI_V1>'
FP_TARTag                          = '<FP_TAR_V1>'
FP_AbortionPercentTag              = '<FP_AbortionPercent_V1>'
FP_SterilityTag                    = '<FP_Sterility_V1>'
FP_MarriageIndexTag                = '<FP_MarriageIndex_V1>'
FP_PPIIndexTag                     = '<FP_PPIIndex_V1>'
FP_AbortionIndexTag                = '<FP_AbortionIndex_V1>'
FP_SterilityIndexTag               = '<FP_SterilityIndex_V1>'
FP_PrevalenceIndexTag              = '<FP_PrevalenceIndex_V1>'
FP_TFRTag                          = '<FP_TFR_V1>'
FP_TFRMetaTag                      = '<FP_TFR_Meta_V1>'
FP_WRATag                          = '<FP_WRA_V1>'
FP_MWRATag                         = '<FP_MWRA_V1>'
FP_MortalityRateTag                = '<FP_MortalityRate_V1>'
FP_BirthsTag                       = '<FP_Births_V1>'
FP_BirthsAvertedTag                = '<FP_BirthsAverted_V1>'
FP_AbortionsTag                    = '<FP_Abortions_V1>'
FP_AverageEffectivenessTag         = '<FP_AverageEffectiveness_V1>'
FP_PrevalenceTag                   = '<FP_Prevalence_V1>'
FP_MPrevalenceTag                  = '<FP_MPrevalence_V1>'
FP_AddMdrnUsersPrevTag             = '<FP_AddMdrnUsersPrev_V1>'
FP_UnmetNeedTag                    = '<FP_UnmetNeed_V1>'
FP_UnmetNeedReductionTag           = '<FP_UnmetNeedReduction_V1>'
FP_WantedTFRTag                    = '<FP_WantedTFR_V1>'
FP_TFRdifferenceTag                = '<FP_TFRdifference_V1>'
FP_TestUnmetNeedFromPrevTag        = '<FP_TestUnmetNeedFromPrev_V1>'
FP_CalcCostRegressionTag           = '<FP_CalcCostRegression_V1>'
FP_ASFRInput_TFRGoalTag            = '<FP_ASFRInput_TFRGoal_V1>'
FP_ChildSurvInputsTag              = '<FP_ChildSurvInputs_V1>'
FP_PACInputsTag                    = '<FP_PACInputs_V1>'
FP_LegalAbortNeedTreatTag          = '<FP_LegalAbortNeedTreat_V1>'
FP_PACOutputsTag                   = '<FP_PACOutputs_V1>'
FP_LAMinsusceptibleTag             = '<FP_LAMinsusceptible_V1>'
FP_EPSurveyYearTFRTag              = '<FP_EPSurveyYearTFR_V1>'
FP_TFTag                           = '<FP_TF_V1>'
FP_PRTag                           = '<FP_PR_V1>'
FP_DiscontinuationRateTag          = '<FP_DiscontinuationRate_V1>'
FP_UsersTag                        = '<FP_Users_V1>'
FP_AcceptorsTag                    = '<FP_Acceptors_V1>'
FP_GrowthRateTag                   = '<FP_GrowthRate_V1>'
FP_PregnanciesTag                  = '<FP_Pregnancies_V1>'
FP_ChildSurvOutputsTag             = '<FP_ChildSurvOutputs_V1>'
FP_PregAvertedTag                  = '<FP_PregAverted_V1>'
FP_MaternalDeathsAvertedTag        = '<FP_MaternalDeathsAverted_V1>'
FP_UnsafeAbortionsAvertedTag       = '<FP_UnsafeAbortionsAverted_V1>'
FP_RelativeRisksTag                = '<FP_RelativeRisks_V1>'
FP_RRAgeBirthOrderResultTag        = '<FP_RRAgeBirthOrderResult_V1>'
FP_RRBirthIntervalResultTag        = '<FP_RRBirthIntervalResult_V1>'
# FP_EdFPSourceTag                   = '<FP_EdFPSource_V1>'
# FP_EdGLSourceTag                   = '<FP_EdGLSource_V1>'
FP_SourceTag                       = '<FP_Source_V1>'
FP_DataSourceTag                   = '<FP_DataSource_V1>'
FP_AvgHouseholdTag                 = '<FP_AvgHousehold_V1>'
FP_GoalAnnualChangeTag             = '<FP_GoalAnnualChange_V1>'

##### OLD TAGS GO BELOW #####