#Tags used in the old desktop pjnz files
DP_PJNZ_SurvRate1970Tag                    = '<SurvRate1970 MV>'
DP_PJNZ_DPSourcesTag                       = '<DPSources MV>'
DP_PJNZ_SourcesTag                         = '<Sources MV>'
DP_PJNZ_HAARTBySexTag		                  =	'<HAARTBySex MV>'
DP_PJNZ_HAARTBySexPerNumTag             	  =	'<HAARTBySexPerNum MV>'
DP_PJNZ_AdultARTAdjFactorTag               = '<AdultARTAdjFactor>'
DP_PJNZ_AdultARTAdjFactorFlagTag           = '<AdultARTAdjFactorFlag>'
DP_PJNZ_AdultARTByMonthTag                 = '<AdultARTByMonth MV>'
DP_PJNZ_AdultPercentLTFUByMonthTag         = '<AdultPercentLTFUByMonth MV>'
DP_PJNZ_TFRTag	                            =	'<TFR MV>'
DP_PJNZ_TFR15_19DefaultDataTag	            =	'<TFR15_19DefaultData MV>'
DP_PJNZ_TFRRFitXMLDefaultDataTag           =	'<FRRFitXMLDefaultData MV>'
DP_PJNZ_LETag2		                          =	'<LE MV2>'
DP_PJNZ_MigrAgeDistTag2                    = '<MigrAgeDist MV2>'
DP_PJNZ_MigrRateTag2                       = '<MigrRate MV2>'
DP_PJNZ_COVID19DeathRateTag                = '<COVID19DeathRateTag>'
DP_PJNZ_COVID19DeathAgeDistTag             = '<COVID19DeathAgeDist MV>'
DP_PJNZ_COVID19DeathAgeDistTag2            = '<COVID19DeathAgeDist MV2>'
DP_PJNZ_ASFRTag                            = '<ASFR MV>'
DP_PJNZ_UNPopASFRTag                       = '<UNPopASFR MV>'
DP_PJNZ_PercentOfPopTag	                  =	'<PercentOfPop MV>'
DP_PJNZ_FirstYearOfEpidemicTag            	=	'<FirstYearOfEpidemic MV>'
DP_PJNZ_CD4CoverageTag	                    =	'<CD4Coverage MV>'
DP_PJNZ_CD4CoverageTag2	                  =	'<CD4Coverage MV2>'
DP_PJNZ_ARTByAgeInputType                  =	'<ARTByAgeInputType MV>'
DP_PJNZ_ARTByAge5YearAG                    =	'<ARTByAge5YearAG MV>'
DP_PJNZ_ARTByAgeGAMAG                      =	'<ARTByAgeGAMAG MV>'
DP_PJNZ_IncidenceInputTag	                =	'<IncidenceInput MV>'
DP_PJNZ_ECDCValuesTag	                    =	'<ECDCValues MV>'
DP_PJNZ_ECDCFQNameTag                      =	'<ECDCFQName MV>'
DP_PJNZ_NosocomialInfectionsTag            =	'<NosocomialInfections MV>'
DP_PJNZ_NosocomialInfectionsByAgeTag       =	'<NosocomialInfectionsByAge MV>'
DP_PJNZ_HIVMigrantsByAgeSexTag             = '<HIVMigrantsByAgeSex MV>'
DP_PJNZ_HIVMigrBySingleAgeTag              = '<HIVMigrBySingleAge MV>'
DP_PJNZ_IncidenceInput1970Tag              = '<IncidenceInput1970 MV>'
DP_PJNZ_AnnualRetentionRateTag             = '<AnnualRetentionRate MV>'
DP_PJNZ_AnnualInterruptionRateTag          = '<AnnualInterruptionRate MV>'
DP_PJNZ_IncreasedLikelihoodOfReinitTag     = '<IncreasedLikelihoodOfReinit MV>'
DP_PJNZ_OffARTMortRateMultiplierTag        = '<OffARTMortRateMultiplier MV>'
DP_PJNZ_ChildAnnualRetentionRateTag        = '<ChildAnnualRetentionRate MV>'
DP_PJNZ_ChildAnnualInterruptionRateTag     = '<ChildAnnualInterruptionRate MV>'
DP_PJNZ_ChildIncreasedLikelihoodOfReinitTag= '<ChildIncreasedLikelihoodOfReinit MV>'
DP_PJNZ_ChildOffARTMortRateMultiplierTag   = '<ChildOffARTMortRateMultiplier MV>'
DP_PJNZ_FitIncidenceEditorValuesTag     	  =	'<FitIncidenceEditorValues MV>'
DP_PJNZ_FitIncidenceEditorValuesTag2       =	'<FitIncidenceEditorValues MV2>'
DP_PJNZ_FitIncidenceEditorValuesTag3       =	'<FitIncidenceEditorValues MV3>'
DP_PJNZ_FitIncidenceEditorValuesTag4       =	'<FitIncidenceEditorValues MV4>'
DP_PJNZ_FitIncidenceEditorValuesTag5       =	'<FitIncidenceEditorValues MV5>'
DP_PJNZ_FitIncidenceEditorValuesTag6       =	'<FitIncidenceEditorValues MV6>'
DP_PJNZ_CSAVRInputAIDSDeathsSourceTag      = '<CSAVRInputAIDSDeathsSource MV>'
DP_PJNZ_CSAVRInputAIDSDeathsSourceNameTag  = '<CSAVRInputAIDSDeathsSourceName MV>'
DP_PJNZ_CSAVRInputAIDSDeathsTag              = '<CSAVRInputAIDSDeaths MV>'
DP_PJNZ_CSAVRInputAIDSDeathsTag2             = '<CSAVRInputAIDSDeaths MV2>'
DP_PJNZ_CSAVRInputAIDSDeathsBySexTag         = '<CSAVRInputAIDSDeathsBySex MV>'
DP_PJNZ_CSAVRInputAIDSDeathsBySexTag2        = '<CSAVRInputAIDSDeathsBySex MV2>'
DP_PJNZ_CSAVRInputAIDSDeathsBySexAgeTag      = '<CSAVRInputAIDSDeathsBySexAge MV>'
DP_PJNZ_CSAVRInputAIDSDeathsBySexAgeTag2     = '<CSAVRInputAIDSDeathsBySexAge MV2>'
DP_PJNZ_CSAVRInputNewDiagnosesTag            = '<CSAVRInputNewDiagnoses MV>'
DP_PJNZ_CSAVRInputNewDiagnosesBySexTag       = '<CSAVRInputNewDiagnosesBySex MV>'
DP_PJNZ_CSAVRInputNewDiagnosesBySexAgeTag    = '<CSAVRInputNewDiagnosesBySexAge MV>'
DP_PJNZ_CSAVRInputNewDiagnosesBySexAgeCD4Tag = '<CSAVRInputNewDiagnosesBySexAgeCD4 MV>'
DP_PJNZ_CSAVRInputCD4DistAtDiagTag         = '<CSAVRInputCD4DistAtDiag MV>'
DP_PJNZ_IncidenceAgeGroupIndexTag          =	'<IncidenceAgeGroupIndex MV>'
DP_PJNZ_CSAVRIncidenceByFitTag             =	'<CSAVRIncidenceByFit MV>'
DP_PJNZ_CSAVRIncidenceByFitTag2            =	'<CSAVRIncidenceByFit MV2>'
DP_PJNZ_TFitIncidencePopulationValueTag    = '<FitIncidencePopulationValueTag>'
DP_PJNZ_TFitIncidenceHIVAidsToggleValueTag = '<FitIncidenceHIVAidsToggleValueTag>'
DP_PJNZ_TFitIncidenceDiagnosisRateValueTag = '<FitIncidenceDiagnosisRateValueTag>'
DP_PJNZ_TFitIncMeanCD4YearToggleValueTag   = '<FitIncMeanCD4YearToggleValueTag>'
DP_PJNZ_FitIncidenceParametersTag       	  =	'<FitIncidenceParameters MV>'
DP_PJNZ_FitIncidenceParametersTag2      	  =	'<FitIncidenceParameters MV2>'
DP_PJNZ_FitIncidenceParametersTag3      	  =	'<FitIncidenceParameters MV3>'
DP_PJNZ_FitIncidenceParametersTag4      	  =	'<FitIncidenceParameters MV4>'
DP_PJNZ_FitIncidenceParametersTag5      	  =	'<FitIncidenceParameters MV5>'
DP_PJNZ_FitIncidenceParametersTag6      	  =	'<FitIncidenceParameters MV6>'
DP_PJNZ_FitIncidenceParametersTag7      	  =	'<FitIncidenceParameters MV7>'
DP_PJNZ_FitIncidenceIncScaleParametersTag  =	'<FitIncidenceIncScaleParameters MV>'
DP_PJNZ_FitIncidenceIncScaleParametersTag2 =	'<FitIncidenceIncScaleParameters MV2>'
DP_PJNZ_FitIncidenceUncertaintyParamsTag   =	'<FitIncidenceUncertaintyParams MV>'
DP_PJNZ_FitIncidenceUncertaintyParamsTag2  =	'<FitIncidenceUncertaintyParams MV2>'
DP_PJNZ_FitIncidenceUncertaintyParamsTag3  =	'<FitIncidenceUncertaintyParams MV3>'
DP_PJNZ_CSAVRConstrainPLHIVGTNumARTTag     = '<CSAVRConstrainPLHIVGTNumART MV3>'
DP_PJNZ_FitIncidenceSOSPParametersTag      = '<FitIncidenceSOSPParameters MV>'
DP_PJNZ_TSOSPFindInitialValueTag           = '<SOSPFindInitialValue MV>'
DP_PJNZ_FitIncidenceIterationsTag       	  =	'<FitIncidenceIterations MV>'
DP_PJNZ_FitIncidenceOptToleranceTag     	  =	'<FitIncidenceOptTolerance MV>'
DP_PJNZ_FitIncidenceTypeOfFitTag       	  =	'<FitIncidenceTypeOfFit MV>'
DP_PJNZ_FitIncidenceTypeOfFitTag2      	  =	'<FitIncidenceTypeOfFit MV2>'
DP_PJNZ_CSAVRSplineKnotsTag                = '<CSAVRSplineKnots MV>'
DP_PJNZ_CSAVRAdjustIRRsTag             	  =	'<CSAVRAdjustIRRs MV>'
DP_PJNZ_CSAVRAdjustIRRsTag2            	  =	'<CSAVRAdjustIRRs MV2>'
DP_PJNZ_CSAVRAdjustIRRsTag3            	  =	'<CSAVRAdjustIRRs MV3>'
DP_PJNZ_CSAVRAdjustIRRsTag4            	  =	'<CSAVRAdjustIRRs MV4>'
DP_PJNZ_FitIncidenceFitMethodTag       	  =	'<FitIncidenceFitMethod MV>'
DP_PJNZ_FitIncidenceFitMethodTag2      	  =	'<FitIncidenceFitMethod MV2>'
DP_PJNZ_MeanCD4atDiagnosisTag              =	'<MeanCD4atDiagnosis MV>'
DP_PJNZ_MeanCD4atDiagnosisTag2             =	'<MeanCD4atDiagnosis MV2>'
DP_PJNZ_MeanCD4atDiagnosisTag3             =	'<MeanCD4atDiagnosis MV3>'
DP_PJNZ_MeanCD4atDiagnosisTag4             =	'<MeanCD4atDiagnosis MV4>'
DP_PJNZ_MeanCD4atDiagnosisTag5             =	'<MeanCD4atDiagnosis MV5>'
DP_PJNZ_MeanCD4atDiagnosisByAgeSexTag      =	'<MeanCD4atDiagnosisByAgeSex MV>'
DP_PJNZ_MeanCD4atDiagnosisByAgeSexTag2     =	'<MeanCD4atDiagnosisByAgeSex MV2>'
DP_PJNZ_TimeInfToDiagTag                   =	'<TimeInfToDiag MV>'
DP_PJNZ_TimeInfToDiagTag2                  =	'<TimeInfToDiag MV2>'
DP_PJNZ_TimeInfToDiagTag3                  =	'<TimeInfToDiag MV3>'
DP_PJNZ_TimeInfToDiagTag4                  =	'<TimeInfToDiag MV4>'
DP_PJNZ_TimeInfToDiagTag5                  =	'<TimeInfToDiag MV5>'
DP_PJNZ_PropOfDiagnosedTag                 =	'<PropOfDiagnosed MV>'
DP_PJNZ_PropOfDiagnosedTag2                =	'<PropOfDiagnosed MV2>'
DP_PJNZ_PropOfDiagnosedTag3                =	'<PropOfDiagnosed MV3>'
DP_PJNZ_PropOfDiagnosedTag4                =	'<PropOfDiagnosed MV4>'
DP_PJNZ_PropOfDiagnosedTag5                =	'<PropOfDiagnosed MV5>'
DP_PJNZ_PropOfDiagnosedNoARTTag            =	'<PropOfDiagnosedNoART MV>'
DP_PJNZ_PropOfDiagnosedNoARTTag2           =	'<PropOfDiagnosedNoART MV2>'
DP_PJNZ_PropOfDiagnosedByAgeSexCD4Tag      =	'<PropOfDiagnosedByAgeSexCD4 MV>'
DP_PJNZ_PropOfDiagnosedByAgeSexCD4Tag2     =	'<PropOfDiagnosedByAgeSexCD4 MV2>'
DP_PJNZ_CSAVRNumPLHIVTag                   = '<CSAVRNumPLHIV MV>'
DP_PJNZ_CSAVRNumPLHIVTag2                  = '<CSAVRNumPLHIV MV2>'
DP_PJNZ_CSAVRNumPLHIVTag3                  = '<CSAVRNumPLHIV MV3>'
DP_PJNZ_CSAVRNumPLHIVByAgeSexCD4Tag        = '<CSAVRNumPLHIVByAgeSexCD4 MV>'
DP_PJNZ_CSAVRNumPLHIVByAgeSexCD4Tag2       = '<CSAVRNumPLHIVByAgeSexCD4 MV2>'
DP_PJNZ_CSAVRNumDiagnosedTag               = '<CSAVRNumDiagnosed MV>'
DP_PJNZ_CSAVRNumDiagnosedTag2              = '<CSAVRNumDiagnosed MV2>'
DP_PJNZ_CSAVRNumDiagnosedTag3              = '<CSAVRNumDiagnosed MV3>'
DP_PJNZ_CSAVRNumDiagnosedByAgeSexCD4Tag      = '<CSAVRNumDiagnosedByAgeSexCD4 MV>'
DP_PJNZ_CSAVRNumDiagnosedByAgeSexCD4Tag2     = '<CSAVRNumDiagnosedByAgeSexCD4 MV2>'
DP_PJNZ_CSAVRAIDSDeathsTag                 = '<CSAVRAIDSDeaths MV>'
DP_PJNZ_CSAVRAIDSDeathsTag2                = '<CSAVRAIDSDeaths MV2>'
DP_PJNZ_CSAVRAIDSDeathsTag3                = '<CSAVRAIDSDeaths MV3>'
DP_PJNZ_CSAVRAIDSDeathsByAgeSexTag           =	'<CSAVRAIDSDeathsByAgeSex MV>'
DP_PJNZ_CSAVRAIDSDeathsByAgeSexTag2          =	'<CSAVRAIDSDeathsByAgeSex MV2>'
DP_PJNZ_CSAVRNumNewInfectionsTag           = '<CSAVRNumNewInfections MV>'
DP_PJNZ_CSAVRNumNewInfectionsTag2          = '<CSAVRNumNewInfections MV2>'
DP_PJNZ_CSAVRNumNewInfectionsTag3          = '<CSAVRNumNewInfections MV3>'
DP_PJNZ_FitIncidenceAICByFitTypeTag2       =	'<FitIncidenceAICByFitType MV2>'
DP_PJNZ_FitIncidenceAICByFitTypeTag3       =	'<FitIncidenceAICByFitType MV3>'
DP_PJNZ_CSAVRMetaDataTag                   =	'<CSAVRMetaData MV>'
DP_PJNZ_CSAVRMetaDataTag2                  =	'<CSAVRMetaData MV2>'
DP_PJNZ_SPTFileExistsTag                   = '<SPTFileExists MV>'
DP_PJNZ_UrbanPercentTag                    = '<UrbanPercent MV>'#last used in Spectrum 5.8 beta 4, need to keep uncommented for RAPI
DP_PJNZ_TFRRegionTag                       = '<TFRRegion MV>'
DP_PJNZ_HIVTFRCustomFlagTag                = '<HIVTFRCustomFlag MV>'
DP_PJNZ_HIVTFRTag2		                      =	'<HIVTFR MV2>'
DP_PJNZ_HIVTFRTag3		                      =	'<HIVTFR MV3>'
DP_PJNZ_HIVTFRTag4		                      =	'<HIVTFR MV4>'
DP_PJNZ_TFRInputType                       = '<TFRInputType MV>'
DP_PJNZ_FertCD4DiscountTag		              =	'<FertCD4Discount MV>'
DP_PJNZ_RatioWomenOnARTTag                 =	'<RatioWomenOnART MV>'
DP_PJNZ_RatioWomenOnARTTag2                =	'<RatioWomenOnART MV2>'
DP_PJNZ_FRRFitInputTag                     =	'<FRRFitInput MV>'
DP_PJNZ_FRRbyLocationTag                   = '<FRRbyLocation MV>'
DP_PJNZ_SexBirthRatioTag                   = '<SexBirthRatio MV>'
DP_PJNZ_DHSDataInputTag                    = '<DHSDataInput MV>'
DP_PJNZ_DHSDataInput2Tag                   = '<DHSDataInput2 MV>'
DP_PJNZ_DHSDataInput3Tag                   = '<DHSDataInput3 MV>'
DP_PJNZ_ChildTreatInputsTag                = '<ChildTreatInputs MV>'
DP_PJNZ_ChildTreatInputsTag2               = '<ChildTreatInputs2 MV>'
DP_PJNZ_ChildTreatInputsTag3               = '<ChildTreatInputs MV3>'
DP_PJNZ_ChildARTAdjFactorTag               = '<ChildARTAdjFactor MV>'
DP_PJNZ_ChildARTAdjFactorFlagTag           = '<ChildARTAdjFactorFlag>'
DP_PJNZ_ChildARTPerDistTag                 = '<ChildARTPerDist MV>'
DP_PJNZ_ChildTreatInputTypeTag             = '<ChildTreatInputType MV>'
DP_PJNZ_CotrimPerNumTag                    = '<CotrimPerNum MV>'
DP_PJNZ_ChildARTPerNumTag                  = '<ChildARTPerNum MV>'
DP_PJNZ_ChildARTPerNumTag2                 = '<ChildARTPerNum MV2>'
DP_PJNZ_ChildARTByAGPerNumTag              = '<ChildARTByAgeGroupPerNum MV>'
DP_PJNZ_ChildARTByAGPerNumTag2             = '<ChildARTByAgeGroupPerNum MV2>'
DP_PJNZ_ChildARTByMonthTag                 = '<ChildARTByMonth MV>'
DP_PJNZ_ChildPercentLTFUByMonthTag         = '<ChildPercentLTFUByMonth MV>'
DP_PJNZ_EarlyInfantDiagnosisTag	          =	'<EarlyInfantDiagnosis MV>'
DP_PJNZ_EIDPerNumTag 	                   	=	'<EIDPerNum MV>'
DP_PJNZ_ANCTestingValuesTag 	              =	'<ANCTestingValues MV>'
DP_PJNZ_ANCTestingValuesTag2	              =	'<ANCTestingValues MV2>'
DP_PJNZ_ANCTestingValuesTag3	              =	'<ANCTestingValues MV3>'
DP_PJNZ_ANCTestingValuesTag4	              =	'<ANCTestingValues MV4>'
DP_PJNZ_NetMigrationPLHIVTag               =	'<NetMigrationPLHIV MV>'
DP_PJNZ_NewInfectionsLessImmigrantsTag     =	'<NewInfectionsLessImmigrants MV>'
DP_PJNZ_HIVTestingTag                      =	'<HIVTesting MV>'
DP_PJNZ_HIVTestingHTSTestsByAgeTag         =	'<HIVTestingHTSTestsByAge MV>'
DP_PJNZ_KnowledgeOfStatusInputTypeTag      =	'<KnowledgeOfStatusInputType MV>'
DP_PJNZ_KnowledgeOfStatusInputTypeTag2     =	'<KnowledgeOfStatusInputType MV2>'
DP_PJNZ_KnowledgeOfStatusInputTag          =	'<KnowledgeOfStatusInput MV>'
DP_PJNZ_KnowledgeOfStatusInputTag2         =	'<KnowledgeOfStatusInput MV2>'
DP_PJNZ_KnowledgeOfStatusInputTag3         =	'<KnowledgeOfStatusInput MV3>'
DP_PJNZ_KnowledgeOfStatusInputTag4         =	'<KnowledgeOfStatusInput MV4>'
DP_PJNZ_KnowledgeOfStatusFileTitleTag      = '<KnowledgeOfStatusFileTitle MV>'
DP_PJNZ_Shiny90AIDSDeathsFYearTag          = '<Shiny90AIDSDeathsFYear MV>'
DP_PJNZ_Shiny90SurveyDataTag               = '<Shiny90SurveyData MV>'
DP_PJNZ_Shiny90IsFittedTag                 = '<Shiny90IsFitted MV>'
DP_PJNZ_Shiny90DataSourceTag               = '<Shiny90DataSource MV>'
DP_PJNZ_Shiny90ProgramDataTag              = '<Shiny90ProgramData MV>'
DP_PJNZ_Shiny90PopTag                      = '<Shiny90Pop MV>'
DP_PJNZ_Shiny90NumTestsTag                 = '<Shiny90NumTests MV>'
DP_PJNZ_Shiny90NumTested12MTag             = '<Shiny90NumTested12M MV>'
DP_PJNZ_Shiny90TotalTestsTag               = '<Shiny90TotalTests MV>'
DP_PJNZ_Shiny90EverTestedTag               = '<Shiny90EverTested MV>'
DP_PJNZ_Shiny90DiagnosedTag                = '<Shiny90Diagnosed MV>'
DP_PJNZ_Shiny90NumAwareTag                 = '<Shiny90NumberAware MV>'
DP_PJNZ_Shiny90NumDiagnosesTag             = '<Shiny90NumDiagnoses MV>'
DP_PJNZ_Shiny90NumDiagnosesModTag          = '<Shiny90NumDiagnosesMod MV>'
DP_PJNZ_Shiny90NumLateDiagnosesTag         = '<Shiny90NumLateDiagnoses MV>'
DP_PJNZ_Shiny90NotDiagHIV1YrTag            = '<Shiny90NotDiagHIV1Yr MV>'
DP_PJNZ_KnowledgeOfStatusCaseReportsTag    =	'<KnowledgeOfStatusCaseReports MV>'
DP_PJNZ_KnowledgeOfStatusPHIATag           =	'<KnowledgeOfStatusPHIA MV>'
DP_PJNZ_PHIADataYearIdxTag                 =	'<PHIADataYearIdx MV>'
DP_PJNZ_KnowledgeOfStatusDHSTag            =	'<KnowledgeOfStatusDHS MV>'
DP_PJNZ_DHSDataYearIdxTag                  =	'<DHSDataYearIdx MV>'
DP_PJNZ_DHSDataYearIdxTag2                 =	'<DHSDataYearIdx MV2>'
DP_PJNZ_ViralSuppressionInputTypeTag       =	'<ViralSuppressionInputType MV>'
DP_PJNZ_ViralSuppressionInputTypeTag2      =	'<ViralSuppressionInputType MV2>'
DP_PJNZ_ViralSuppressionClinicalTag        =	'<ViralSuppressionClinical MV>'
DP_PJNZ_ViralSuppressionClinicalTag2       =	'<ViralSuppressionClinical MV2>'
DP_PJNZ_ViralSuppressionInputTag           =	'<ViralSuppressionInput MV>'
DP_PJNZ_ViralSuppressionInputTag2          =	'<ViralSuppressionInput MV2>'
DP_PJNZ_ViralSuppressionInputTag3          =	'<ViralSuppressionInput MV3>'
DP_PJNZ_ViralSuppressionInputTag4          =	'<ViralSuppressionInput MV4>'
DP_PJNZ_ViralSuppressionThresholdTag       =	'<ViralSuppressionThreshold MV>'
DP_PJNZ_ViralSuppressionThresholdTag2      =	'<ViralSuppressionThreshold MV2>'
DP_PJNZ_ViralSuppressionThresholdTag3      =	'<ViralSuppressionThreshold MV3>'
DP_PJNZ_ViralSuppressionThresholdTag4      =	'<ViralSuppressionThreshold MV4>'
DP_PJNZ_ViralSuppressionSurveysTag         =	'<ViralSuppressionSurveys MV>'
DP_PJNZ_VSSurveysDataYearIdxTag            =	'<VSSurveysDataYearIdx MV>'
DP_PJNZ_ARVRegimenTag2	                    =	'<ARVRegimen MV2>'
DP_PJNZ_ARVRegimenTag3	                    =	'<ARVRegimen MV3>'
DP_PJNZ_PatientsReallocatedTag             = '<DP_PJNZ_PatientsReallocatedTag>'
DP_PJNZ_DropoutPrPrTag                     = '<DropoutPrPr MV>'
DP_PJNZ_PercentARTDeliveryTag                     = '<PercentARTDelivery MV>'
DP_PJNZ_InfantFeedingOptionsTag	          =	'<InfantFeedingOptions MV>'
DP_PJNZ_TransEffAssumpTag	                =	'<TransEffAssump MV>'
DP_PJNZ_SurvARTchildLT1YTag                = '<SurvARTchildLT1Y MV>'
DP_PJNZ_SurvARTchildFYTag                  = '<SurvARTchildFY MV>'
DP_PJNZ_SurvARTchildSYTag                  = '<SurvARTchildSY MV>'
DP_PJNZ_AdultAvgDurByCD4Tag2               = '<AdultAvgDurByCD4 MV2>'
DP_PJNZ_AdultAnnRateProgressLowerCD4Tag 	  =	'<AdultAnnRateProgressLowerCD4 MV>'
DP_PJNZ_AdultDistNewInfectionsCD4Tag       = '<AdultDistNewInfectionsCD4 MV>'
DP_PJNZ_AdultMortByCD4NoARTTag             = '<AdultMortByCD4NoART MV>'
DP_PJNZ_ChildAnnRateProgressLowerCD4Tag  	=	'<ChildAnnRateProgressLowerCD4 MV>'
DP_PJNZ_ChildAnnRateProgressLowerCD4Tag2  	=	'<ChildAnnRateProgressLowerCD4 MV2>'
DP_PJNZ_ChildDistNewInfectionsCD4Tag	      =	'<ChildDistNewInfectionsCD4 MV>'
DP_PJNZ_ChildMortByCD4NoARTTag2	          =	'<ChildMortByCD4NoART MV2>'
DP_PJNZ_ChildMortByCD4WithART0to6Tag2      = '<ChildMortByCD4WithART0to6 MV2>'
DP_PJNZ_ChildMortByCD4WithART7to12Tag      = '<ChildMortByCD4WithART7to12 MV>'
DP_PJNZ_ChildMortByCD4WithARTGT12Tag       = '<ChildMortByCD4WithARTGT12 MV>'
DP_PJNZ_EffectTreatChildTag                = '<EffectTreatChild MV>'
DP_PJNZ_ChildWeightBandsTag                = '<ChildWeightBands MV>'
DP_PJNZ_AdultMortByCD4WithART0to6Tag2      = '<AdultMortByCD4WithART0to6 MV2>'
DP_PJNZ_AdultMortByCD4WithART7to12Tag2     = '<AdultMortByCD4WithART7to12 MV2>'
DP_PJNZ_AdultMortByCD4WithARTGt12Tag2      = '<AdultMortByCD4WithARTGt12 MV2>'
DP_PJNZ_AdultInfectReducTag                = '<AdultInfectReduc MV>'
DP_PJNZ_MortalityRatesTag                  = '<MortalityRates MV>'
DP_PJNZ_MortalityRatesTag2                 = '<MortalityRates MV2>'
DP_PJNZ_MortalityRatesMultiplierTag        = '<MortalityRatesMultiplier MV>'
DP_PJNZ_ChildMortalityRatesTag             = '<ChildMortalityRates MV>'
DP_PJNZ_ChildMortalityRatesTag2            = '<ChildMortalityRates MV2>'
DP_PJNZ_ChildMortalityRatesMultiplierTag   = '<ChildMortalityRatesMultiplier MV>'
DP_PJNZ_IncCD4FirstYrWithARTTag            = '<IncCD4FirstYrWithART MV>'
DP_PJNZ_IncCD4SubYrWithARTTag              = '<IncCD4SubYrWithART MV>'
DP_PJNZ_PCRTag                             = '<PCR MV>'
DP_PJNZ_PregTermAbortionPerNumTag          = '<PregTermAbortionPerNum MV>'
DP_PJNZ_PregTermAbortionPerNumTag2          = '<PregTermAbortionPerNum MV2>'
DP_PJNZ_PregTermAbortionTag	              =	'<PregTermAbortion MV>'
DP_PJNZ_PregTermAbortionTag2	              =	'<PregTermAbortion MV2>'
DP_PJNZ_PregTermAbortionTag3	              =	'<PregTermAbortion MV3>'
DP_PJNZ_AgeHIVChildOnTreatmentTag          = '<AgeHIVChildOnTreatment MV>'
DP_PJNZ_CD4ThreshHoldTag                   = '<CD4ThreshHold MV>'
DP_PJNZ_CD4ThreshHoldAdultsTag          	  =	'<CD4ThreshHoldAdults MV>'
DP_PJNZ_PopsEligTreatTag	                  =	'<PopsEligTreat MV>'
DP_PJNZ_CovPopsEligTreatTag             	  =	'<CovPopsEligTreat MV>'
DP_PJNZ_AIDS45q15Tag		                    =	'<AIDS45q15 MV>'
DP_PJNZ_NonAIDS45q15Tag		                =	'<NonAIDS45q15 MV>'
DP_PJNZ_Total45q15Tag		                  =	'<Total45q15 MV>'
DP_PJNZ_Under5MortRateTag	                =	'<Under5MortRate MV>'
DP_PJNZ_PMTCTProgEstNeedTag	              =	'<PMTCTProgEstNeed MV>'
DP_PJNZ_NumberOnARTTag		                  =	'<NumberOnART MV>'
DP_PJNZ_ARTCovByAgeTag                     =	'<ARTCovByAge MV>'
DP_PJNZ_KeyPopsTag                         =	'<KeyPops MV>'
DP_PJNZ_KeyPopsYearTag                     =	'<KeyPopsYear MV>'
DP_PJNZ_KeyPopsFNameTag                    =	'<KeyPopsFName MV>'
DP_PJNZ_PregWomenPrevTag	                  =	'<PregWomenPrev MV>'
DP_PJNZ_AllCauseDeathsARTValidationTag	    =	'<AllCauseDeathsARTValidation MV>'
DP_PJNZ_WaterfallValidationTag             =	'<WaterfallValidation MV>'
DP_PJNZ_PregWomenPrevRoutineTestTag	      =	'<PregWomenPrevRoutineTest MV>'
DP_PJNZ_AIDSMortalityAllAgesTag2	          =	'<AIDSMortalityAllAges MV2>'
DP_PJNZ_CSAVRFitOptionsTag                 =	'<CSAVRFitOptions MV2>'
DP_PJNZ_CSAVRFitOptionsTag3                =	'<CSAVRFitOptions MV3>'
DP_PJNZ_MortRateByAgeTag2	                =	'<MortRateByAge MV2>'
DP_PJNZ_AllCauseMortalityTag2	            =	'<AllCauseMortality MV2>'
DP_PJNZ_AIDSMortalityTag2	                =	'<AIDSMortality MV2>'
DP_PJNZ_NumberOnARTByAgeTag2	              =	'<NumberOnARTByAge MV2>'
DP_PJNZ_NewlyStartingARTTag	              =	'<NewlyStartingART MV>'
DP_PJNZ_AdultsChildrenStartingARTTag       = '<AdultsChildrenStartingART MV>'
DP_PJNZ_PrevSurveyDataTag2              	  =	'<PrevSurveyData MV2>'
DP_PJNZ_PrevSurveyDataTag3                 =	'<PrevSurveyData MV3>'
DP_PJNZ_PrevSurveyDataTag4                 =	'<PrevSurveyData MV4>'
DP_PJNZ_PrevSurveyDataTag5                 =	'<PrevSurveyData MV5>'
DP_PJNZ_PrevSurveyUsedTag	                =	'<PrevSurveyUsed MV>'
DP_PJNZ_PrevSurveyUsedTag2	                =	'<PrevSurveyUsed MV2>'
DP_PJNZ_PrevSurveyUsedTag3	                =	'<PrevSurveyUsed MV3>'
DP_PJNZ_PrevSurveyNameTag               	  =	'<PrevSUrveyName MV>'
DP_PJNZ_PrevSurveyNameTag2              	  =	'<PrevSurveyName MV2>'
DP_PJNZ_PrevSurveyNameTag3              	  =	'<PrevSurveyName MV3>'
DP_PJNZ_PrevSurveyYearTag	                =	'<PrevSurveyYear MV>'
DP_PJNZ_PrevSurveyYearTag2	                =	'<PrevSurveyYear MV2>'
DP_PJNZ_PrevSurveyYearTag3	                =	'<PrevSurveyYear MV3>'
DP_PJNZ_ARTCovSurveyDataTag                =	'<ARTCovSurveyData MV>'
DP_PJNZ_ARTCovSurveyDataTag2               =	'<ARTCovSurveyData MV2>'
DP_PJNZ_ARTCovSurveyUsedTag	              =	'<ARTCovSurveyUsed MV>'
DP_PJNZ_ARTCovSurveyUsedTag2	              =	'<ARTCovSurveyUsed MV2>'
DP_PJNZ_ARTCovSurveyNameTag               	=	'<ARTCovSurveyName MV>'
DP_PJNZ_ARTCovSurveyNameTag2              	=	'<ARTCovSurveyName MV2>'
DP_PJNZ_ARTCovSurveyYearTag	              =	'<ARTCovSurveyYear MV>'
DP_PJNZ_ARTCovSurveyYearTag2	              =	'<ARTCovSurveyYear MV2>'
DP_PJNZ_DALYDisabilityWeightsTag	          =	'<DALYDisabilityWeights MV>'
DP_PJNZ_NewARTPatAllocTag                  = '<NewARTPatAlloc MV>'
DP_PJNZ_NewARTPatAllocMethodTag2           = '<NewARTPatAllocationMethod MV2>'
DP_PJNZ_RiskPopOrphansTag2	                =	'<RiskPopOrphans MV2>'
DP_PJNZ_NumNewARTPatsTag		                =	'<NumNewARTPats MV>'
DP_PJNZ_NumNewlyInitARTTag		              =	'<NumNewlyInitART MV>'
DP_PJNZ_MedCD4CountInitTag	              	=	'<MedCD4CountInit MV>'
DP_PJNZ_FirstYearTag2                      = '<FirstYear MV2>'
DP_PJNZ_SingleYearProjectionTag2           = '<SingleYearProjection MV2>'
DP_PJNZ_ScalerTag2                         = '<Scaler MV2>'
DP_PJNZ_FourDecPlaceIDTag2                 = '<FourDecPlaceID MV2>'
DP_PJNZ_LifeTableNumTag2                   = '<LifeTableNum MV2>'
DP_PJNZ_ARTCoverageSelectionTag            = '<ARTCoverageSelection MV>'
DP_PJNZ_FutureARTTag2                      = '<FutureART MV2>'
DP_PJNZ_PercVirallySuppressedTag           = '<PercVirallySuppressed MV>'
DP_PJNZ_PercLostFollowupTag                = '<PercLostFollowup MV>'
DP_PJNZ_NumberInitTreatmentTotalTag        = '<NumberInitTreatmentTotal MV>'
DP_PJNZ_NumberInitTreatmentReinitsTag      = '<NumberInitTreatmentReinits MV>'
DP_PJNZ_PercLostFollowupChildTag           = '<PercLostFollowupChild MV>'
DP_PJNZ_NumberInitTreatmentReinitsChildTag = '<NumberInitTreatmentReinitsChild MV>'
DP_PJNZ_NumNewlyInitARTChildTag	          =	'<NumNewlyInitARTChild MV>'
DP_PJNZ_SexRatioFromEPPTag	                =	'<SexRatioFromEPP MV>'
DP_PJNZ_EPPPopulationAgesTag	              =	'<EPPPopulationAges MV>'
DP_PJNZ_DHSYrIDTag                         = '<DHSYrID MV>'
DP_PJNZ_DHSYr2IDTag                        = '<DHSYr2ID MV>'
DP_PJNZ_IncidenceInput1970BoolTag          = '<IncidenceInput1970Bool MV>'
DP_PJNZ_EPPPrevAdjTag	                    =	'<EPPPrevAdj MV>'
DP_PJNZ_EPPMaxAdjFactorTag	                =	'<EPPMaxAdjFactor MV>'
DP_PJNZ_EPPPrevAdjustmentYearTag	          =	'<EPPPrevAdjustmentYear MV>'
DP_PJNZ_IncidenceOptionsTag	              =	'<IncidenceOptions MV>'
DP_PJNZ_IncidenceByFitTag2	                =	'<IncidenceByFit MV2>'
DP_PJNZ_IncidenceByFitTag3	                =	'<IncidenceByFit MV3>'
DP_PJNZ_IncidenceByFitTag4	                =	'<IncidenceByFit MV4>'
DP_PJNZ_FitIncidenceConditionsTag       	  =	'<FitIncidenceConditions MV>'
DP_PJNZ_MalePrevalenceTag                  = '<MalePrevalence MV>'
DP_PJNZ_SexRatioSurveyUsedTag              = '<SexRatioSurveyUsed MV>'
DP_PJNZ_BFYearsRGIdxTag                 	  =	'<BFYearsRGIdx MV>'
DP_PJNZ_BFArvRGIdxTag	                    =	'<BFArvRGIdx MV>'
DP_PJNZ_AdultPrevalenceTag	                =	'<AdultPrevalence MV>'
DP_PJNZ_ChildHIVMortARTRegionTag           = '<ChildHIVMortARTRegion MV>'
DP_PJNZ_ChildHIVMortARTCustomFlagTag       = '<ChildHIVMortARTCustomFlag MV>'
DP_PJNZ_AdultProgressRatesRegionTag2	      =	'<AdultProgressRatesRegion MV2>'
DP_PJNZ_AdultHIVMortNoARTRegionTag2        =	'<AdultHIVMortNoARTRegion MV2>'
DP_PJNZ_AdultHIVMortARTRegionTag        	  =	'<HIV Mortality with ART Country or Region MV>'
DP_PJNZ_AdultHIVMortARTCustomFlagTag       =	'<AdultHIVMortARTCustomFlag MV>'
DP_PJNZ_AdultMedianTimeInfToDeathTag2      = '<AdultMedianTimeInfToDeath MV2>'
DP_PJNZ_DALYUseStandardLifeTableTag	      =	'<DALYUseStandardLifeTable MV>'
DP_PJNZ_DALYBaseYearTag	                  =	'<DALYBaseYear MV>'
DP_PJNZ_DALYDiscountRateTag	              =	'<DALYDiscountRate MV>'
DP_PJNZ_DALYTBWeightTag	                  =	'<DALYTBRate MV>'
DP_PJNZ_DP_AM_OrphansRegionalPatternTag 	  =	'<OrphansRegionalPattern MV>'
DP_PJNZ_RegionalAdjustPopDataTag2          =	'<RegionalAdjustPopData MV2>'
DP_PJNZ_RegionalAdjustPopCBStateTag	      =	'<RegionalAdjustPopCBState MV>'
DP_PJNZ_RegionalAdjustPopFNameTag	        =	'<RegionalAdjustPopFName MV>'
DP_PJNZ_RegionalAdjustPopFDateTag	        =	'<RegionalAdjustPopFDate MV>'
DP_PJNZ_ChangesLogTag	                 	  =	'<ChangesLog MV>'
DP_PJNZ_PercART50PlusTag		                =	'<PercART50Plus MV>'
DP_PJNZ_HIVPos50YearOldsTag                = '<HIVPos50YearOlds MV>'
DP_PJNZ_HIVPos50YearOldsARTTag             = '<HIVPos50YearOldsART MV>'
DP_PJNZ_ChildARTDistRegionTag2             = '<ChildARTDistRegion MV2>'
DP_PJNZ_ChildARTDistTag                    = '<ChildARTDist MV>'
DP_PJNZ_ASFRTablesTag                      = '<ASFRTables MV>'
DP_PJNZ_CustomFileYearsTag                 = '<CustomFileYears MV>'
DP_PJNZ_CustomPopStopRescalingYearTag      = '<CustomPopStopRescalingYear MV>'
DP_PJNZ_MigrAgeDistTag                     = '<MigrAgeDist MV>'
DP_PJNZ_LifeTableNumTag                    = '<LifeTableNum MV>'
DP_PJNZ_SingleYearProjectionTag            = '<SingleYearProjection MV>'
DP_PJNZ_FutureARTTag                       = '<FutureART MV>'
DP_PJNZ_ChildARTDistRegionTag              = '<ChildARTDistRegion MV>'
DP_PJNZ_ChildARTDistCustomFlagTag          = '<ChildARTDistCustomFlag MV>'
DP_PJNZ_AdultProgressRatesRegionTag	      =	'<AdultProgressRatesRegion MV>'
DP_PJNZ_AdultProgressRatesCustomFlagTag	  =	'<AdultProgressRatesCustomFlag MV>'
DP_PJNZ_AdultHIVMortNoARTRegionTag      	  =	'<AdultHIVMortNoARTRegion MV>'
DP_PJNZ_AdultHIVMortNoARTCustomFlagTag  	  =	'<AdultHIVMortNoARTCustomFlag MV>'
DP_PJNZ_IncidenceByFitTag	                =	'<IncidenceByFit MV>'
DP_PJNZ_FourDecPlaceIDTag                  = '<FourDecPlaceID MV>'
DP_PJNZ_ScalerTag                          = '<Scaler MV>'
DP_PJNZ_AIDSMortalityAllAgesTag	          =	'<AIDSMortalityAllAges MV>'
DP_PJNZ_MortRateByAgeTag	                  =	'<MortRateByAge MV>'
DP_PJNZ_AllCauseMortalityTag	              =	'<AllCauseMortality MV>'
DP_PJNZ_AIDSMortalityTag	                  =	'<AIDSMortality MV>'
DP_PJNZ_ChildMortByCD4NoARTTag	            =	'<ChildMortByCD4NoART MV>'
DP_PJNZ_HIVTFRTag		                      =	'<HIVTFR MV>'
DP_PJNZ_RiskPopOrphansTag	                =	'<RiskPopOrphans MV>'
DP_PJNZ_RegionalAdjustPopDataTag	          =	'<RegionalAdjustPopData MV>'
DP_PJNZ_AdultAvgDurByCD4Tag                = '<AdultAvgDurByCD4 MV>'
DP_PJNZ_LETag		                          =	'<LE MV>'
DP_PJNZ_MigrRateTag                        = '<MigrRate MV>'
DP_PJNZ_ARVRegimenTag	                    =	'<ARVRegimen MV>'
DP_PJNZ_PrevSurveyDataTag               	  =	'<PrevSurveyData MV>'
DP_PJNZ_NumberOnARTByAgeTag	              =	'<NumberOnARTByAge MV>'
DP_PJNZ_FirstYearTag                       = '<FirstYear MV>'
DP_PJNZ_ChildMortByCD4WithART0to6Tag       = '<ChildMortByCD4WithART0to6 MV>'
DP_PJNZ_AdultMortByCD4WithART0to6Tag       = '<AdultMortByCD4WithART0to6 MV>'
DP_PJNZ_AdultMortByCD4WithART7to12Tag      = '<AdultMortByCD4WithART7to12 MV>'
DP_PJNZ_AdultMortByCD4WithARTGt12Tag       = '<AdultMortByCD4WithARTGt12 MV>'
DP_PJNZ_AdultMedianTimeInfToDeathTag       = '<AdultMedianTimeInfToDeath MV>'

DP_PJNZ_DefaultEpidemicTag                 = '<DefaultEpidemic MV>'
DP_PJNZ_FinalYearTag2                      = '<FinalYear MV2>'
DP_PJNZ_ASFRNumTag                         = '<ASFRNum MV>'
DP_PJNZ_ASFRCustomFlagTag                  = '<ASFRCustomFlag MV>'
DP_PJNZ_VersionNumTag2                     = '<VersionNum MV2>'
DP_PJNZ_FileTitleTag2                      = '<FileTitle MV2>'
DP_PJNZ_ProjectionValidTag2                = '<ProjectionValid MV2>'
DP_PJNZ_ValidDateTag	                 	    =	'<ValidDate MV>'
DP_PJNZ_ValidVersTag	                 	    =	'<ValidVers MV>'
DP_PJNZ_MedDurDBPopIDTag                   = '<MedDurDBPopID MV>'
DP_PJNZ_EarlyHIVIDTag                      = '<EarlyHIVID MV>'
DP_PJNZ_EppAgeRangeTag                     = '<EppAgeRange MV>'
DP_PJNZ_EpidemicTypeFromEPPTag	            =	'<EpidemicTypeFromEPP MV>'
DP_PJNZ_ModelLifeFileNameTag2              = '<ModelLifeFileName MV2>'
DP_PJNZ_OnARTTag                           = '<OnART MV>'
DP_PJNZ_OnARTBySingleAgeTag                = '<OnARTBySingleAge MV>'
DP_PJNZ_NewInfectionsBySingleAgeTag        = '<NewInfectionsBySingleAge MV>'
DP_PJNZ_OnSLTag                            = '<OnSL MV>'
DP_PJNZ_NewlyOnARTTag	                    =	'<NewlyOnART MV>'
DP_PJNZ_HIVAgingRateTag	                  =	'<HIV Aging Rate MV>'
DP_PJNZ_ChildrenHIVtoAIDSTag               = '<ChildrenHIVtoAIDS MV>'
DP_PJNZ_HIVSexRatioFromEPPTag	            =	'<HIVSexRatioFromEPP MV>'
DP_PJNZ_ARTDropOutRateTag	                =	'<ARTDropOutRate MV>'
DP_PJNZ_AgeDistribTag                      = '<AgeDistrib MV>'
DP_PJNZ_ProgressionTag                     = '<Progression MV>'
DP_PJNZ_UseFYrSingleAgesTag2               = '<UseFYrSingleAges MV2>'
DP_PJNZ_EnterCOVID19DeathsTag              = '<EnterCOVID19DeathsTag>'
DP_PJNZ_NumOfEPPEpidemicsTag               = '<NumOfEPPEpidemics MV>'
DP_PJNZ_PrevEpidemicRGIdxTag	              =	'<PrevEpidemicRGIdx MV>'
DP_PJNZ_PMTCTPerNumTag                     = '<PMTCTPerNum MV>'
DP_PJNZ_EPPCountryNameTag                  = '<EPPCountryName MV>'
DP_PJNZ_EPPEpiNameTag                      = '<EPPEpiName MV>'
DP_PJNZ_EPPEpidemicTag                     = '<EPPEpidemic MV>'
DP_PJNZ_EPPPrevDataTag                     = '<EPPPrevData MV>'
DP_PJNZ_EPPIncDataTag	                    =	'<EPPIncData MV>'
DP_PJNZ_EPPPopDataTag	                    =	'<EPPPopData MV>'
DP_PJNZ_EPPSexRatioTag	                    =	'<EPPSexRatio MV>'
DP_PJNZ_EPPBaseYrPopTag                    = '<EPPBaseYrPop MV>'
DP_PJNZ_EPPIDUMortalityTag                 = '<EPPIDUMortality MV>'
DP_PJNZ_EPPPathInfoTag                  	  =	'<EPPPathInfo MV>'
DP_PJNZ_HIVPopByRiskGroupTag	              =	'<HIVPopByRiskGroup MV>'
DP_PJNZ_ARTExpUninfChildrenTag	            =	'<ARTExpUninfChildren MV>'
DP_PJNZ_HIVExpUninfChildrenTag	            =	'<HIVExpUninfChildren MV>'
DP_PJNZ_NewHIVInfByRiskGroupTag	          =	'<NewHIVInfByRiskGroup MV>'
DP_PJNZ_ChAged14ByCD4CatTag	              =	'<ChAged14ByCD4Cat MV>'
DP_PJNZ_DHSYr3IDTag                        = '<DHSYr3ID MV>'
DP_PJNZ_FitIncidenceProgDataTag           	=	'<FitIncidenceProgData MV>'
DP_PJNZ_FitIncidenceProgDataTag2          	=	'<FitIncidenceProgData MV2>'
DP_PJNZ_SurveyYearIndexTag                 = '<SurveyYearIndex MV>'
DP_PJNZ_FemalePrevalenceTag                = '<FemalePrevalence MV>'
DP_PJNZ_HIVChildNoARTByInfectionTag	      =	'<HIVChildNoARTByInfection MV>'
DP_PJNZ_TreatPercentTag	                  =	'<TreatPercent MV>'
DP_PJNZ_CountryProjUsedBySubNatRegionTag	  =	'<CountryProjUsedBySubNatRegion MV>'
DP_PJNZ_CountryProjBigPopTag	              =	'<CountryProjBigPop MV>'
DP_PJNZ_YrPtPrevalence_WBTag2              = '<YrPtPrevalence_WB MV2>'
DP_PJNZ_PropIDU_WBTag	                    =	'<PropIDU_WB MV>'
DP_PJNZ_PrevIncid15PlusTag2                = '<PrevIncid15Plus MV2>'
DP_PJNZ_AIDSBirthsTag                    	=	'<AIDSBirths MV>'
DP_PJNZ_NewInfantInfectionsTag             = '<NewInfantInfections MV>'
DP_PJNZ_HIVPop1517Tag                      = '<HIVPop1517 MV>'
DP_PJNZ_ChildARTNeed1To4Tag                = '<ChildARTNeed1To4 MV>'
DP_PJNZ_ARTNeedUnder2Tag2	                =	'<HIV+ Children Under 2 MV2>'
DP_PJNZ_CD4DistributionTag	                =	'<CD4Distribution MV>'
DP_PJNZ_CD4DistributionTag2                =	'<CD4Distribution MV2>'
DP_PJNZ_CD4Distribution15_49Tag	          =	'<CD4Distribution15_49 MV>'
DP_PJNZ_CD4Distribution15_49Tag2           =	'<CD4Distribution15_49 MV2>'
DP_PJNZ_CD4DistributionNoARTChildTag2      =	'<CD4DistributionNoARTChild MV2>'
DP_PJNZ_CD4DistributionWithARTChildTag2 	  =	'<CD4DistributionWithARTChild MV2>'
DP_PJNZ_ARTCalcTag2                        = '<ARTCalc MV2>'
DP_PJNZ_ARTCalc_15PlusTag2                 = '<ARTCalc_15Plus MV2>'
DP_PJNZ_DefaultUPDLETag                    = '<DefaultUPDLE MV>'
DP_PJNZ_UPDSourcesTag		                  =	'<UPDSources MV>'
DP_PJNZ_HIVPos15YearOldsTag             	  =	'<HIVPos15YearOlds MV>'
DP_PJNZ_BirthsTag	                        =	'<Births MV>'
DP_PJNZ_DeathsTag2	                        =	'<Deaths MV2>'
DP_PJNZ_DeathsByAgeTag2                    = '<DeathsByAge MV2>'
DP_PJNZ_HIVBySingleAgeTag2	                =	'<HIVBySingleAge MV2>'
DP_PJNZ_IMRTag2		                        =	'<IMR MV2>'
DP_PJNZ_DefaultUPDIMRTag                   = '<DefaultUPDIMR MV>'
DP_PJNZ_CMRTag2                            = '<CMR MV2>'
DP_PJNZ_DefaultUPDCMRTag                   = '<DefaultUPDCMR MV>'
DP_PJNZ_AdultDeathsTag                     = '<AdultDeaths MV>'
DP_PJNZ_SurvRateTag2                       = '<SurvRate MV2>'
DP_PJNZ_DefaultUPDSurvRateTag              = '<DefaultUPDSurvRate MV>'
DP_PJNZ_RegionalOutputTag2                 = '<RegionalOutput MV2>'
DP_PJNZ_TransParamRGTag                    = '<TransParamRG MV>'
DP_PJNZ_ImpactCalculatedTag	              =	'<ImpactCalculated MV>'
DP_PJNZ_NumChildOnARTByAgeTag2	            =	'<NumChildOnARTByAge MV2>'
DP_PJNZ_NumChildOnARTUnder1Tag             =	'<NumChildOnARTUnder1 MV>'
DP_PJNZ_Prop350_500Tag2                    = '<Prop350_500 MV2>'
DP_PJNZ_AIDSMortAllAgesFYrAdjIdxTag	      =	'<AIDSMortAllAgesFYrAdjIdx MV>'
DP_PJNZ_AIDSDeathsNoIntervTag	            =	'<AIDSDeathsNoInterv MV>'
DP_PJNZ_OrphansTag2	                 	    =	'<Orphans DP MV2>'
DP_PJNZ_AgeLastBDayTag2                    =	'<AgeLastBDay MV2>'
DP_PJNZ_CalcStateDataTag2	                =	'<CalcStateData MV2>'
DP_PJNZ_CalcStateDataTag3	                =	'<CalcStateData MV3>'
DP_PJNZ_IncidenceAdjustmentFactor2012Tag	  =	'<IncidenceAdjustmentFactor2012 MV>'
DP_PJNZ_FirstYearChangedPercentTag         = '<FirstYearChangedPercent MV>'
DP_PJNZ_EdAdSourceTag                      = '<EdAdSource MV>'
DP_PJNZ_EdDmSourceTag                      = '<EdDmSource MV>'
DP_PJNZ_EdPmSourceTag                      = '<EdPmSource MV>'
DP_PJNZ_PopAdjTag                          = '<PopAdj MV>'
DP_PJNZ_PopAdjAmountTag                    = '<PopAdjAmount MV>'
DP_PJNZ_PeriInfTag                         = '<PerinatalInfection MV>'
DP_PJNZ_SexuallyActive15to19Tag            = '<SexuallyActive15to19 MV>'
DP_PJNZ_SexuallyActive15to19Tag2           = '<SexuallyActive15to19 MV2>'
DP_PJNZ_HIVSexRatioTag                     = '<HIVSexRatio MV>'
DP_PJNZ_ARTTreatFitHIVSexRatioTag          = '<ARTTreatFitHIVSexRatio MV>'
DP_PJNZ_CSAVRHIVSexRatioTag                = '<CSAVRHIVSexRatio MV>'
DP_PJNZ_CSAVRHIVSexRatioTag2               = '<CSAVRHIVSexRatio MV2>'
DP_PJNZ_CSAVRHIVSexRatioTag3               = '<CSAVRHIVSexRatio MV3'
DP_PJNZ_HIVSexRatioFittingValuesTag        = '<HIVSexRatioFittingValues MV>'
DP_PJNZ_SexRatioByEpidPattTag              = '<SexRatioByEpidPatt MV>'
DP_PJNZ_FittingAICDataTag                  = '<FittingAICData MV>'
DP_PJNZ_ARTTreatFittingDataTag             = '<ARTTreatFittingData MV>'
DP_PJNZ_DistOfHIVTag2                      = '<DistOfHIV MV2>'
DP_PJNZ_ARTTreatFitDistOfHIVTag            = '<ARTTreatFit MV>'
DP_PJNZ_CSAVRDistOfHIVTag                  = '<CSAVRDistOfHIV MV>'
DP_PJNZ_CSAVRDistOfHIVTag2                 = '<CSAVRDistOfHIV MV2>'
DP_PJNZ_IRRFittingValuesTag                = '<IRRFittingValues MV>'
DP_PJNZ_FitIncIdxTag                       = '<FitIncidenceIndex MV>'
DP_PJNZ_IncEpidemicRGIdxTag                = '<IncEpidemicRGIdx MV>'
DP_PJNZ_IncEpidemicCustomFlagIdxTag        = '<IncEpidemicCustomFlagIdx MV>'
DP_PJNZ_SAPFitTypeTag                      = '<SAPFitType MV>'
DP_PJNZ_HIVPrevModelTag                    = '<HIVPrevModel MV>'
DP_PJNZ_CalcStateDataTag	                  =	'<CalcStateData MV>'
DP_PJNZ_YrPtPrevalence_WBTag               = '<YrPtPrevalence_WB MV>'
DP_PJNZ_IMRTag		                          =	'<IMR MV>'
DP_PJNZ_CMRTag                             = '<CMR MV>'
DP_PJNZ_ARTCalcTag                         = '<ARTCalc MV>'
DP_PJNZ_ARTCalc_15PlusTag                  = '<ARTCalc_15Plus MV>'
DP_PJNZ_ModelLifeFileNameTag               = '<ModelLifeFileName MV>'
DP_PJNZ_UseFYrSingleAgesTag                = '<UseFYrSingleAges MV>'
DP_PJNZ_AgeLastBDayTag                  	  =	'<AgeLastBDay MV>'
DP_PJNZ_OrphansTag	                 	      =	'<Orphans DP MV>'
DP_PJNZ_HIVBySingleAgeTag	                =	'<HIVBySingleAge MV>'
DP_PJNZ_SurvRateTag                        = '<SurvRate MV>'
DP_PJNZ_DistOfHIVTag                       = '<DistOfHIV MV>'
DP_PJNZ_DeathsTag	                        =	'<Deaths MV>'
DP_PJNZ_DeathsByAgeTag                     = '<DeathsByAge MV>'
DP_PJNZ_NumChildOnARTByAgeTag	            =	'<NumChildOnARTByAge MV>'
DP_PJNZ_RegionalOutputTag                  = '<RegionalOutput MV>'
DP_PJNZ_CD4DistributionWithARTChildTag  	  =	'<CD4DistributionWithARTChild MV>'
DP_PJNZ_PrevIncid15PlusTag                 = '<PrevIncid15Plus MV>'
DP_PJNZ_ARTNeedUnder2Tag	                  =	'<HIV+ Children Under 2 MV>'
DP_PJNZ_CD4DistributionNoARTChildTag    	  =	'<CD4DistributionNoARTChild MV>'
DP_PJNZ_FinalYearTag                       = '<FinalYear MV>'
DP_PJNZ_ProjectionValidTag                 = '<ProjectionValid MV>'
DP_PJNZ_VersionNumTag                      = '<VersionNum MV>'
DP_PJNZ_FileTitleTag                       = '<FileTitle MV>'
DP_PJNZ_Prop350_500Tag                     = '<Prop350_500 MV>'
