IH_IVG_MaternalNewbornHealth_MST_ID = '1'
IH_IVG_SexualReprodHealth_MST_ID = '111'
IH_IVG_ChildHealth_MST_ID = '15'
IH_IVG_Vaccination_MST_ID = '20'
IH_IVG_Malaria_MST_ID = '21'
IH_IVG_TB_MST_ID = '22'
IH_IVG_HIVAIDS_MST_ID = '23'
IH_IVG_Nutrition_MST_ID = '28'
IH_IVG_WASH_MST_ID = '29'
IH_IVG_NoncommunicableDiseases_MST_ID = '30'
IH_IVG_MentalNueroSubsUseDis_MST_ID = '42'
IH_IVG_AdolescentHealth_MST_ID = '73'
IH_IVG_NegTropDiseases_MST_ID = '74'
IH_PROG_AREA_MST_IDS = [IH_IVG_MaternalNewbornHealth_MST_ID, IH_IVG_SexualReprodHealth_MST_ID, IH_IVG_ChildHealth_MST_ID, IH_IVG_Vaccination_MST_ID, IH_IVG_Malaria_MST_ID, IH_IVG_TB_MST_ID, IH_IVG_HIVAIDS_MST_ID, IH_IVG_Nutrition_MST_ID, IH_IVG_WASH_MST_ID, IH_IVG_NoncommunicableDiseases_MST_ID, IH_IVG_MentalNueroSubsUseDis_MST_ID, IH_IVG_AdolescentHealth_MST_ID, IH_IVG_NegTropDiseases_MST_ID]