IC_IV_ContraceptiveUse_MST_ID = '47'
IC_IV_FolicAcidSupp_MST_ID = '7'
IC_IV_SafeAbortServ_MST_ID = '73'
IC_IV_PostAbortCaseMgmt_MST_ID = '170'
IC_IV_EctopicPregCaseMgmt_MST_ID = '171'
IC_IV_BlanketIronSuppFort_MST_ID = '446'
IC_IV_PillStdDailyReg_MST_ID = '95'
IC_IV_PillProgestin_MST_ID = '380'
IC_IV_PillPCC_MST_ID = '381'
IC_IV_CondomM_MST_ID = '96'
IC_IV_CondomF_MST_ID = '373'
IC_IV_InjectableDepo_MST_ID = '97'
IC_IV_InjectableNor_MST_ID = '374'
IC_IV_InjectableLun_MST_ID = '375'
IC_IV_Injectable6mo_MST_ID = '376'
IC_IV_InjectableUniject_MST_ID = '377'
IC_IV_IUD_Copper_MST_ID = '98'
IC_IV_IUD_LNG_IUS_MST_ID = '382'
IC_IV_ImplantJad_MST_ID = '99'
IC_IV_ImplantImp_MST_ID = '378'
IC_IV_ImplantSin_MST_ID = '379'
IC_IV_FSterilization_MST_ID = '100'
IC_IV_MSterilization_MST_ID = '101'
IC_IV_LAM_MST_ID = '102'
IC_IV_SDM_MST_ID = '383'
IC_IV_VagBarrier_MST_ID = '103'
IC_IV_VagTabs_MST_ID = '104'
IC_IV_PeriAbstinence_MST_ID = '384'
IC_IV_Widthdrawal_MST_ID = '385'
IC_IV_TraditionalNotSpec_MST_ID = '386'
IC_IV_OtherContraceptives_MST_ID = '105'
IC_IV_TetToxVacc_MST_ID = '4'
IC_IV_IPT_Mal_MST_ID = '3'
IC_IV_SyphDetectTr_MST_ID = '1'
IC_IV_CalciumSupp_MST_ID = '72'
IC_IV_Omeg3FASupp_MST_ID = '533'
IC_IV_AspirinLowDose_MST_ID = '529'
IC_IV_Progesterone_MST_ID = '530'
IC_IV_IronSuppPreg_MST_ID = '235'
IC_IV_MultiMicronSuppPreg_MST_ID = '9'
IC_IV_BalEnergySupp_MST_ID = '8'
IC_IV_HyperDisCaseMgmt_MST_ID = '82'
IC_IV_DiabCaseMgmt_MST_ID = '87'
IC_IV_MalCaseMgmt_MST_ID = '172'
IC_IV_MgSO4MgmtPreEclampsia_MST_ID = '81'
IC_IV_FGRDetMgmt_MST_ID = '91'
IC_IV_PMTCT_MST_ID = '14'
IC_IV_ThermalCare_MST_ID = '168'
IC_IV_DelayedCordClamp_MST_ID = '535'
IC_IV_CleanCordCare_MST_ID = '255'
IC_IV_CleanBirthEnvironment_MST_ID = '11'
IC_IV_ImmDryAndAdditionalStim_MST_ID = '174'
IC_IV_PrerefMgmtLabor_MST_ID = '109'
IC_IV_TrPostpartHemor_MST_ID = '112'
IC_IV_NeoResusc_MST_ID = '15'
IC_IV_CortPretermLabor_MST_ID = '5'
IC_IV_AntipPRoM_MST_ID = '6'
IC_IV_MgSO4ForEclampsia_MST_ID = '83'
IC_IV_ParenteralAdminOfUter_MST_ID = '62'
IC_IV_ParenteralAdminOfAntibiotics_MST_ID = '505'
IC_IV_AssisVagDeliv_MST_ID = '506'
IC_IV_ManualRemovOfPlacent_MST_ID = '507'
IC_IV_RemovOfRetainProdOfConcep_MST_ID = '508'
IC_IV_SurgeryChildbirth_MST_ID = '509'
IC_IV_BloodTransfusion_MST_ID = '510'
IC_IV_InductionOfLabour_MST_ID = '94'
IC_IV_KangarooMothCare_MST_ID = '16'
IC_IV_FullSuppCarePremat_MST_ID = '322'
IC_IV_iKMC_MST_ID = '547'
IC_IV_ChangesInBF_MST_ID = '17'
IC_IV_CompFeedEOnly_MST_ID = '18'
IC_IV_CompFeedSE_MST_ID = '19'
IC_IV_NNVitASupp_MST_ID = '540'
IC_IV_VitASupp_MST_ID = '46'
IC_IV_ZincSupp_MST_ID = '24'
IC_IV_BasicSanitation_MST_ID = '42'
IC_IV_PointOfUseFilteredWater_MST_ID = '40'
IC_IV_PipedWater_MST_ID = '41'
IC_IV_HandWashWSoap_MST_ID = '43'
IC_IV_HygDisposalStools_MST_ID = '44'
IC_IV_ITN_IRS_MST_ID = '22'
IC_IV_BCG_Vacc_MST_ID = '49'
IC_IV_PolioVacc_MST_ID = '34'
IC_IV_PentaVacc_MST_ID = '175'
IC_IV_DPT_Vacc_MST_ID = '33'
IC_IV_HibVacc_MST_ID = '25'
IC_IV_HepBVacc_MST_ID = '167'
IC_IV_PneuVacc_MST_ID = '26'
IC_IV_RotavirusVacc_MST_ID = '45'
IC_IV_MeningA_MST_ID = '191'
IC_IV_MalVacc_MST_ID = '251'
IC_IV_MeasVacc_MST_ID = '21'
IC_IV_HPV_Vacc_MST_ID = '132'
IC_IV_CovidVacc_MST_ID = '679'
IC_IV_CholeraVacc_MST_ID = '680'
IC_IV_DengueVacc_MST_ID = '681'
IC_IV_EbolaVacc_MST_ID = '682'
IC_IV_HepAVacc_MST_ID = '683'
IC_IV_JapEncephVacc_MST_ID = '684'
IC_IV_RabiesVacc_MST_ID = '685'
IC_IV_SeasInfluenzaVacc_MST_ID = '686'
IC_IV_TetToxVaccImmunization_MST_ID = '687'
IC_IV_TickEncephVacc_MST_ID = '688'
IC_IV_TyphoidVacc_MST_ID = '689'
IC_IV_VaricellaVacc_MST_ID = '690'
IC_IV_YellowFeverVacc_MST_ID = '691'
IC_IV_CampaignCholeraVacc_MST_ID = '692'
IC_IV_CampaignMeaslesVacc_MST_ID = '693'
IC_IV_CampaignMeningitisVacc_MST_ID = '694'
IC_IV_CampaignPolioVacc_MST_ID = '695'
IC_IV_CampaignTetanusVacc_MST_ID = '696'
IC_IV_CampaignTyphoidVacc_MST_ID = '697'
IC_IV_CampaignYellowFeverVacc_MST_ID = '698'
IC_IV_MatSepsisCaseMgmt_MST_ID = '173'
IC_IV_OralAntibNeonSeps_MST_ID = '69'
IC_IV_InjectAntibNeonSeps_MST_ID = '70'
IC_IV_FullSuppCareNeonSepsPneu_MST_ID = '13'
IC_IV_ORS_MST_ID = '27'
IC_IV_AntibTrDysentery_MST_ID = '28'
IC_IV_ZincTrDiar_MST_ID = '29'
IC_IV_OralAntibPneu_MST_ID = '30'
IC_IV_OxAndPulseOxiForPneum_MST_ID = '528'
IC_IV_VitATrMeas_MST_ID = '31'
IC_IV_CaseMgmtMalTreat_MST_ID = '658'
IC_IV_ACTsMal_MST_ID = '32'
IC_IV_SAM_MST_ID = '71'
IC_IV_TrMAM_MST_ID = '237'
IC_IV_ART_MST_ID = '36'
IC_IV_PregWSleepITN_MST_ID = '135'
IC_IV_IndoorResidSpray_MST_ID = '136'
IC_IV_VectorCtrlOther_MST_ID = '319'
IC_IV_Larviciding_MST_ID = '320'
IC_IV_SeasMalChemoproph_MST_ID = '479'
IC_IV_MalDiagMalFevers_MST_ID = '318'
IC_IV_MalDiagNonMalFevers_MST_ID = '483'
IC_IV_MalTrCh5t14_MST_ID = '480'
IC_IV_MalTrAdExclPregW_MST_ID = '126'
IC_IV_TrSevMalFivePlus_MST_ID = '481'
IC_IV_TrNonMalParasPosFevers_MST_ID = '454'
IC_IV_WorkplaceVisit_MST_ID = '350'
IC_IV_CaseMgmtWorkDiseases_MST_ID = '351'
IC_IV_HealthAssessRetWork_MST_ID = '352'
IC_IV_IntervFocSexWorkersF_MST_ID = '147'
IC_IV_FSW_PrEP_MST_ID = '628'
IC_IV_IntervFocSexWorkersM_MST_ID = '253'
IC_IV_MSW_PrEP_MST_ID = '629'
IC_IV_IntervFocMSM_MST_ID = '148'
IC_IV_MSM_PrEP_MST_ID = '630'
IC_IV_TransgenderHIV_Prev_MST_ID = '631'
IC_IV_TransgenderPrEP_MST_ID = '632'
IC_IV_IDUOutreach_MST_ID = '149'
IC_IV_PWID_PrEP_MST_ID = '633'
IC_IV_IDUNeedleExchange_MST_ID = '196'
IC_IV_IDUDrugSubstit_MST_ID = '197'
IC_IV_PrisonersPrEP_MST_ID = '634'
IC_IV_PrisonersNSEP_MST_ID = '635'
IC_IV_STI_Treatment_MST_ID = '636'
IC_IV_Condoms_MST_ID = '140'
IC_IV_AGYW_PrEP_MST_ID = '637'
IC_IV_YouthFocIntervOutSch_MST_ID = '145'
IC_IV_MaleCircumcision_MST_ID = '141'
IC_IV_AdultFemalePrEP_MST_ID = '638'
IC_IV_AdultMalePrEP_MST_ID = '639'
IC_IV_PostExposProphylaxis_MST_ID = '151'
IC_IV_VolCounsTest_MST_ID = '139'
IC_IV_ART_M_MST_ID = '240'
IC_IV_ART_W_MST_ID = '241'
IC_IV_EconEmpowerCashTransfers_MST_ID = '640'
IC_IV_ScreenRiskCVD_Diab_MST_ID = '199'
IC_IV_FollowUpCareLR_CVD_Diab_MST_ID = '200'
IC_IV_TrHighCholLR_CVD_Diab_MST_ID = '201'
IC_IV_TrHighBloodPresLR_CVD_Diab_MST_ID = '202'
IC_IV_TrCVD_DiabRisk20To30_MST_ID = '203'
IC_IV_TrCVD_DiabRiskGT30_MST_ID = '204'
IC_IV_TrNewCasesAMI_Aspirin_MST_ID = '205'
IC_IV_TrIHD_PostMI_MST_ID = '206'
IC_IV_TrCerebrovascDisPostStroke_MST_ID = '207'
IC_IV_TrRheumHrtDisBenzPenic_MST_ID = '208'
IC_IV_StdGlycCtrl_MST_ID = '344'
IC_IV_IntensGlycCtrl_MST_ID = '345'
IC_IV_RetinopScreenPhotocoag_MST_ID = '346'
IC_IV_NeuropScreenPrevFootCare_MST_ID = '347'
IC_IV_ElimIndustrialTransFats_MST_ID = '485'
IC_IV_BasicBreastCancerAware_MST_ID = '225'
IC_IV_ScrClinBreastExam_MST_ID = '120'
IC_IV_ScrMammography_MST_ID = '226'
IC_IV_DiagScrClinBreastExam_MST_ID = '442'
IC_IV_DiagScrMammogram_MST_ID = '443'
IC_IV_DiagNoScrBreastCancer_MST_ID = '444'
IC_IV_BreastCancerTrS1_MST_ID = '227'
IC_IV_BreastCancerTrS2_MST_ID = '228'
IC_IV_BreastCancerTrS3_MST_ID = '229'
IC_IV_BreastCancerTrS4_MST_ID = '230'
IC_IV_Trastuzamab_MST_ID = '445'
IC_IV_PostTrSurvBreastCancerPat_MST_ID = '236'
IC_IV_BasicPallCareBreastCancer_MST_ID = '231'
IC_IV_ExtendPallCareBreastCancer_MST_ID = '232'
IC_IV_HPV_DNATest_MST_ID = '413'
IC_IV_VisualInspectAceticAcid_MST_ID = '414'
IC_IV_PapTest_MST_ID = '415'
IC_IV_HPV_DNA_VIA_MST_ID = '416'
IC_IV_HPV_DNA_PapSmear_MST_ID = '417'
IC_IV_BiopsyHistopathology_MST_ID = '418'
IC_IV_Cryotherapy_MST_ID = '419'
IC_IV_LEEP_MST_ID = '420'
IC_IV_CervCancerTrS1_MST_ID = '213'
IC_IV_CervCancerTrS2_MST_ID = '421'
IC_IV_CervCancerTrS3_MST_ID = '422'
IC_IV_CervCancerTrS4_MST_ID = '423'
IC_IV_PostTrSurvCervCancer_MST_ID = '424'
IC_IV_BasicPallCareCervCancer_MST_ID = '425'
IC_IV_ExtendPallCareCervCancer_MST_ID = '426'
IC_IV_ScrFecalImmChemTest_MST_ID = '427'
IC_IV_ScrFecalOccultBloodTest_MST_ID = '428'
IC_IV_ScrSigmoidoscopy_MST_ID = '429'
IC_IV_ScrColonoscopy_MST_ID = '430'
IC_IV_DiagColorCancerScrFIT_MST_ID = '431'
IC_IV_DiagColorCancerScrFOBT_MST_ID = '432'
IC_IV_DiagColorCancerScrSigm_MST_ID = '433'
IC_IV_DiagNoScrColorCancer_MST_ID = '434'
IC_IV_ColorCancerTrS1_MST_ID = '435'
IC_IV_ColorCancerTrS2_MST_ID = '436'
IC_IV_ColorCancerTrS3_MST_ID = '437'
IC_IV_ColorCancerTrS4_MST_ID = '438'
IC_IV_PostTrSurvColorCancer_MST_ID = '439'
IC_IV_BasicPallCareColorCancer_MST_ID = '440'
IC_IV_ExtendPallCareColorCancer_MST_ID = '441'
IC_IV_DentalCleanPrevCare_MST_ID = '218'
IC_IV_OralCancerTr_MST_ID = '221'
IC_IV_AsthmaSABA_Interm_MST_ID = '332'
IC_IV_AsthmaLDBeclSABA_MST_ID = '333'
IC_IV_AsthmaHDBeclSABA_MST_ID = '334'
IC_IV_AsthmaTheoHDBeclSABA_MST_ID = '335'
IC_IV_AsthmaPrednTheoHDBeclSABA_MST_ID = '336'
IC_IV_COPD_SmokingCessation_MST_ID = '337'
IC_IV_COPD_InhSalbut_MST_ID = '338'
IC_IV_COPD_LDTheo_MST_ID = '339'
IC_IV_COPD_IpraInhaler_MST_ID = '340'
IC_IV_COPD_ExcacerbTrAntib_MST_ID = '341'
IC_IV_COPD_ExcacerbTrPredn_MST_ID = '342'
IC_IV_COPD_ExcacerbTrOxy_MST_ID = '343'
IC_IV_AvgAnnEmerCareNeeds_MST_ID = '224'
IC_IV_RFsHelpQuitTobUse_MST_ID = '387'
IC_IV_RFsScrBriefIntervAlc_MST_ID = '388'
IC_IV_RFsPhysInactBriefAdvice_MST_ID = '389'
IC_IV_TobMonUsePrevPolicies_MST_ID = '390'
IC_IV_TobSmokeProtection_MST_ID = '391'
IC_IV_TobHelpToQuitMCess_MST_ID = '392'
IC_IV_TobWarningLabels_MST_ID = '393'
IC_IV_TobWarnViaMassMedia_MST_ID = '394'
IC_IV_TobEnforceBansAdvertis_MST_ID = '395'
IC_IV_TobEnforceYouthRestr_MST_ID = '396'
IC_IV_TobRaiseTaxes_MST_ID = '397'
IC_IV_TobPlainPackaging_MST_ID = '398'
IC_IV_AlcEnforceAvail_MST_ID = '399'
IC_IV_AlcEnforceRestrictAdvertis_MST_ID = '400'
IC_IV_AlcEnforceDrunkDrivLaws_MST_ID = '401'
IC_IV_AlcRaiseTaxes_MST_ID = '402'
IC_IV_PhysInactAwareCamp_MST_ID = '403'
IC_IV_NaSurv_MST_ID = '404'
IC_IV_NaIndustryReform_MST_ID = '405'
IC_IV_NaStdsFrontPackLab_MST_ID = '406'
IC_IV_NaStdsStratMisleadMarketing_MST_ID = '407'
IC_IV_NaEduComm_MST_ID = '408'
IC_IV_NaReductCommSpaces_MST_ID = '409'
IC_IV_ObesNoTransFats_MST_ID = '410'
IC_IV_ObesReplaceSaturFats_MST_ID = '411'
IC_IV_ObesTaxSugaryDrinks_MST_ID = '412'
IC_IV_AnxBasicPsychTrMild_MST_ID = '328'
IC_IV_AnxBasicPsychTrMed_MST_ID = '329'
IC_IV_AnxIntensPsychTrMed_MST_ID = '330'
IC_IV_DeprBasicPsychTrMild_MST_ID = '325'
IC_IV_DeprBasicPsychTrMed_MST_ID = '288'
IC_IV_DeprIntensPsychTrMed_MST_ID = '289'
IC_IV_DeprIntensPsychTrMedEpB_MST_ID = '348'
IC_IV_DeprIntensPsychTrMedMnB_MST_ID = '349'
IC_IV_DeprPsychCarePerinatal_MST_ID = '260'
IC_IV_PsychBasicPsychSuppMed_MST_ID = '290'
IC_IV_PsychIntensPsychSuppMed_MST_ID = '291'
IC_IV_BipDisBasicPsychTrMed_MST_ID = '264'
IC_IV_BipDisIntensPsychIntervMed_MST_ID = '267'
IC_IV_EpilBasicPsychSuppMed_MST_ID = '292'
IC_IV_DevDisBasicPsychTr_MST_ID = '270'
IC_IV_DevDisIntensPsychInterv_MST_ID = '271'
IC_IV_BehDisBasicPsychTr_MST_ID = '272'
IC_IV_BehDisIntensPsychInterv_MST_ID = '273'
IC_IV_FamPsychADHD_MST_ID = '326'
IC_IV_FamPsychCondDis_MST_ID = '327'
IC_IV_MethylphenidateMed_MST_ID = '274'
IC_IV_DemAssessDiagFollowUp_MST_ID = '275'
IC_IV_DemPharmTr_MST_ID = '276'
IC_IV_AlcIdAssessNewCases_MST_ID = '277'
IC_IV_AlcBriefIntervFollowUp_MST_ID = '278'
IC_IV_MgmtAlcWd_MST_ID = '279'
IC_IV_AlcRelapsePrevMed_MST_ID = '280'
IC_IV_DrugIdAssessNewCases_MST_ID = '281'
IC_IV_DrugBriefIntervFollowUp_MST_ID = '282'
IC_IV_MgmtOpioidWd_MST_ID = '283'
IC_IV_MgmtNonOpioidWd_MST_ID = '284'
IC_IV_SelfHarmAssessCare_MST_ID = '285'
IC_IV_SelfHarmBasicPsychTr_MST_ID = '286'
IC_IV_PestIntoxMgmt_MST_ID = '287'
IC_IV_VisionScr_MST_ID = '447'
IC_IV_TdVaccCoDelivery_MST_ID = '448'
IC_IV_InjuryCareIPVPhysAssault_MST_ID = '449'
IC_IV_InjuryCareIPVSexAssault_MST_ID = '450'
IC_IV_ContracNotInUnionLT15_MST_ID = '451'
IC_IV_MgmtCondPrimaryCare_MST_ID = '452'
IC_IV_SchistCh_MST_ID = '455'
IC_IV_SchistAd_MST_ID = '456'
IC_IV_SoilTransHelm_MST_ID = '457'
IC_IV_Onchocer_MST_ID = '458'
IC_IV_LymphFilar_MST_ID = '459'
IC_IV_Trachoma_MST_ID = '460'
IC_IV_YawsTCT_MST_ID = '461'
IC_IV_BuruliUlcer_MST_ID = '462'
IC_IV_CutanLeishman_MST_ID = '463'
IC_IV_VisceralLeishman_MST_ID = '464'
IC_IV_HumanAfricTrypan_MST_ID = '465'
IC_IV_Leprosy_MST_ID = '466'
IC_IV_Echinoc_MST_ID = '467'
IC_IV_ChagasDisease_MST_ID = '468'
IC_IV_LymphFilarHydroSurgery_MST_ID = '469'
IC_IV_Trichiasis_MST_ID = '470'
IC_IV_LymphedemaMgmt_MST_ID = '471'
IC_IV_Yaws_MST_ID = '472'
IC_IV_AedesAegMosquito_MST_ID = '473'
IC_IV_Blackflies_MST_ID = '474'
IC_IV_Sandflies_MST_ID = '475'
IC_IV_TriatomineBugs_MST_ID = '476'
IC_IV_RabiesVaccCanine_MST_ID = '477'
IC_IV_RabiesPostExpProph_MST_ID = '478'
IC_IV_ScreenProvInitPLHIV_GTE10YrsOnART_NotIll_MST_ID = '641'
IC_IV_ScreenProvInitPLHIV_Children0t9_MST_ID = '551'
IC_IV_ScreenProvInitPLHIV_GTE10YrsInpat_MST_ID = '550'
IC_IV_ScreenProvInitPLHIV_Children0t9Inpat_MST_ID = '674'
IC_IV_ScreenProvInitHHAdults15Plus_MST_ID = '555'
IC_IV_ScreenProvInitHHChildren0t14_MST_ID = '552'
IC_IV_ScreenProvInitHHChildren0t4_MST_ID = '553'
IC_IV_ScreenProvInitHHChildren5t14_MST_ID = '554'
IC_IV_ScreenProvInitPrisoners_MST_ID = '556'
IC_IV_ScreenProvInitMiners_MST_ID = '557'
IC_IV_ScreenProvInitFibroticLesions_MST_ID = '558'
IC_IV_ScreenProvInitRiskFactorsGTE_P1PercTBPrev_MST_ID = '559'
IC_IV_ScreenProvInitRiskFactorsLmtdHlthCare_MST_ID = '560'
IC_IV_ScreenProvInitGenPop_MST_ID = '561'
IC_IV_TBCaseFindPatInitAdults_MST_ID = '675'
IC_IV_TBCaseFindPatInitChildren_MST_ID = '676'
IC_IV_DiagPatInitPulmTBAdults_MST_ID = '574'
IC_IV_DiagPatInitPulmTBChildren_MST_ID = '576'
IC_IV_DiagPatInitExtraPulmTBAdults_MST_ID = '575'
IC_IV_DiagPatInitExtraPulmTBChildren_MST_ID = '577'
IC_IV_DiagProvInitPulmTB_PLHIV_Outpat_MST_ID = '580'
IC_IV_DiagProvInitPulmTB_PLHIV_Inpat_MST_ID = '581'
IC_IV_DiagProvInitPulmTB_PLHIV_ChildrenOutpat_MST_ID = '582'
IC_IV_DiagProvInitPulmTB_PLHIV_ChildrenInpat_MST_ID = '583'
IC_IV_DiagProvInitPulmTB_HHChildren_MST_ID = '579'
IC_IV_DiagProvInitPulmTBAllHRGsAdults_MST_ID = '578'
IC_IV_RifampIsonResistTest_MST_ID = '584'
IC_IV_IsonResistTestRifampSensCases_MST_ID = '585'
IC_IV_FluoroqResistTestRifampResistCases_MST_ID = '586'
IC_IV_RESIST_TEST_BEDAQ_LINEZ_LEVO_MOXI_MST_ID = '649'
IC_IV_TreatDrugSuscTBRifampIsonSensAdults_MST_ID = '597'
IC_IV_TreatDrugSuscTBRifampIsonSensChildren0t14_MST_ID = '598'
IC_IV_TreatDrugSuscTBRifampIsonSensChildren3MoTo16_MST_ID = '599'
IC_IV_TreatTBMeningPericardAdults_MST_ID = '600'
IC_IV_TreatDrugSuscTBMeningPericardChildren_MST_ID = '601'
IC_IV_NonMedTreatSuppPatFirstLine_MST_ID = '677'
IC_IV_TreatDrugResistTBRifampSensIsonResistAdults_MST_ID = '602'
IC_IV_TreatDrugResistTBRifampSensIsonResistChildren_MST_ID = '603'
IC_IV_BpalMOralBedaqRegDrugResistTBAdults_MST_ID = '604'
IC_IV_OralBedaqRegDrugResistTBChildren_MST_ID = '605'
IC_IV_BPalRegDrugResistTBAdults_MST_ID = '606'
IC_IV_LongerRegDrugResistTBTreatAdults_MST_ID = '607'
IC_IV_LongerRegDrugResistTBTreatChildren_MST_ID = '608'
IC_IV_TreatDrugResistTB_XDR_Adults_MST_ID = '609'
IC_IV_TreatDrugResistTB_XDR_Children_MST_ID = '610'
IC_IV_NonMedTreatSuppPatSecLine_MST_ID = '678'
IC_IV_TestLatentTB_HHContactAdults15Plus_MST_ID = '563'
IC_IV_TestLatentTB_HHContactChildren5t14_MST_ID = '562'
IC_IV_TestLatentTB_HHContactChildren0t4_MST_ID = '564'
IC_IV_TestLatentTBOtherHRGsAdults15Plus_MST_ID = '565'
IC_IV_TB_ORAL_PREV_MED_ADULTS_15_PLUS_MST_ID = '650'
IC_IV_TB_ORAL_PREV_MED_CHILDREN_0_14_MST_ID = '567'
IC_IV_TBOralPrevMedWRifampDrugResist_MST_ID = '569'
IC_IV_LungResectionSurgery_MST_ID = '673'
IC_IV_PalliativeCare_MST_ID = '625'
