# Input ModVars
LG_VERSION_TAG = "<LG_Version_V1>"
LG_DATA_CHANGED_TAG = "<LG_DataChanged_V1>"
LG_FILE_NAME_TAG = "<LG_FileName_V1>"
LG_PROJ_VALID_TAG = "<LG_ProjectionValid_V1>"
LG_PROJ_VALID_DATE_TAG = "<LG_ProjectionValidDate_V1>"
LG_SUPPLY_CHAIN_LEVEL_RECORDS_TAG = "<LG_SupplyChainLevelRecords_V1>"
LG_WAREHOUSE_RECORDS_TAG = "<LG_WarehouseRecords_V1>"
LG_DISAGGREGATION_LEVEL_TAG = "<LG_DisaggregationLevel_V1>"
LG_CALC_APPROACH_TAG = "<LG_CalcApproach_V1>"
LG_VEHICLE_TYPE_RECORDS_TAG = "<LG_VehicleTypeRecords_V1>"
LG_WORKER_TYPE_RECORDS_TAG = "<LG_WorkerTypeRecords_V1>"
LG_COLD_CHAIN_RECORDS_TAG = "<LG_ColdChainRecords_V1>"
LG_DEFAULT_COLD_CHAIN_RECORDS_MEGA_TAG = "<LG_DefaultColdChainRecordsMeta_V1>"
LG_COLD_CHAIN_TARG_CONFIG_OPTION_TAG = "<LG_ColdChainTargetConfigOption_V1>"
LG_THIRD_PARTY_LOG_CONTRACT_RECORDS_TAG = "<LG_ThirdPartyLogisticsContractRecords_V1>"
LG_ENTER_COMP_MAINT_OP_COSTS_VEHICLES_TAG = "<LG_EnterComponentMaintOpCostsVehicles_V1>"
LG_COST_FUEL_PER_LITER_TAG = "<LG_CostOfFuelPerLiter_V1>"
LG_ENTER_COMP_CONSTRUCT_COSTS_WAREHOUSES_TAG = "<LG_EnterComponentConstructCostsWarehouses_V1>"
LG_ENTER_COMP_OP_COSTS_WAREHOUSES_TAG = "<LG_EnterComponentOpCostsWarehouses_V1>"
LG_VEHICLE_TARG_CONFIG_OPTION_TAG = "<LG_VehicleTargetConfigOption_V1>"
LG_VEHICLE_TARG_VARY_TRIPS_PER_YEAR_TAG = "<LG_VehicleTargetVaryTripsPerYear_V1>"
LG_VEHICLE_PERFORMANCE_CONFIG_OPTION_TAG = "<LG_VehiclePerformanceConfigOption_V1>"
LG_NUM_WORK_HOURS_PER_DAY = "<LG_NumWorkHoursPerDay_V1>"
LG_NUM_WORK_DAYS_PER_YEAR = "<LG_NumWorkDaysPerYear_V1>"

# Output / Result ModVars

# Warehouses
LG_RES_NUM_WAREHOUSES_BY_LEVEL = "<LG_ResNumWarehousesByLevel_V1>"
LG_RES_NUM_WAREHOUSES_BY_WAREHOUSE = "<LG_ResNumWarehousesByWarehouse_V1>"
LG_RES_NUM_WAREHOUSES_BY_WAREHOUSE_BY_LEVEL = "<LG_ResNumWarehousesByWarehouseByLevel_V1>"
LG_RES_OPERATING_COSTS_BY_LEVEL = "<LG_ResWarehouseOperatingCostsByLevel_V1>"
LG_RES_OPERATING_COSTS_BY_WAREHOUSE = "<LG_ResWarehouseOperatingCostsByWarehouse_V1>"
LG_RES_OPERATING_COSTS_BY_WAREHOUSE_BY_LEVEL = "<LG_ResWarehouseOperatingCostsByWarehouseByLevel_V1>"
LG_RES_CONSTRUCTION_COSTS_BY_LEVEL = "<LG_ResWarehouseConstructionCostsByLevel_V1>"
LG_RES_CONSTRUCTION_COSTS_BY_WAREHOUSE = "<LG_ResWarehouseConstructionCostsByWarehouse_V1>"
LG_RES_CONSTRUCTION_COSTS_BY_WAREHOUSE_BY_LEVEL = "<LG_ResWarehouseConstructionCostsByWarehouseByLevel_V1>"
LG_RES_REHAB_COSTS_BY_LEVEL = "<LG_ResWarehouseRehabCostsByLevel_V1>"
LG_RES_REHAB_COSTS_BY_WAREHOUSE = "<LG_ResWarehouseRehabCostsByWarehouse_V1>"
LG_RES_REHAB_COSTS_BY_WAREHOUSE_BY_LEVEL = "<LG_ResWarehouseRehabCostsByWarehouseByLevel_V1>"
# Volume analytics
LG_RES_LABOR_UTILIZATION_BY_LEVEL = "<LG_ResLaborUtilizationByLevel_V1>"
LG_RES_LABOR_UTILIZATION_BY_WAREHOUSE = "<LG_ResLaborUtilizationByWarehouse_V1>"
LG_RES_LABOR_UTILIZATION_BY_WAREHOUSE_BY_LEVEL = "<LG_ResLaborUtilizationByWarehouseByLevel_V1>"
LG_RES_AVG_DEMAND_AMBIENT_BY_LEVEL = "<LG_ResAvgDemandAmbientByLevel_V1>"
LG_RES_AVG_DEMAND_AMBIENT_BY_WAREHOUSE = "<LG_ResAvgDemandAmbientByWarehouse_V1>"
LG_RES_AVG_DEMAND_AMBIENT_BY_WAREHOUSE_BY_LEVEL = "<LG_ResAvgDemandAmbientByWarehouseByLevel_V1>"
LG_RES_AVG_DEMAND_PER_PERIOD_AMBIENT_BY_LEVEL = "<LG_ResAvgDemandPerPeriodAmbientByLevel_V1>"
LG_RES_AVG_DEMAND_PER_PERIOD_AMBIENT_BY_WAREHOUSE = "<LG_ResAvgDemandPerPeriodAmbientByWarehouse_V1>"
LG_RES_AVG_DEMAND_PER_PERIOD_AMBIENT_BY_WAREHOUSE_BY_LEVEL = "<LG_ResAvgDemandPerPeriodAmbientByWarehouseByLevel_V1>"
LG_RES_AVG_SAFETY_STOCK_AMBIENT_BY_LEVEL = "<LG_ResAvgSafetyStockAmbientByLevel_V1>"
LG_RES_AVG_SAFETY_STOCK_AMBIENT_BY_WAREHOUSE = "<LG_ResAvgSafetyStockAmbientByWarehouse_V1>"
LG_RES_AVG_SAFETY_STOCK_AMBIENT_BY_WAREHOUSE_BY_LEVEL = "<LG_ResAvgSafetyStockAmbientByWarehouseByLevel_V1>"
LG_RES_EXPECTED_MAX_INVENTORY_AMBIENT_BY_LEVEL = "<LG_ResExpectedMaxInventoryAmbientByLevel_V1>"
LG_RES_EXPECTED_MAX_INVENTORY_AMBIENT_BY_WAREHOUSE = "<LG_ResExpectedMaxInventoryAmbientByWarehouse_V1>"
LG_RES_EXPECTED_MAX_INVENTORY_AMBIENT_BY_WAREHOUSE_BY_LEVEL = "<LG_ResExpectedMaxInventoryAmbientByWarehouseByLevel_V1>"
LG_RES_EXPECTED_AVG_INVENTORY_AMBIENT_BY_LEVEL = "<LG_ResExpectedAvgInventoryAmbientByLevel_V1>"
LG_RES_EXPECTED_AVG_INVENTORY_AMBIENT_BY_WAREHOUSE = "<LG_ResExpectedAvgInventoryAmbientByWarehouse_V1>"
LG_RES_EXPECTED_AVG_INVENTORY_AMBIENT_BY_WAREHOUSE_BY_LEVEL = "<LG_ResExpectedAvgInventoryAmbientByWarehouseByLevel_V1>"
LG_RES_AVG_CAPACITY_UTILIZATION_AMBIENT_BY_LEVEL = "<LG_ResAvgCapacityUtilizationAmbientByLevel_V1>"
LG_RES_AVG_CAPACITY_UTILIZATION_AMBIENT_BY_WAREHOUSE = "<LG_ResAvgCapacityUtilizationAmbientByWarehouse_V1>"
LG_RES_AVG_CAPACITY_UTILIZATION_AMBIENT_BY_WAREHOUSE_BY_LEVEL = (
    "<LG_ResAvgCapacityUtilizationAmbientByWarehouseByLevel_V1>"
)
LG_RES_COLD_CHAIN_CAPACITY_BY_LEVEL = "<LG_ResColdChainCapacityByLevel_V1>"
LG_RES_COLD_CHAIN_CAPACITY_BY_WAREHOUSE = "<LG_ResColdChainCapacityByWarehouse_V1>"
LG_RES_COLD_CHAIN_CAPACITY_BY_WAREHOUSE_BY_LEVEL = "<LG_ResColdChainCapacityByWarehouseByLevel_V1>"
LG_RES_AVG_DEMAND_COLD_CHAIN_BY_LEVEL = "<LG_ResAvgDemandColdChainByLevel_V1>"
LG_RES_AVG_DEMAND_COLD_CHAIN_BY_WAREHOUSE = "<LG_ResAvgDemandColdChainByWarehouse_V1>"
LG_RES_AVG_DEMAND_COLD_CHAIN_BY_WAREHOUSE_BY_LEVEL = "<LG_ResAvgDemandColdChainByWarehouseByLevel_V1>"
LG_RES_AVG_DEMAND_PER_PERIOD_COLD_CHAIN_BY_LEVEL = "<LG_ResAvgDemandPerPeriodColdChainByLevel_V1>"
LG_RES_AVG_DEMAND_PER_PERIOD_COLD_CHAIN_BY_WAREHOUSE = "<LG_ResAvgDemandPerPeriodColdChainByWarehouse_V1>"
LG_RES_AVG_DEMAND_PER_PERIOD_COLD_CHAIN_BY_WAREHOUSE_BY_LEVEL = (
    "<LG_ResAvgDemandPerPeriodColdChainByWarehouseByLevel_V1>"
)
LG_RES_AVG_SAFETY_STOCK_COLD_CHAIN_BY_LEVEL = "<LG_ResAvgSafetyStockColdChainByLevel_V1>"
LG_RES_AVG_SAFETY_STOCK_COLD_CHAIN_BY_WAREHOUSE = "<LG_ResAvgSafetyStockColdChainByWarehouse_V1>"
LG_RES_AVG_SAFETY_STOCK_COLD_CHAIN_BY_WAREHOUSE_BY_LEVEL = "<LG_ResAvgSafetyStockColdChainByWarehouseByLevel_V1>"
LG_RES_EXPECTED_MAX_INVENTORY_COLD_CHAIN_BY_LEVEL = "<LG_ResExpectedMaxInventoryColdChainByLevel_V1>"
LG_RES_EXPECTED_MAX_INVENTORY_COLD_CHAIN_BY_WAREHOUSE = "<LG_ResExpectedMaxInventoryColdChainByWarehouse_V1>"
LG_RES_EXPECTED_MAX_INVENTORY_COLD_CHAIN_BY_WAREHOUSE_BY_LEVEL = (
    "<LG_ResExpectedMaxInventoryColdChainByWarehouseByLevel_V1>"
)
LG_RES_EXPECTED_AVG_INVENTORY_COLD_CHAIN_BY_LEVEL = "<LG_ResExpectedAvgInventoryColdChainByLevel_V1>"
LG_RES_EXPECTED_AVG_INVENTORY_COLD_CHAIN_BY_WAREHOUSE = "<LG_ResExpectedAvgInventoryColdChainByWarehouse_V1>"
LG_RES_EXPECTED_AVG_INVENTORY_COLD_CHAIN_BY_WAREHOUSE_BY_LEVEL = (
    "<LG_ResExpectedAvgInventoryColdChainByWarehouseByLevel_V1>"
)
LG_RES_AVG_CAPACITY_UTILIZATION_COLD_CHAIN_BY_LEVEL = "<LG_ResAvgCapacityUtilizationColdChainByLevel_V1>"
LG_RES_AVG_CAPACITY_UTILIZATION_COLD_CHAIN_BY_WAREHOUSE = "<LG_ResAvgCapacityUtilizationColdChainByWarehouse_V1>"
LG_RES_AVG_CAPACITY_UTILIZATION_COLD_CHAIN_BY_WAREHOUSE_BY_LEVEL = (
    "<LG_ResAvgCapacityUtilizationColdChainByWarehouseByLevel_V1>"
)


# Vehicles
LG_RES_NUM_VEHICLES_AVAIL_BY_LEVEL = "<LG_ResNumVehiclesAvailByLevel_V1>"
LG_RES_NUM_VEHICLES_AVAIL_BY_WAREHOUSE = "<LG_ResNumVehiclesAvailByWarehouse_V1>"
LG_RES_NUM_VEHICLES_AVAIL_BY_WAREHOUSE_BY_LEVEL = "<LG_ResNumVehiclesAvailByWarehouseByLevel_V1>"
LG_RES_NUM_VEHICLES_PURCHASED_BY_LEVEL = "<LG_ResNumVehiclesPurchasedByLevel_V1>"
LG_RES_NUM_VEHICLES_PURCHASED_BY_WAREHOUSE = "<LG_ResNumVehiclesPurchasedByWarehouse_V1>"
LG_RES_NUM_VEHICLES_PURCHASED_BY_WAREHOUSE_BY_LEVEL = "<LG_ResNumVehiclesPurchasedByWarehouseByLevel_V1>"
LG_RES_VEHICLE_PURCHASE_COSTS_BY_LEVEL = "<LG_ResVehiclePurchaseCostsByLevel_V1>"
LG_RES_VEHICLE_PURCHASE_COSTS_BY_WAREHOUSE = "<LG_ResVehiclePurchaseCostsByWarehouse_V1>"
LG_RES_VEHICLE_PURCHASE_COSTS_BY_WAREHOUSE_BY_LEVEL = "<LG_ResVehiclePurchaseCostsByWarehouseByLevel_V1>"
LG_RES_VEHICLE_MAINT_REPAIR_COSTS_BY_LEVEL = "<LG_ResVehicleMaintRepairCostsByLevel_V1>"
LG_RES_VEHICLE_MAINT_REPAIR_COSTS_BY_WAREHOUSE = "<LG_ResVehicleMaintRepairCostsByWarehouse_V1>"
LG_RES_VEHICLE_MAINT_REPAIR_COSTS_BY_WAREHOUSE_BY_LEVEL = "<LG_ResVehicleMaintRepairCostsByWarehouseByLevel_V1>"
LG_RES_VEHICLE_FUEL_COSTS_BY_LEVEL = "<LG_ResVehicleFuelCostsByLevel_V1>"
LG_RES_VEHICLE_FUEL_COSTS_BY_WAREHOUSE = "<LG_ResVehicleFuelCostsByWarehouse_V1>"
LG_RES_VEHICLE_FUEL_COSTS_BY_WAREHOUSE_BY_LEVEL = "<LG_ResVehicleFuelCostsByWarehouseByLevel_V1>"
# Volume analytics
LG_RES_NUM_WAREHOUSES_VISITED_BY_LEVEL = "<LG_ResNumWarehousesVisitedByLevel_V1>"
LG_RES_NUM_WAREHOUSES_VISITED_BY_WAREHOUSE = "<LG_ResNumWarehousesVisitedByWarehouse_V1>"
LG_RES_NUM_WAREHOUSES_VISITED_BY_WAREHOUSE_BY_LEVEL = "<LG_ResNumWarehousesVisitedByWarehouseByLevel_V1>"
LG_RES_NUM_VEHICLE_TRIPS_BY_LEVEL = "<LG_ResNumVehicleTripsByLevel_V1>"
LG_RES_NUM_VEHICLE_TRIPS_BY_WAREHOUSE = "<LG_ResNumVehicleTripsByWarehouse_V1>"
LG_RES_NUM_VEHICLE_TRIPS_BY_WAREHOUSE_BY_LEVEL = "<LG_ResNumVehicleTripsByWarehouseByLevel_V1>"
LG_RES_VEHICLE_DISTANCE_TRAVELED_BY_LEVEL = "<LG_ResVehicleDistanceTraveledByLevel_V1>"
LG_RES_VEHICLE_DISTANCE_TRAVELED_BY_WAREHOUSE = "<LG_ResVehicleDistanceTraveledByWarehouse_V1>"
LG_RES_VEHICLE_DISTANCE_TRAVELED_BY_WAREHOUSE_BY_LEVEL = "<LG_ResVehicleDistanceTraveledByWarehouseByLevel_V1>"
LG_RES_VEHICLE_UTILIZATION_VOLUME_BY_LEVEL = "<LG_ResVehicleUtilizationVolumeByLevel_V1>"
LG_RES_VEHICLE_UTILIZATION_VOLUME_BY_WAREHOUSE = "<LG_ResVehicleUtilizationVolumeByWarehouse_V1>"
LG_RES_VEHICLE_UTILIZATION_VOLUME_BY_WAREHOUSE_BY_LEVEL = "<LG_ResVehicleUtilizationVolumeByWarehouseByLevel_V1>"
LG_RES_VEHICLE_UTILIZATION_TIME_BY_LEVEL = "<LG_ResVehicleUtilizationTimeByLevel_V1>"
LG_RES_VEHICLE_UTILIZATION_TIME_BY_WAREHOUSE = "<LG_ResVehicleUtilizationTimeByWarehouse_V1>"
LG_RES_VEHICLE_UTILIZATION_TIME_BY_WAREHOUSE_BY_LEVEL = "<LG_ResVehicleUtilizationTimeByWarehouseByLevel_V1>"
LG_RES_TIME_NEEDED_PER_ROUND_TRIP_BY_LEVEL = "<LG_ResTimeNeededPerRoundTripByLevel_V1>"
LG_RES_TIME_NEEDED_PER_ROUND_TRIP_BY_WAREHOUSE = "<LG_ResTimeNeededPerRoundTripByWarehouse_V1>"
LG_RES_TIME_NEEDED_PER_ROUND_TRIP_BY_WAREHOUSE_BY_LEVEL = "<LG_ResTimeNeededPerRoundTripByWarehouseByLevel_V1>"
LG_RES_NUM_DAYS_OUT_ON_DELIVERY_BY_LEVEL = "<LG_ResNumDaysOutOnDeliveryByLevel_V1>"
LG_RES_NUM_DAYS_OUT_ON_DELIVERY_BY_WAREHOUSE = "<LG_ResNumDaysOutOnDeliveryByWarehouse_V1>"
LG_RES_NUM_DAYS_OUT_ON_DELIVERY_BY_WAREHOUSE_BY_LEVEL = "<LG_ResNumDaysOutOnDeliveryByWarehouseByLevel_V1>"


# Workers
LG_RES_NUM_WORKERS_BY_LEVEL = "<LG_ResNumWorkersByLevel_V1>"
LG_RES_NUM_WORKERS_BY_WAREHOUSE = "<LG_ResNumWorkersByWarehouse_V1>"
LG_RES_NUM_WORKERS_BY_WAREHOUSE_BY_LEVEL = "<LG_ResNumWorkersByWarehouseByLevel_V1>"
LG_RES_WORKER_SALARIES_BY_LEVEL = "<LG_ResWorkerSalariesByLevel_V1>"
LG_RES_WORKER_SALARIES_BY_WAREHOUSE = "<LG_ResWorkerSalariesByWarehouse_V1>"
LG_RES_WORKER_SALARIES_BY_WAREHOUSE_BY_LEVEL = "<LG_ResWorkerSalariesByWarehouseByLevel_V1>"
LG_RES_WORKER_BENEFITS_BY_LEVEL = "<LG_ResWorkerBenefitsByLevel_V1>"
LG_RES_WORKER_BENEFITS_BY_WAREHOUSE = "<LG_ResWorkerBenefitsByWarehouse_V1>"
LG_RES_WORKER_BENEFITS_BY_WAREHOUSE_BY_LEVEL = "<LG_ResWorkerBenefitsByWarehouseByLevel_V1>"

# Cold chain
LG_RES_NUM_COLD_CHAIN_AVAIL_BY_LEVEL = "<LG_ResNumColdChainAvailByLevel_V1>"
LG_RES_NUM_COLD_CHAIN_AVAIL_BY_WAREHOUSE = "<LG_ResNumColdChainAvailByWarehouse_V1>"
LG_RES_NUM_COLD_CHAIN_AVAIL_BY_WAREHOUSE_BY_LEVEL = "<LG_ResNumColdChainAvailByWarehouseByLevel_V1>"
LG_RES_NUM_COLD_CHAIN_PURCHASED_BY_LEVEL = "<LG_ResNumColdChainPurchasedByLevel_V1>"
LG_RES_NUM_COLD_CHAIN_PURCHASED_BY_WAREHOUSE = "<LG_ResNumColdChainPurchasedByWarehouse_V1>"
LG_RES_NUM_COLD_CHAIN_PURCHASED_BY_WAREHOUSE_BY_LEVEL = "<LG_ResNumColdChainPurchasedByWarehouseByLevel_V1>"
LG_RES_COLD_CHAIN_PURCHASE_COSTS_BY_LEVEL = "<LG_ResColdChainPurchaseCostsByLevel_V1>"
LG_RES_COLD_CHAIN_PURCHASE_COSTS_BY_WAREHOUSE = "<LG_ResColdChainPurchaseCostsByWarehouse_V1>"
LG_RES_COLD_CHAIN_PURCHASE_COSTS_BY_WAREHOUSE_BY_LEVEL = "<LG_ResColdChainPurchaseCostsByWarehouseByLevel_V1>"
LG_RES_COLD_CHAIN_MAINT_COSTS_BY_LEVEL = "<LG_ResColdChainMaintCostsByLevel_V1>"
LG_RES_COLD_CHAIN_MAINT_COSTS_BY_WAREHOUSE = "<LG_ResColdChainMaintCostsByWarehouse_V1>"
LG_RES_COLD_CHAIN_MAINT_COSTS_BY_WAREHOUSE_BY_LEVEL = "<LG_ResColdChainMaintCostsByWarehouseByLevel_V1>"

# Drugs and supplies
LG_RES_DRUG_SUPPLY_QUANTITIES_NEEDED = "<LG_ResDrugSupplyQuantitiesNeeded_V1>"
LG_RES_DRUG_SUPPLY_PURCHASE_COSTS = "<LG_ResDrugSupplyPurchaseCosts_V1>"
LG_RES_DRUG_SUPPLY_WASTAGE_COSTS = "<LG_ResDrugSupplyWastageCosts_V1>"
LG_RES_DRUG_SUPPLY_WASTAGE_QUANTITIES = "<LG_ResDrugSupplyWastageQuantities_V1>"
LG_RES_DRUG_SUPPLY_SAFETY_STOCK_NEEDED = "<LG_ResDrugSupplySafetyStockNeeded_V1>"
LG_RES_DRUG_SUPPLY_SAFETY_STOCK_AVAILABLE = "<LG_ResDrugSupplySafetyStockAvailable_V1>"
LG_RES_DRUG_SUPPLY_SAFETY_STOCK_NEED_PURCH = "<LG_ResDrugSupplySafetyStockNeedingToBePurchased_V1>"
LG_RES_DRUG_SUPPLY_SAFETY_STOCK_PURCHASE_COSTS = "<LG_ResDrugSupplySafetyStockPurchaseCosts_V1>"
LG_RES_DRUG_SUPPLY_WEIGHTS = "<LG_ResDrugSupplyWeights_V1>"
LG_RES_DRUG_SUPPLY_VOLUMES = "<LG_ResDrugSupplyVolumes_V1>"
LG_RES_DRUG_SUPPLY_WASTAGE_WEIGHTS = "<LG_ResDrugSupplyWastageWeights_V1>"
LG_RES_DRUG_SUPPLY_WASTAGE_VOLUMES = "<LG_ResDrugSupplyWastageVolumes_V1>"
LG_RES_DRUG_SUPPLY_TOTAL_COLD_CHAIN_VOLUMES = "<LG_ResDrugSupplyTotalColdChainVolumes_V1>"
