from SpectrumCommon.Const.IH.IHConst import *
from SpectrumCommon.Const.IH.IHTags import *

#############################    IH    ##########################

IS_IH_COMMUNITY_CHAN_MST_ID              = IH_COMMUNITY_CHAN_MST_ID
IS_IH_OUTREACH_CHAN_MST_ID               = IH_OUTREACH_CHAN_MST_ID
IS_IH_CLINIC_CHAN_MST_ID                 = IH_CLINIC_CHAN_MST_ID
IS_IH_FIRST_REFERRAL_CHAN_MST_ID         = IH_FIRST_REFERRAL_CHAN_MST_ID
IS_IH_PREHOSPITAL_EMERGENCY_CHAN_MST_ID  = IH_PREHOSPITAL_EMERGENCY_CHAN_MST_ID
IS_IH_GEN_OUTPATIENT_SERV_CHAN_MST_ID    = IH_GEN_OUTPATIENT_SERV_CHAN_MST_ID
IS_IH_SEC_REFERRAL_CHAN_MST_ID           = IH_SEC_REFERRAL_CHAN_MST_ID         
IS_IH_COMPREHENSIVE_PLAN                 = IH_COMPREHENSIVE_PLAN
IS_IH_SPECIFIC_PLAN                      = IH_SPECIFIC_PLAN

IS_IH_PROG_AREA_RECORDS_TAG_V1           = IH_PROG_AREA_RECORDS_TAG_V1

