#////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
#/////                                                                                                          /////
#/////                                          Input Modvars                                                   /////
#/////                                                                                                          /////
#////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

#/* Subnational Wizard */
CS_SubnatWizProjTag                      = '<CS_SubnatWizProj_V1>'
CS_SubnatRegionTag                       = '<CS_SubnatRegion_V1>'
CS_FirstTimeEnteringCoverageTag          = '<CS_FirstTimeEnteringCoverage_V1>'
CS_SubnatDefDataMstIDsetTag              = '<CS_SubnatDefDataMstIDset_V1>'
CS_SubnatDataSourceArrayTag              = '<CS_SubnatDataSourceArray_V1>'

CS_DataSourceTag                         = '<CS_DataSource_V1>'

# Meta data
CS_IDMapTag                              = '<CS_IDMap_V1>'
CS_FinalIndicesTag                       = '<CS_FinalIndices_V1>'

#/* Intervention info */
CS_NumIntervsTag                         = '<CS_NumIntervs_V1>'
CS_IVInfoTag                             = '<CS_IVInfo_V1>'
CS_IVGroupInfoTag                        = '<CS_IVGroupInfo_V1>'
CS_IVSubgroupInfoTag                     = '<CS_IVSubgroupInfo_V1>'

#/* General */
CS_DevModeTag                            = '<CS_DevMode_V1>'
CS_FirstYearTag                          = '<CS_FirstYear_V1>'
CS_FinalYearTag                          = '<CS_FinalYear_V1>'
CS_ProjValidTag                          = '<CS_ProjValid_V1>'
CS_ProjValidDateTag                      = '<CS_ProjValidDateTime_V1>'
CS_DefaultDBChoiceTag                    = '<CS_DefaultDBChoice_V1>'

#/* Controls */
CS_CovBYTag                              = '<CS_CovBY_V1>'
CS_MenARecommendedTag                    = '<CS_MenARecommended_V1>'
CS_IPTpCBCheckedTag                      = '<CS_IPTpCBStatus_V1>'
CS_HaveCalculatedChDeathsByCauseTag      = '<CS_HaveCalculatedChDeathsByCause_V1>'
CS_FirstYearAtWorkTag                    = '<CS_FirstYearAtWork_V1>'
CS_LastYearAtWorkTag                     = '<CS_LastYearAtWork_V1>'
CS_AbortCalcFamPlanTag                   = '<CS_AbortCalcFamPlan_V1>'
CS_CovEntryModeTag                       = '<CS_CovEntryMode_V1>'
CS_CalcCovFromInputsTag                  = '<CS_CalcCovFromInputs_V1>'
CS_EnterBFImproveDataTag                 = '<CS_BFEntryMode_V1>'
CS_BFPromoCBsTag                         = '<CS_BFPromoCBs_V1>'
CS_StuntMatrixOnTag                      = '<CS_StuntingMatrixOn_V1>'
CS_WasteMatrixOnTag                      = '<CS_WastingMatrixOn_V1>'
CS_UseDetailedStuntMatrixTag             = '<CS_UseDetailedStuntMatrix_V1>'
CS_UseDetailedWasteMatrixTag             = '<CS_UseDetailedWasteMatrix_V1>'
CS_FertilityRisksMatrixOnTag             = '<CS_FertilityRisksMatrixOn_V1>'
CS_DirectEntryFITag                      = '<CS_DirectEntryFI_V1>'
CS_SelectedIVSetTag                      = '<CS_SelectedIVSet_V1>'

#/* Health status */
CS_NutrDeficTag                          = '<CS_NutrDefic_V1>'
CS_VitADefInPWTag                        = '<CS_VitADefInPW_V1>'
CS_StatusAtBirthTag                      = '<CS_StatusAtBirth_V1>'
CS_DiarrIncTag                           = '<CS_DiarrInc_V1>'
CS_SevereDiarrIncTag                     = '<CS_SevereDiarrInc_V1>'
CS_PneumIncTag                           = '<CS_PneumInc_V1>'
CS_MeninIncTag                           = '<CS_MeninInc_V1>'
CS_MaternalAnemiaTag                     = '<CS_MaternalAnemia_V1>'
CS_PercWom15t49LowBMITag                 = '<CS_PercWwom15t49LowBMI_V1>'
CS_SyphilisAmongWRATag                   = '<CS_SyphilisAmongWRA_V1>'
CS_PercExposedFalciparumTag              = '<CS_PercExposedFalciparum_V1>'
CS_PercWomenWithPrevPreEclampTag         = '<CS_PercWomenWithPrevPreEclamp_V1>'
CS_PercWomenWithChronicHypertensionTag   = '<CS_PercWomenWithChronicHypertension_V1>'
CS_FolicAcidDeficPrevTag                 = '<CS_FolicAcidDeficPrev_V1>'
CS_CongenitalDueToNTDsAFTag              = '<CS_CongenitalDueToNTDsAF_V1>'
CS_StuntDistrTag                         = '<CS_StuntDistr_V1>'
CS_WasteDistrTag                         = '<CS_WasteDistr_V1>'
CS_SingleStuntDistrTag                   = '<CS_SingleStuntDistr_V1>'
CS_SingleWasteDistrTag                   = '<CS_SingleWasteDistr_V1>'
CS_DiarrPathTag	                         = '<CS_DiarrPath_V1>'
CS_PneumPathTag                          = '<CS_PneumPath_V1>'
CS_MeninPathTag	                         = '<CS_MeninPath_V1>'
CS_BaselineMortTag                       = '<CS_BaselineMort_V1>'
CS_PercDthByCauseTag	                 = '<CS_PercDthByCause_V1>'
CS_AdolMortRatioTag                      = '<CS_AdolMortRatio_V1>'
CS_PercAdolDeathsByCauseTag              = '<CS_PercAdolDeathsByCause_V1>'  
CS_MatMortRatioTag                       = '<CS_MatMortRatio_V1>'
CS_PercMatDthByCauseTag                  = '<CS_PercMatDthByCause_V1>'
CS_PercPregEndAbortTag                   = '<CS_PercPregEndAbort_V1>'
CS_AbortIncRatioTag                      = '<CS_AbortIncRatio_V1>'
CS_SBRateTag                             = '<CS_SBRate_V1>'
CS_SBCausesTag                           = '<CS_SBCauses_V1>'
CS_PerCapitaIncTag                       = '<CS_PerCapitaInc_V1>'
CS_FoodInsecureTag                       = '<CS_FoodInsecure_V1>'
CS_AvgHouseholdSizeTag	                 = '<CS_AverageHouseholdSize_V1>'
CS_IncludeCostForBCRTag                  = '<CS_IncludeCostForBCR_V1>'
CS_IncludeBenefitForBCRTag               = '<CS_IncludeBenefitForBCR_V1>'
CS_BaselineGDPTag                        = '<CS_BaselineGDP_V1>'
CS_AnnualPercGrowthRateTag	             = '<CS_GNIPerCap_V1>'
CS_LaborForceParRateTag	                 = '<CS_LaborForceParRate_V1>'
CS_FemaleLaborForceParRateTag	         = '<CS_FemaleLaborForceParRate_V1>'
CS_PercGDPAllocWageTag	                 = '<CS_LaborShareInc_V1>'
CS_DiscountRatesTag                      = '<CS_DiscountRates_V1>'
CS_FactorsTag                            = '<CS_Factors_V1>'

#/* Coverage */
CS_CoverageTag                           = '<CS_Coverage_V1>'
CS_BFPrevTag                             = '<CS_BFPrev_V1>'
CS_EarlyInitBFPrevTag                    = '<CS_EarlyInitBFPrev_V1>'
CS_RoutDetVaccCovTag                     = '<CS_RoutDetVaccCov_V1>'
CS_PentaDetVaccCovTag                    = '<CS_PentaDetVaccCov_V1>'
CS_VaccineSuppPercTag                    = '<CS_VaccineSuppPerc_V1>'
CS_AgeAndBirthOrderMatrixTag	         = '<CS_AgeAndBirthOrderMatrix_V1>'
CS_BirthIntervalsMatrixTag               = '<CS_BirthIntervalsMatrix_V1>'

#/* Maternal, Stillbirth, and Child Efficacy */
CS_MatEffTag                             = '<CS_MatEff_V1>'
CS_SBEffTag                              = '<CS_SBEff_V1>'
CS_ChildEffTag                           = '<CS_ChildEff_V1>'
CS_DetVaccEffTag                         = '<CS_DetVaccEff_V1>'

#/* Effectiveness of interventions on incidence */
CS_DiarrIncReductionTag                  = '<CS_DiarrIncReduct_V1>'
CS_SevDiarrIncReductionTag               = '<CS_SevereDiarrIncReduct_V1>'
CS_PneumIncReductionTag                  = '<CS_PneumIncReduct_V1>'
CS_MeninIncReductionTag                  = '<CS_MeninIncReduct_V1>'
CS_RelRisksDiarrTag                      = '<CS_RelRisksDiarr_V1>'
CS_RelRisksPneumTag                      = '<CS_RelRisksPneum_V1>'
CS_RelRisksMeninTag	                     = '<CS_RelRisksMenin_V1>'

#/* Herd effectiveness of vaccines */
CS_HerdVaccEffTag                        = '<CS_HerdVaccEff_V1>'

#/* Impact on food security */
CS_ImpOnFoodSecurityTag                  = '<CS_ImpOnFoodSecurity_V1>'

#/* Effectiveness of nutrition interventions */
CS_AgeAndBirthOrderTag                   = '<CS_AgeAndBirthOrder_V1>'
CS_BirthIntervalsTag	                 = '<CS_BirthIntervals_V1>'
CS_IntervForBOTag                        = '<CS_IntervForBO_V1>'
CS_ImpactOnStuntTag                      = '<CS_ImpactOnStunt_V1>'
CS_ImpactOnWasteTag                      = '<CS_ImpactOnWaste_V1>'
CS_ImpactOnMatAnemiaTag  	             = '<CS_ImpactOnMatAnemia_V1>'
CS_ImpactBFPromoTag                      = '<CS_ImpactBFPromo_V1>'
CS_KMConBFTag                            = '<CS_KMConBF_V1>'
CS_LBWFTag                               = '<CS_LBWF_V1>'
CS_ReducStuntTag                         = '<CS_ReducStunt_V1>'
CS_EducAttainTag                         = '<CS_EducAttain_V1>'

#/* Impact of under-nutrition on mortality */
CS_RelRisksStuntTag                      = '<CS_RelRisksStunt_V1>'
CS_RelRisksWasteTag                      = '<CS_RelRisksWaste_V1>'
CS_RelRisksIUGR_LBWTag	                 = '<CS_RelRisksIUGRLBW_V1>'
CS_ImpactBFOnMortNeoNatTag               = '<CS_ImpactBFOnMortNeoNat_V1>'
CS_ImpactBFOnMortPostNatTag              = '<CS_ImpactBFOnMort_V1>'
CS_RelRisksAnemiaTag                     = '<CS_RelRisksAnemia_V1>'

# ////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
# /////                                                                                                          /////
# /////                                         Result Modvars                                                   /////
# /////                                                                                                          /////
# ////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

CS_PercDeathsAvtdSeqPTag                 = '<CS_PercDeathsAvtdSeqP_V1>'
CS_MortalityRatesTag                     = '<CS_MortalityRates_V1>'
CS_DistPathDiarIncResultTag              = '<CS_DistPathDiarIncResult_V1>'
  
# // Neonatal, child sectors
CS_ChDeathsTag                           = '<CS_ChDeaths_V1>'
CS_ChDeathsByYearTag                     = '<CS_ChDeathsByYear_V1>'
CS_ChDeathsPrevdTag                      = '<CS_ChDeathsPrevd_V1>'
CS_ChDeathsByCauseTag                    = '<CS_ChDeathsByCause_V1>'
CS_DeathsByCauseByBirthCohortTag         = '<CS_ChDeathsByCauseByBirthCohort_V1>'
CS_ChDeathsPrevdByCauseTag               = '<CS_ChDeathsPrevdByCause_V1>'
CS_ChDeathsPrevdByIntTag                 = '<CS_ChDeathsPrevdByInt_V1>'
CS_ChDeathsPrevByInterByCauseTag         = '<CS_ChDeathsPrevByIntByCause_V1>'
CS_DetVaccCovResultsTag                  = '<CS_DetVaccCovResults_V1>'
CS_DAvtdByVaccByCohortTag                = '<CS_DAvtdByVaccByCohort_V1>'
CS_DAvtdByVaccByCohortByCauseTag	     = '<CS_DAvtdByVaccByCohortByCause_V1>'

#// Maternal sector
CS_MatDeathsTag                          = '<CS_MatDeaths_V1>'
CS_MatDeathsPrevTag                      = '<CS_MatDeathsPrev_V1>'
CS_MatDeathsByCauseTag                   = '<CS_MatDeathsByCause_V1>'
CS_MatDeathsPrevByCauseTag               = '<CS_MatDeathsPrevByCause_V1>'
CS_MatDeathsPrevByInterTag               = '<CS_MatDeathsPrevByInter_V1>'
CS_MatDeathsPrevByInterByCauseTag	     = '<CS_MatDeathsPrevByInterByCause_V1>'
CS_NumAbortionsTag	                     = '<CS_NumAbortions_V1>'
CS_PercPregAnemicWomenTag                = '<CS_PercPregAnemicWomen_V1>'

#// Stillbirth sector
CS_SBResultsTag                          = '<CS_SBResults_V1>'
CS_SBPrevResultsTag                      = '<CS_SBPrevResults_V1>'
CS_SBByCauseResultsTag                   = '<CS_SBByCauseResults_V1>'
CS_SBPrevByCauseResultsTag               = '<CS_SBPrevByCauseResults_V1>'
CS_SBPrevByInterResultsTag               = '<CS_SBPrevByInterResults_V1>'
CS_SBPrevByInterByCauseTag               = '<CS_SBPrevByInterByCause_V1>'

#// Mortality rates sector
CS_SBRateResultTag                       = '<CS_SBRateResult_V1>'
CS_MatMortRatioResultTag                 = '<CS_MatMortRatioResult_V1>'
CS_MatMortRateResultTag                  = '<CS_MatMortRateResult_V1>'
CS_MortalityRateResultTag                = '<CS_MortRateResult_V1>'
CS_RedMortIntervResultTag                = '<CS_RedMortIntervResult_V1>'
CS_RedMortIntervSortedIDsTag             = '<CS_RedMortIntervSortedIDs_V1>'

#// Nutrition sector
CS_ShutDownBOAttriByIVTag                = '<CS_ShutDownBOAttriByIV_V1>'
CS_SubOpBOAvertByInterTag	             = '<CS_SuboptimalBOAvertByInter_V1>'
CS_MAM_PINTag                            = '<CS_MAM_PIN_V1>'
CS_SAM_PINTag                            = '<CS_SAM_PIN_V1>'
CS_PInVarHtForAgeStuntTag	             = '<CS_PInVarHtForAgeStunt_V1>'
CS_PInVarWtForHtWasteTag                 = '<CS_PInVarWtForHtWaste_V1>'
CS_PInVarWtForHtWasteCFTag               = '<CS_PInVarWtForHtWasteCF_V1>'
CS_NumStuntedTag                         = '<CS_NumStunted_V1>'
CS_NumStuntedAvertedTag	                 = '<CS_NumStuntedAverted_V1>'
CS_NumStuntedAvertedByInterTag	         = '<CS_NumStuntedAvertedByInter_V1>'
CS_PStuntRedAccountByIntBaseYrTag        = '<CS_PStuntRedAccountByIntBaseYr_V1>'
CS_AdditionalYrsSchoolingGainedTag	     = '<CS_AdditionalYrsSchoolingGained_V1>'
CS_PercIncEarnStuntDeclineTag	         = '<CS_PercIncEarnStuntDecline_V1>'
CS_ImpLifeEarnDueToStuntReducTag         = '<CS_ImpLifeEarnDueToStuntReduc_V1>'
CS_LifetimeEarningsObtainedTag	         = '<CS_LifetimeEarningsObtained_V1>'
CS_BFPrevResultTag                       = '<CS_BFPrevResult_V1>'
CS_BirthTermResultTag	                 = '<CS_BirthTermResult_V1>'
CS_PercAnemicWomenTag                    = '<CS_PercAnemicWomen_V1>'
CS_NumAnemicWomenTag                     = '<CS_NumAnemicWomen_V1>'
CS_NumAnemiaCasesPrevTag                 = '<CS_NumAnemiaCasesPrev_V1>'
CS_PrevFoodInsecurityTag                 = '<CS_PrevFoodInsecurity_V1>'

#// Incidence and etiology sector
CS_DiarrIncResultTag                     = '<CS_DiarrIncResult_V1>'
CS_SevereDiarrIncResultTag               = '<CS_SevereDiarrIncRatesResult_V1>'
CS_PneumIncResultTag                     = '<CS_PneumIncResult_V1>'
CS_MeninIncResultTag	                 = '<CS_MeninIncResult_V1>'
CS_NumDiarrCasesTag                      = '<CS_NumDiarrCases_V1>'
CS_NumSevereDiarrCasesTag                = '<CS_NumSevereDiarrCases_V1>'
CS_NumPneumCasesTag                      = '<CS_NumPneumCases_V1>'
CS_NumMeninCasesTag                      = '<CS_NumMeninCases_V1>'
CS_DiarrCasesAvertByInterTag             = '<CS_DiarrCasesAvertByInter_V1>'
CS_SevereDiarrCasesAvertByInterTag       = '<CS_NumSevereDiarrCasesAvertedByInter_V1>'
CS_PneumCasesAvertByInterTag             = '<CS_PneumCasesAvertByInter_V1>'
CS_MeninCasesAvertByInterTag             = '<CS_MeninCasesAvertByInter_V1>'
CS_PercDiarrDeathsByPathTag	             = '<CS_PercDiarrMortByPathResult_V1>'
CS_PercPneumDeathsByPathTag              = '<CS_PercPneumMortByPathResult_V1>'
CS_PercMeninDeathsByPathTag              = '<CS_PercMeninMortByPathResult_V1>'
CS_DiarrDeathsByPathTag                  = '<CS_DiarrDeathsByPath_V1>'
CS_PneumDeathsByPathTag                  = '<CS_PneumDeathsByPath_V1>'
CS_MeninDeathsByPathTag                  = '<CS_MeninDeathsByPath_V1>'
CS_DiarrDeathsByPathBy1yrAgeGrpsTag      = '<CS_DiarrDeathsByPathBy1yrAgeGrps_V1>'
CS_PneumDeathsByPathBy1yrAgeGrpsTag      = '<CS_PneumDeathsByPathBy1yrAgeGrps_V1>'
CS_MeninDeathsByPathBy1yrAgeGrpsTag      = '<CS_MeninDeathsByPathBy1yrAgeGrps_V1>'
CS_PercDiarrCasesByPathTag	             = '<CS_PercDiarrCasesByPath_V1>'
CS_PercSevDiarrCasesByPathTag	         = '<CS_PercSevDiarrCasesByPath_V1>'
CS_PercPneumCasesByPathTag               = '<CS_PercPneumCasesByPath_V1>'
CS_PercMeninCasesByPathTag               = '<CS_PercMeninCasesByPath_V1>'
CS_DiarrCasesByPathTag                   = '<CS_DiarrCasesByPath_V1>'
CS_SevereDiarrCasesByPathTag             = '<CS_SevereDiarCasesByPath_V1>'
CS_PneumCasesByPathTag                   = '<CS_PneumCasesByPath_V1>'
CS_MeninCasesByPathTag                   = '<CS_MeninCasesByPath_V1>'
CS_DiarrCasesByPathBy1YrAgeGrpsTag       = '<CS_DiarrCasesByPathBy1YrAgeGrps_V1>'
CS_SevereDiarrCasesByPathBy1YrAgeGrpsTag = '<CS_SevereDiarrCasesByPathBy1YrAgeGrps_V1>'
CS_PneumCasesByPathBy1YrAgeGrpsTag       = '<CS_PneumCasesByPathBy1YrAgeGrps_V1>'
CS_MeninCasesByPathBy1YrAgeGrpsTag       = '<CS_MeninCasesByPathBy1YrAgeGrps_V1>'
CS_DiarrCasesByBirthCohTag               = '<CS_DiarrCasesByBirthCoh_V1>'
CS_PneumCasesByBirthCohTag               = '<CS_PneumCasesByBirthCoh_V1>'
CS_MeninCasesByBirthCohTag               = '<CS_MeninCasesByBirthCoh_V1>'
CS_SevDiarrCasesByBirthCohTag            = '<CS_SevDiarrCasesByBirthCoh_V1>'
CS_DiarCasesAvtdByYr1stDoseVaccTag       = '<CS_DiarrCasesAvtdByYr1stDoseVacc_V1>'
CS_PneumCasesAvtdByYr1stDoseVaccTag      = '<CS_PneumCasesAvtdByYr1stDoseVacc_V1>'
CS_MeninCasesAvtdByYr1stDoseVaccTag      = '<CS_MeninCasesAvtdByYr1stDoseVacc_V1>'
CS_SevDiarrCasesAvtdByYr1stDoseVaccTag   = '<CS_SevDiarrCasesAvtdByYr1stDoseVacc_V1>'
CS_DiarrDeathsByPathBirthCohTag          = '<CS_DiarrDeathsByPathBirthCoh_V1>'
CS_PneumDeathsByPathBirthCohTag          = '<CS_PneumDeathsByPathBirthCoh_V1>'
CS_MeninDeathsByPathBirthCohTag          = '<CS_MeninDeathsByPathBirthCoh_V1>'
CS_DiarrCasesByPathBirthCohTag           = '<CS_DiarrCasesByPathBirthCoh_V1>'
CS_PneumCasesByPathBirthCohTag           = '<CS_PneumCasesByPathBirthCoh_V1>'
CS_MeninCasesByPathBirthCohTag           = '<CS_MeninCasesByPathBirthCoh_V1>'
CS_SevDiarrCasesByPathBirthCohTag        = '<CS_SevDiarrCasesByPathBirthCoh_V1>'
CS_DiarrDeathsByPathBirthCohVCTag        = '<CS_DiarrDeathsByPathBirthCohVC_V1>'
CS_PneumDeathsByPathBirthCohVCTag        = '<CS_PneumDeathsByPathBirthCohVC_V1>'
CS_MeninDeathsByPathBirthCohVCTag        = '<CS_MeninDeathsByPathBirthCohVC_V1>'
CS_DiarrCasesByPathBirthCohVCTag         = '<CS_DiarrCasesByPathBirthCohVC_V1>'
CS_PneumCasesByPathBirthCohVCTag         = '<CS_PneumCasesByPathBirthCohVC_V1>'
CS_MeninCasesByPathBirthCohVCTag         = '<CS_MeninCasesByPathBirthCohVC_V1>'
CS_PersonsVaccByIntervTag                = '<CS_PersonsVaccByInterv_V1>'
CS_PersonsVaccByIntervBy1YrAgeGrpsTag    = '<CS_PersonsVaccByIntervBy1YrAgeGrps_V1>'

# BCR       
CS_DiscountedCostsTag                    = '<CS_DiscountedCosts_V1>'
CS_DiscountedSocialBenefitsTag           = '<CS_DiscountedSocialBenefits_V1>'
CS_DiscountedEconBenefitsTag             = '<CS_DiscountedEconomicBenefits_V1>'
CS_IncLifetimeEarningsDueToStuntTag      = '<CS_IncLifetimeEarningsDueToStunt_V1>'

CS_TotalDiscountedCostsTag               = '<CS_TotalDiscountedCosts_V1>'
CS_TotalDiscountedSocialBenefitsTag      = '<CS_TotalDiscountedSocialBenefits_V1>'
CS_TotalDiscountedEconBenefitsTag        = '<CS_TotalDiscountedEconomicBenefits_V1>'
CS_LifetimeEarningsIncTag                = '<CS_LifetimeEarningsInc_V1>'
CS_BCRTag                                = '<CS_BCR_V1>'

# ////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
# /////                                                                                                          /////
# /////                                          Meta Modvars                                                    /////
# /////                                                                                                          /////
# ////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

CS_SourcesTag                            = '<CS_Sources_V1>'
CS_DiarrIncMetaTag                       = '<CS_DiarrInc_Meta_V1>'
CS_SevereDiarrIncMetaTag                 = '<CS_SevereDiarrInc_Meta_V1>'
CS_PneumIncMetaTag                       = '<CS_PneumInc_Meta_V1>'
CS_MeninIncMetaTag                       = '<CS_MeninInc_Meta_V1>'
CS_BaselineMortMetaTag                   = '<CS_BaselineMort_Meta_V1>'
CS_PercDthByCauseMetaTag                 = '<CS_PercDthByCause_Meta_V1>'
CS_MatMortRatioMetaTag                   = '<CS_MatMortRatio_Meta_V1>'
CS_PercMatDthByCauseMetaTag              = '<CS_PercMatDthByCause_Meta_V1>'
CS_SBRateMetaTag                         = '<CS_SBRate_Meta_V1>'
CS_SBCausesMetaTag                       = '<CS_SBCauses_Meta_V1>'
CS_CoverageMetaTag                       = '<CS_Coverage_Meta_V1>'
CS_RoutDetVaccCovMetaTag                 = '<CS_RoutDetVaccCov_Meta_V1>'
CS_PentaDetVaccCovMetaTag                = '<CS_PentaDetVaccCov_Meta_V1>'
CS_VaccineSuppPercMetaTag                = '<CS_VaccineSuppPerc_Meta_V1>'
CS_MatEffMetaTag                         = '<CS_MatEff_Meta_V1>'
CS_SBEffMetaTag                          = '<CS_SBEff_Meta_V1>'
CS_ChildEffMetaTag                       = '<CS_ChildEff_Meta_V1>'
CS_DetVaccEffMetaTag                     = '<CS_DetVaccEff_Meta_V1>'
CS_DiarrIncReductMetaTag                 = '<CS_DiarrIncReduct_Meta_V1>'
CS_SevereDiarrIncReductMetaTag           = '<CS_SevereDiarrIncReduct_Meta_V1>'
CS_PneumIncReductMetaTag                 = '<CS_PneumIncReduct_Meta_V1>'
CS_MeninIncReductMetaTag                 = '<CS_MeninIncReduct_Meta_V1>'
CS_RelRisksDiarrMetaTag                  = '<CS_RelRisksDiarr_Meta_V1>'
CS_RelRisksPneumMetaTag                  = '<CS_RelRisksPneum_Meta_V1>'
CS_RelRisksMeninMetaTag                  = '<CS_RelRisksMenin_Meta_V1>'
CS_AgeAndBirthOrderMetaTag               = '<CS_AgeAndBirthOrder_Meta_V1>'
CS_BirthIntervalsMetaTag                 = '<CS_BirthIntervals_Meta_V1>'
CS_IntervForBOMetaTag                    = '<CS_IntervForBO_Meta_V1>'
CS_ImpactOnStuntMetaTag                  = '<CS_ImpactOnStunt_Meta_V1>'
CS_ImpactOnWasteMetaTag                  = '<CS_ImpactOnWaste_Meta_V1>'
CS_ImpactOnMatAnemiaMetaTag              = '<CS_ImpactOnMatAnemia_Meta_V1>'
CS_ImpactBFPromoMetaTag                  = '<CS_ImpactBFPromo_Meta_V1>'
CS_KMConBFMetaTag                        = '<CS_KMConBF_Meta_V1>'
CS_ReducStuntMetaTag                     = '<CS_ReducStunt_Meta_V1>'
CS_EducAttainMetaTag                     = '<CS_EducAttain_Meta_V1>'
CS_RelRisksStuntMetaTag                  = '<CS_RelRisksStunt_Meta_V1>'
CS_RelRisksWasteMetaTag                  = '<CS_RelRisksWaste_Meta_V1>'
CS_RelRisksIUGRLBWMetaTag                = '<CS_RelRisksIUGRLBW_Meta_V1>'
CS_ImpactBFOnMortNeoNatMetaTag           = '<CS_ImpactBFOnMortNeoNat_Meta_V1>'
CS_ImpactBFOnMortMetaTag                 = '<CS_ImpactBFOnMort_Meta_V1>'
CS_RelRisksAnemiaMetaTag                 = '<CS_RelRisksAnemia_Meta_V1>'
CS_DetVaccCovResultsMetaTag              = '<CS_DetVaccCovResults_Meta_V1>'
CS_DAvtdByVaccByCohortMetaTag            = '<CS_DAvtdByVaccByCohort_Meta_V1>'
CS_DAvtdByVaccByCohortByCauseMetaTag     = '<CS_DAvtdByVaccByCohortByCause_Meta_V1>'
CS_DebugTag                              = '<CS_Debug_V1>'
### OLD MODVAR TAGS:

#////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
#/////                                                                                                          /////
#/////                                          Input Modvars                                                   /////
#/////                                                                                                          /////
#////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

# #/* LiST */
# #/* General */
# CS_TG_FirstYear_MV2                       = '<First Year MV2>'
# CS_TG_FinalYear_MV2                       = '<Final Year MV2>'
# CS_TG_ProjectionValidDate_MV2	          = '<Projection Valid Date and Time: MV2>'

# #/* Controls */
# CS_TG_CovBY_MV                            = '<CovBY MV>'
# CS_TG_ANCMode_MV                          = '<ANCMode MV>'
# CS_TG_ChildbirthMode_MV                   = '<ChildbirthMode MV>'
# CS_TG_CalcCovFromInputs_MV2               = '<CalcCovFromInputs MV2>'
# CS_TG_EnterBFImproveData_MV2              = '<BFEntryMode MV3>'
# CS_TG_StuntingMatrixOn_MV2                = '<StuntingMatrixOn MV2>'
# CS_TG_WastingMatrixOn_MV2                 = '<WastingMatrixOn MV2>'
# CS_TG_FertilityRisksMatrixOn_MV2          = '<FertilityRisksMatrixOn MV2>'
# CS_TG_IPTpCBChecked_MV2                   = '<IPTpCBStatus MV2>'
# CS_TG_AbortCalcFamPlan_MV2                = '<AbortCalcFamPlan MV2>'
# CS_TG_SelectedIVSet_MV                    = '<Selected intervention set MV>'
# #// CS_TG_InterventionList_MV                 = '<InterventionList MV>'
# #// CS_TG_InterventionGroupList_MV            = '<InterventionGroupList MV>'
# #// CS_TG_InterventionSubGroupList_MV         = '<InterventionSubGroupList MV>'

# #/* Health status */
# CS_TG_MenARecommended                     = '<MenA recommended>'
# CS_TG_NutritionalDeficiencies_MV2         = '<Nutritional Deficiencies MV2>'
# CS_TG_VitADefInPW_MV                      = '<VitA deficiency in PW MV>'
# CS_TG_StatusAtBirth_MV                    = '<Status At Birth MV>'
# CS_TG_DiarInc_MV                          = '<DiarInc MV>'
# CS_TG_SevereDiarInc_MV                    = '<SevereDiarInc MV>'
# CS_TG_PneumInc_MV                         = '<Pneumonia Incidence MV>'
# CS_TG_MeningInc_MV                        = '<Meningitis Incidence MV>'
# CS_TG_MaternalAnemia_MV                   = '<Maternal Anemia MV>'
# CS_TG_RelRisksAnemia_MV2                  = '<RelRisksAnemia MV2>'
# CS_TG_PercWom15t49LowBMI_MV               = '<Percentage of women aged 15-49 with low BMI MV>'
# CS_TG_PercExposedFalciparum_MV            = '<Percent exposed to falciparum>'
# CS_TG_FolicAcidDeficPrev_MV               = '<Folic acid deficient prevalence>'
# CS_TG_CongenitalDueToNTDsAF_MV            = '<CongenitalDueToNTDsAF>'
# CS_TG_StuntingDistr_MV                    = '<Stunting distribution MV>'
# CS_TG_SingleStuntingDistr_MV              = '<Single Stunting distribution MV>'
# CS_TG_WastingDistr_MV                     = '<Wasting distribution MV>'
# CS_TG_SingleWastingDistr_MV               = '<Single Wasting distribution MV>'
# CS_TG_UseDetailedStuntingMatrix_MV        = '<Use Detailed Stunting Matrix MV>'
# CS_TG_UseDetailedWastingMatrix_MV         = '<Use Detailed Wasting Maxtrix MV>'
# CS_TG_DiarPath_MV2	                      = '<Diarrhea pathogens MV2>'
# CS_TG_PneumPath_MV                        = '<Pneumonia pathogens MV>'
# CS_TG_MenPath_MV	                      = '<Meningitis pathogens MV>'
# CS_TG_BaselineMort_MV                     = '<BaselineMort MV>'
# CS_TG_PercDthByCause_MV2	              = '<PercDthByCause MV2>'
# CS_TG_MatMortRatio_MV2                    = '<MatMortRatio MV2>'
# CS_TG_PercMatDeathsByCause_MV             = '<PercMatDeathsByCause MV>'
# CS_TG_PercPregEndAbort_MV2                = '<PercPregEndAbort MV2>'
# CS_TG_AbortIncRatio_MV2                   = '<AbortIncRatio MV 2>'
# CS_TG_SBRate_MV2                          = '<SBRate MV2>'
# CS_TG_SBCauses_MV                         = '<SBCauses MV>'
# CS_TG_PerCapitaInc_MV                     = '<PerCapitaInc MV>'
# CS_TG_FoodInsecure_MV                     = '<FoodInsecure MV>'
# CS_TG_AvgHouseholdSize_MV	              = '<Average Household Size MV>'
# CS_TG_FirstYearAtWork_MV                  = '<First year at work MV>'
# CS_TG_LastYearAtWork_MV                   = '<Last year at work MV>'
# CS_TG_GNIPerCap_MV	                      = '<GNIPerCap MV>'
# CS_TG_LaborForceParRate_MV	              = '<LaborForceParRate MV>'
# CS_TG_LaborShareInc_MV	                  = '<LaborShareInc MV>'

# #/* Coverage */
# CS_TG_Coverage_MV3                        = '<Coverage MV3>'
# CS_TG_BreastfeedPrev_MV                   = '<Breastfeeding Prevalence MV>'
# CS_TG_EarlyInitBFPrev_MV2                 = '<Early Initiation BF prevalence MV2>'
# CS_TG_RoutDetVaccCov_MV3                  = '<RoutDetVaccCov MV3>'
# CS_TG_BreastFeedPromoCB_MV                = '<Breastfeeding Promotion Checkboxes MV>'
# CS_TG_PentavalentDetVaccCov_MV            = '<PentavalentDetVaccCov MV>'
# CS_TG_AgeAndBirthOrderMatrix_MV2	      = '<Age And Birth Order Matrix MV2>'
# CS_TG_BirthIntervalsMatrix_MV2            = '<Birth Intervals Matrix MV2>'

# #/* Maternal, Stillbirth, and Child Efficacy */
# CS_TG_MatEfficacy_MV3                     = '<Maternal Efficacy MV3>'
# CS_TG_SBEfficacy_MV2                      = '<SBEfficacy MV2>'
# CS_TG_Efficacy_MV2                        = '<Efficacy MV2>'
# CS_TG_DetVaccEff_MV2                      = '<DetVaccEff MV2>'

# #/* Effectiveness of interventions on incidence */
# CS_TG_DiarrIncReduction_MV3               = '<DiarrIncReduction MV3>'
# CS_TG_SevDiarrIncReduction_MV             = '<Severe Diarrhea Incidence Reduction>'
# CS_TG_PneumIncReduction_MV                = '<Pneumonia Incidence Reduction MV>'
# CS_TG_MeningIncReduction_MV               = '<Meningitis Incidence Reduction MV>'
# CS_TG_RelRisksDiarrhea_MV2                = '<RelRisksDiarrhea MV2>'
# CS_TG_RelRisksPneumonia_MV2          	  = '<RelRisksPneumonia MV2>'
# CS_TG_RelRisksMeningitis_MV2	          = '<RelRisksMeningitis MV2>'

# #/* Herd effectiveness of vaccines */
# CS_TG_HerdVaccEff_MV3                     = '<Custom herd vaccine efficacy MV 3>'

# #/* Effectiveness of nutrition interventions */
# CS_TG_AgeAndBirthOrder_MV2                = '<Age And Birth Order MV2>'
# CS_TG_BirthIntervals_MV2	              = '<Birth Intervals MV2>'
# CS_TG_IntervForBO_MV7                     = '<Maternal Nutrition MV7>'
# CS_TG_ImpactsOnStunting_MV                = '<Impacts On Stunting MV>'
# CS_TG_ImpactsOnWasting_MV4                = '<Impacts On Wasting MV4>'
# CS_TG_ImpactsOnMatAnemia_MV3  	          = '<Impacts On Maternal Anemia MV3>'
# CS_TG_ImpactsBFPromotion_MV3              = '<ImpactsBFPromotion MV3>'
# CS_TG_KMConBF_MV                          = '<Kangaroo Mother Care on Breastfeeding MV>'
# CS_TG_LBWF_MV2                            = '<Low birth weight factor MV2>'
# CS_TG_ReducStunt_MV                       = '<ReducStunt MV>'
# CS_TG_EducationAttain_MV                  = '<EducationAttain MV>'

# #/* Impact of under-nutrition on mortality */
# CS_TG_RelRisksStunting_MV                 = '<RelRisksStunting MV>'
# CS_TG_RelRisksWasting_MV                  = '<RelRisksWasting MV>'
# CS_TG_ImpactBFOnMortNeoNat_MV             = '<ImpactBFOnMortNeoNat MV>'
# CS_TG_ImpactBFOnMortPostNat_MV            = '<ImpactBFOnMort MV>'
# CS_TG_RelRisksIUGR_LBW_MV	              = '<RelRisksIUGR_LBW MV>'
# CS_TG_RelRisksAnemia_MV2                  = '<RelRisksAnemia MV2>'

# # ////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
# # /////                                                                                                          /////
# # /////                                         Result Modvars                                                   /////
# # /////                                                                                                          /////
# # ////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

# CS_TG_PercDeathsAvtdSeqP_MV2            = '<PercDeathsAvtdSeqP MV2>';
  
# # // Neonatal, child sectors
# CS_TG_ChDeaths_MV2                         = '<ChDeaths MV2>'
# CS_TG_ChDeathsByYear_MV2                   = '<ChDeathsByYear MV2>'
# CS_TG_ChDeathsPrevd_MV2                    = '<ChDeathsPrevd MV2>'
# CS_TG_ChDeathsxCause_MV2                   = '<ChDeathsxCause MV2>'
# CS_TG_DeathsByCauseByBirthCohort_MV2       = '<Cause-specific deaths in children under five years of age by year of birth cohort2>'
# CS_TG_ChDeathsPrevdxCause_MV2              = '<ChDeathsPrevdxCause MV2>'
# CS_TG_ChDeathsPrevdxInt_MV3                = '<ChDeathsPrevdxInt MV3>'
# CS_TG_DeathsPrevByInterByCause_MV3         = '<Child deaths prevented by intervention by cause MV3>'
# CS_TG_DetVaccCovResults_MV3                = '<DetVaccCovResults MV3>'
# CS_TG_DAvtdByVaccByCohortResult_MV2        = '<DAvtdByVaccByCohortResult MV2>'
# CS_TG_DAvtdByVaccByCohortByCause_MV3	   = '<DAvtdByVaccByCohortByCause MV3>'

# #// Maternal sector
# CS_TG_MatDeaths_MV2                        = '<MatDeaths MV2>'
# CS_TG_MatDeathsPrev_MV2                    = '<MatDeathsPrev MV2>'
# CS_TG_MatDeathsByCauseResults_MV2          = '<MatDeathsByCauseResults MV2>'
# CS_TG_MatDeathsPrevByCause_MV2             = '<MatDeathsPrevByCause MV2>'
# CS_TG_MatDeathsPrevByInter_MV3             = '<MatDeathsPrevByInter MV3>'
# CS_TG_MatDeathsPrevByInterByCause_MV3	   = '<Maternal deaths prevented by intervention by cause MV3>'
# CS_TG_NumAbortions_MV2	                   = '<Number of Abortions MV2>'
# CS_TG_PercAnemicPregWomen_MV2              = '<Percent of pregnant women who are anemic MV2>'

# #// Stillbirth sector
# CS_TG_SBResults_MV2                        = '<SBResults MV2>'
# CS_TG_SBPrevResults_MV2                    = '<SBPrevResults MV2>'
# CS_TG_SBByCauseResults_MV2                 = '<SBByCauseResults MV2>'
# CS_TG_SBPrevByCauseResults_MV2             = '<SBPrevByCauseResults MV2>'
# CS_TG_SBPrevByInterResults_MV3             = '<SBPrevByInterResults MV3>'
# CS_TG_SBPrevByInterByCause_MV3             = '<Stillbirths prevented by intervention by cause MV3>'

# #// Mortality rates sector
# CS_TG_SBRateResults_MV2                    = '<SBRateResults MV2>'
# CS_TG_MatMortRatioResult_MV2               = '<MatMortRatioResult MV2>'
# CS_TG_MatMortRateResult_MV2                = '<MatMortRateResult MV2>'
# CS_TG_MortalityRateResults_MV2             = '<MortalityRateResults MV2>'
# CS_TG_RedMortIntervResults_MV3             = '<RedMortIntervResults MV3>'
# CS_TG_RedMortIntervSortedIDs_MV3           = '<RedMortIntervSortedIDs MV3>'

# #// Nutrition sector 
# CS_TG_ShutDownBOAttriByIV_MV            = '<ShutDownBOAttriByIV MV>';
# CS_TG_SubOpBOAvertByInter_MV	          = '<Suboptimal birth outcomes averted by intervention MV>';
# CS_TG_MAM_PIN_MV                           = '<MAM_PIN MV>'
# CS_TG_SAM_PIN_MV                           = '<SAM_PIN MV>'
# CS_TG_PInVarHtForAgeStunt_MV2	           = '<PInVarHtForAgeStunt MV2>'
# CS_TG_PInVarWtForHtWaste_MV2               = '<PInVarWtForHtWaste MV2>'
# CS_TG_NumStunted_MV                        = '<NumStunted MV>'
# CS_TG_NumStuntedAverted_MV	               = '<NumStuntedAverted MV>'
# CS_TG_NumStuntedAvertedByInter_MV	       = '<NumStuntedAvertedByInter MV>'
# CS_TG_PStuntRedAccountByIntBaseYr_MV2      = '<PStuntRedAccountByIntBaseYr MV2>'
# CS_TG_PercIncEarnStuntDecline_MV	      = '<PercIncEarnStuntDecline MV>';
# CS_TG_AdditionalYrsSchoolingGained_MV	  = '<AdditionalYrsSchoolingGained MV>';
# CS_TG_ImpLifeEarnDueToStuntReduc_MV     = '<ImpLifeEarnDueToStuntReduc MV>';   
# CS_TG_LifetimeEarningsObtained_MV	      = '<LifetimeEarningsObtained MV>';    
# CS_TG_BFPrevResult_MV2                     = '<BFPrevResult MV2>'
# CS_TG_BirthTermResult_MV2	               = '<Birth Term Results MV2>'
# CS_TG_PercWomenAnemicResults_MV            = '<Percent of women with anemia MV>'
# CS_TG_NumWomenAnemicResults_MV             = '<Number of women with anemia MV>'
# CS_TG_AnemiaCasesPreventedResults_MV       = '<Number of anemia cases prevented MV>'

# #// Incidence and etiology sector
# CS_TG_DiarIncResult_MV2                    = '<DiarIncResult MV2>'
# CS_TG_SevereDiarIncResult_MV               = '<Severe Diarrhea Incidence Rates Result>'
# CS_TG_PneumIncResult_MV2                   = '<PneumIncResult MV2>'
# CS_TG_MeningIncResult_MV2	               = '<Meningitis Incidence Result MV2>'
# CS_TG_DiarCasesResult_MV2                  = '<Number of diarrhea Cases MV2>'
# CS_TG_SevereDiarCasesResult_MV             = '<Number of Severe Diarrhea Cases Result>'
# CS_TG_PneumCasesResult_MV2                 = '<Number of pneumonia cases MV2>'
# CS_TG_MeningCasesResult_MV2                = '<Number of Meningitis Cases- Result MV2>'
# CS_TG_DiarCasesAvertByInter_MV3            = '<DiarCasesAvertByInter MV3>'
# CS_TG_DiarCasesAvertByInter_MV4            = '<DiarCasesAvertByInter MV4>'
# CS_TG_SevereDiarCasesAvertByInter_MV       = '<Number of Severe Diarrhea Cases Averted by Intervention Result>'
# CS_TG_SevereDiarCasesAvertByInter_MV2      = '<Number of Severe Diarrhea Cases Averted by Intervention Result2>'
# CS_TG_PneumCasesAvertByInter_MV3           = '<PneumCasesAvertByInter MV3>'
# CS_TG_MeninCasesAvertByInter_MV3           = '<MeninCasesAvertByInter MV3>'
# CS_TG_PercDiarDeathsByPath_MV2	           = '<PDiarrMortByPathResult MV2>'
# CS_TG_PercPneumDeathsByPath_MV3            = '<PPneumMortByPathResult MV3>'
# CS_TG_PercMeningDeathsByPath_MV2           = '<PMeningMortByPathResult MV2>'
# CS_TG_DiarDeathsByPath_MV2                 = '<Number of deaths due to pathogens by year of impact - Diarrhea MV2>'
# CS_TG_PneumDeathsByPath_MV2                = '<Number of deaths due to pathogens by year of impact - Pneumonia MV2>'
# CS_TG_MeningDeathsByPath_MV2               = '<Number of deaths due to pathogens by year of impact - Meningitis MV2>'
# CS_TG_DiarDeathsByPathBy1yrAgeGrps_MV      = '<Number of deaths due to pathogens by year of impact by 1 year age groups - Diarrhea MV>'
# CS_TG_PneumDeathsByPathBy1yrAgeGrps_MV     = '<Number of deaths due to pathogens by year of impact by 1 year age groups - Pneumonia MV>'
# CS_TG_MeningDeathsByPathBy1yrAgeGrps_MV    = '<Number of deaths due to pathogens by year of impact by 1 year age groups - Meningitis MV>'
# CS_TG_PercDiarCasesByPath_MV2	           = '<PDiarIncWInfectResult MV2>'
# CS_TG_PercSevDiarCasesByPath_MV	           = '<Percent of 1-59 Month Severe Diarrhea Cases by Pathogen>'
# CS_TG_PercPneumCasesByPath_MV3             = '<PPneumIncWInfectResult MV3>'
# CS_TG_PercMeningCasesByPath_MV2            = '<PMeningIncWInfectResult MV2>'
# CS_TG_DiarCasesByPath_MV2                  = '<Number of cases by pathogen by year of impact - Diarrhea MV2>'
# CS_TG_SevereDiarCasesByPath_MV             = '<Number of Severe Diarrhea Cases by Pathogen by Year of Impact Result>'
# CS_TG_PneumCasesByPath_MV2                 = '<Number of cases by pathogen by year of impact - Pneumonia MV2>'
# CS_TG_MeningCasesByPath_MV2                = '<Number of cases by pathogen by year of impact - Meningitis MV2>'
# CS_TG_DiarCasesByPathBy1YrAgeGrps_MV       = '<Number of cases by pathogen by year of impact by 1 year age groups - Diarrhea MV>'
# CS_TG_SevereDiarCasesByPathBy1YrAgeGrps_MV = '<Number of Severe Diarrhea Cases by Pathogen by Year of Impact by 1 year age groups Result>'
# CS_TG_PneumCasesByPathBy1YrAgeGrps_MV      = '<Number of cases by pathogen by year of impact by 1 year age groups - Pneumonia MV>'
# CS_TG_MeningCasesByPathBy1YrAgeGrps_MV     = '<Number of cases by pathogen by year of impact by 1 year age groups - Meningitis MV>'
# CS_TG_DiarCasesByBirthCoh_MV2              = '<Number of cases by cause by birth cohort - Diarrhea MV2>'
# CS_TG_PneumCasesByBirthCoh_MV2             = '<Number of cases by cause by birth cohort - Pneumonia MV2>'
# CS_TG_MeningCasesByBirthCoh_MV2            = '<Number of cases by cause by birth cohort - Meningitis MV2>'
# CS_TG_SevDiarCasesByBirthCoh_MV            = '<Number of cases by cause by birth cohort - Severe diarrhea MV>'
# CS_TG_DiarCasesAvtdByYr1stDoseVacc_MV2     = '<Cases averted by cause by year that the first dose of a vaccine was received by a child - Diarrhea MV2>'
# CS_TG_PneumCasesAvtdByYr1stDoseVacc_MV2    = '<Cases averted by cause by year that the first dose of a vaccine was received by a child - Pneumonia MV2>'
# CS_TG_MeningCasesAvtdByYr1stDoseVacc_MV2   = '<Cases averted by cause by year that the first dose of a vaccine was received by a child - Meningitis MV2>'
# CS_TG_SevDiarCasesAvtdByYr1stDoseVacc_MV   = '<Cases averted by cause by year that the first dose of a vaccine was received by a child - Severe diarrhea MV>'
# CS_TG_DiarDeathsByPathBirthCoh_MV2         = '<Number of deaths by pathogen - Diarrhea MV2>'
# CS_TG_PneumDeathsByPathBirthCoh_MV2        = '<Number of deaths by pathogen - Pneumonia MV2>'
# CS_TG_MeningDeathsByPathBirthCoh_MV2       = '<Number of deaths by pathogen - Meningitis MV2>'
# CS_TG_DiarCasesByPathBirthCoh_MV2          = '<Number of cases by pathogen - Diarrhea MV2>'
# CS_TG_PneumCasesByPathBirthCoh_MV2         = '<Number of cases by pathogen - Pneumonia MV2>'
# CS_TG_MeningCasesByPathBirthCoh_MV2        = '<Number of cases by pathogen - Meningitis MV2>'
# CS_TG_SevDiarCasesByPathBirthCoh_MV        = '<Number of cases by pathogen - Severe diarrhea MV>'
# CS_TG_DiarDeathsByPathBirthCohVC_MV        = '<Number of deaths by pathogen - Diarrhea - Vaccinated cohort MV>'
# CS_TG_PneumDeathsByPathBirthCohVC_MV       = '<Number of deaths by pathogen - Pneumonia - Vaccinated cohort MV>'
# CS_TG_MeningDeathsByPathBirthCohVC_MV      = '<Number of deaths by pathogen - Meningitis - Vaccinated cohort MV>'
# CS_TG_DiarCasesByPathBirthCohVC_MV         = '<Number of cases by pathogen - Diarrhea - Vaccinated cohort MV>'
# CS_TG_PneumCasesByPathBirthCohVC_MV        = '<Number of cases by pathogen - Pneumonia - Vaccinated cohort MV>'
# CS_TG_MeningCasesByPathBirthCohVC_MV       = '<Number of cases by pathogen - Meningitis - Vaccinated cohort MV>'
# CS_TG_PersonsVaccByInterv_MV2              = '<Number of persons vaccinated by intervention MV2>'
# CS_TG_PersonsVaccByIntervBy1YrAgeGrps_MV   = '<Number of persons vaccinated by intervention by 1 year age groups MV>'
# CS_TG_PersonsVaccByIntervBy1YrAgeGrps_MV2  = '<Number of persons vaccinated by intervention by 1 year age groups MV2>'

# ////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
# /////                                                                                                          /////
# /////                                         DefaultData Tags                                                 /////
# /////                                                                                                          /////
# ////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

TG_Efficacy                             = '<Efficacy>'
TG_AgeAndBirthOrder                     = '<Age and Birth Order>'
TG_BirthSpacing                         = '<Birth Spacing>'
TG_IntervForBO                          = '<Interventions for birth outcomes>'
TG_ImpactsStunting                      = '<Impacts on Stunting>'
TG_ImpactWastingOnMort                  = '<Impact Wasting on Mortality>'
TG_ImpactOnAnemia                       = '<Impact on Anemia>'
TG_ReducInStunt                         = '<Reduction in stunting>'
TG_EducAttain                           = '<Education attainment>'
TG_RelRiskAnemia                        = '<Relative Risk Anemia>'
TG_ImpactDiarrInc                       = '<Impact on Diarrhea Incidence>'
TG_ImpactPneumInc                       = '<Impact Pneumonia Incidence>'
TG_ImpactMeninInc                       = '<Impact Meningitis Incidence>'
TG_BFImprovement                        = '<Breastfeeding Improvement>'
TG_RelRiskStunting                      = '<Relative Risk Stunting>'
TG_RelRiskWasting                       = '<Relative Risk Wasting>'
TG_RelRiskMortBF                        = '<Relative Risk Mortality Breastfeeding>'
TG_RelRiskDiarrBF                       = '<Relative Risk Diarrhea Breastfeeding>'
TG_RelRiskPneumBF                       = '<Relative Risk Pneumonia Breastfeeding>'
TG_RelRiskMeninBF                       = '<Relative Risk Meningitis Breastfeeding>'
TG_HerdEfficacy                         = '<Herd Efficacy>'
TG_DetVaccEff                           = '<Detailed Vaccine Efficacy>'

# ////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
# /////                                                                                                          /////
# /////                                        DataByCountry Tags                                                /////
# /////                                                                                                          /////
# ////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

TG_DataSource                           = '<DataSource>'
TG_MostRecentSurvey                     = '<Most Recent Survey>'
TG_NutritionalDeficiencies              = '<Nutritional deficiencies>'
TG_VitADefInPW                          = '<VitA deficiency in PW>'
TG_BaseBirthOutcomes                    = '<Baseline birth outcomes>'
TG_IncDiarrhea                          = '<Incidence of diarrhea>'
TG_IncSevereDiarrhea                    = '<Incidence of severe diarrhea>'
TG_IncPneum                             = '<Incidence of pneumonia>'
TG_IncMening                            = '<Incidence of meningitis>'
TG_MaternalAnemia                       = '<Maternal anemia>'
TG_PercWomenSevereAnemia                = '<Percent of women with severe anemia>'
TG_PercExposedFalciparum                = '<Percent exposed to falciparum>'
TG_IPTPRec                              = '<IPTP recommended>'
TG_MenArecommended                      = '<MenA recommended>'
TG_PercWom15t49LowBMI                   = '<Prevalence of low BMI in WRA>'
TG_SyphilisAmongWRA                     = '<Syphilis among WRA>'
TG_StuntingDist                         = '<Stunting Distribution>'
TG_WastingDist                          = '<Wasting Distribution>'
TG_PathSevDiarr                         = '<Pathogen incidence severe diarrhea>'
TG_PathAllDiarr                         = '<Pathogen incidence all diarrhea>'
TG_PathIncPneum                         = '<Pathogen incidence pneumonia>'
TG_PathIncMening                        = '<Pathogen incidence meningitis>'
TG_PathMortDiarr                        = '<Pathogen mortality diarrhea>'
TG_PathMortPneum                        = '<Pathogen mortality pneumonia>'
TG_PathMortMening                       = '<Pathogen mortality meningitis>'
TG_MortalityRate                        = '<Mortality Rate>'
TG_DeathsByCause                        = '<Deaths by cause>'
TG_BaselineAdolMort                     = '<Adolescent mortality rate>'
TG_AdolDeathByCause                     = '<Adolescent deaths by cause>'  
TG_BaselineMatMort                      = '<Baseline maternal mortality>'
TG_MatDeathByCause                      = '<Maternal death by cause>'
TG_PercPregEndInAbort                   = '<% pregnancies ending in abortion>'
TG_AbortIncRatio                        = '<Abortion incidence ratio>'
TG_BaselineSBRate                       = '<Baseline stillbirth rate>'
TG_SBCauses                             = '<Stillbirth causes>'
TG_EconomicStatus                       = '<Economic status>'
TG_GDPPerCapita                         = '<GDPPerCapita>'
TG_GDPPerWorker                         = '<GDPPerWorker>'
TG_GNIPerCap                            = '<GNI per capita>'
TG_LaborForceParRate                    = '<Labor force participation rate>'
TG_FemaleLaborForceParRate              = '<Female labor force participation rate>'
TG_LaborShareOfInc                      = '<Labor share of income>'
TG_EconReturnsToSchool                  = '<Economic Returns to Schooling>'
TG_AvgHouseHoldSize                     = '<Average household size>'
TG_Coverage                             = '<Coverage>'
TG_BreastFeeding                        = '<Breastfeeding>'
TG_EarlyInitBFPrev                      = '<Early initiation BF>'
TG_MaternalAF                           = '<Maternal affected fractions>'
TG_SBAffFractions                       = '<Stillbirth affected fractions>'
TG_AffFractions                         = '<Affected fractions>'
TG_RotavirusEff                         = '<Rotavirus effectiveness>'
TG_RotavirusEffSevDiar                  = '<Rotavirus Impact on Severe Diarrhea Incidence effectiveness>'
TG_RotavirusEffAllDiar                  = '<Rotavirus Impact on All Diarrhea Incidence effectiveness>'
TG_PneumoEffMortPneum                   = '<Pneumococcal effectiveness - mortality pneumonia>'
TG_PneumoEffMortMening                  = '<Pneumococcal effectiveness - mortality meningitis>'
TG_PathogenMortOther                    = '<Pathgen mortality -other>'
TG_PneumoEffMortOther                   = '<Pneumococcal effectiveness - mortality other>'
TG_AffFrac                              = '<Affected fraction for impact of therapeutic feeding on other>'
TG_PneumoEffIncPneum                    = '<Pneumococcal effectiveness - incidence pneumonia>'
TG_PneumoEffIncMening                   = '<Pneumococcal effectiveness - incidence meningitis>'
TG_ImpactBirthOutcomesOnMort            = '<Impact of birth outcomes on mortality>'
TG_AFRiskStuntWasteInfDis               = '<Affected fraction for risk of stunting and Wasting on other due to infectious disease>'
TG_AFRiskStuntWasteOtherPreterm         = '<Affected fraction for risk of stunting and Wasting on other due to preterm>'
TG_AFRiskStuntWasteOtherAsphyxia        = '<Affected fraction for risk of stunting and Wasting on other due to asphyxia>'
TG_AFRiskStuntWasteOtherCongenital      = '<Affected fraction for risk of stunting and Wasting on other due to congenital>'
TG_AFRiskStuntWasteOtherRemainOthers    = '<Affected fraction for risk of stunting and Wasting on other due to remaining others>'
TG_LiSTCostingOtherDirectCost           = '<LiST costing other direct cost>'
TG_LiSTCostingIndirectCost              = '<LiST costing indirect cost>'
TG_LBWConversionAlgorithm               = '<LBW conversion algorithm>'
TG_HerdEff                              = '<Herd Effectiveness>'
TG_AFBalancedEnergySupp                 = '<Affected Fraction -Balanced energy Supplementation>'
TG_AFStopSmokingEdu                     = '<Affected Fraction -Stop smoking education>'
TG_PercWomenWithPrevPreEclamp           = '<Percent of women with previous pre-eclampsia>'
TG_PercWomenWithChronicHypertension     = '<Percent of women with chronic hypertension>'